@@ -1,6 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * Main loader script
  *
  * @package PhpMyAdmin
  */
@@ -14,6 +15,7 @@ require_once 'libraries/common.inc.php';
  * display Git revision if requested
  */
 require_once 'libraries/display_git_revision.lib.php';
+require_once 'libraries/Template.class.php';
 
 /**
  * pass variables to child pages
@@ -32,25 +34,55 @@ foreach ($drops as $each_drop) {
 }
 unset($drops, $each_drop);
 
+/*
+ * Black list of all scripts to which front-end must submit data.
+ * Such scripts must not be loaded on home page.
+ *
+ */
+$target_blacklist = array (
+    'import.php', 'export.php'
+);
+
 // If we have a valid target, let's load that script instead
 if (! empty($_REQUEST['target'])
     && is_string($_REQUEST['target'])
     && ! preg_match('/^index/', $_REQUEST['target'])
+    && ! in_array($_REQUEST['target'], $target_blacklist)
     && in_array($_REQUEST['target'], $goto_whitelist)
 ) {
     include $_REQUEST['target'];
     exit;
 }
 
+if (isset($_REQUEST['ajax_request']) && ! empty($_REQUEST['access_time'])) {
+    exit;
+}
+
+// See FAQ 1.34
+if (! empty($_REQUEST['db'])) {
+    $page = null;
+    if (! empty($_REQUEST['table'])) {
+        $page = PMA_Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabTable'], 'table'
+        );
+    } else {
+        $page = PMA_Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+        );
+    }
+    include $page;
+    exit;
+}
+
 /**
  * Check if it is an ajax request to reload the recent tables list.
  */
-require_once 'libraries/RecentTable.class.php';
+require_once 'libraries/RecentFavoriteTable.class.php';
 if ($GLOBALS['is_ajax_request'] && ! empty($_REQUEST['recent_table'])) {
     $response = PMA_Response::getInstance();
     $response->addJSON(
-        'options',
-        PMA_RecentTable::getInstance()->getHtmlSelectOption()
+        'list',
+        PMA_RecentFavoriteTable::getInstance('recent')->getHtmlList()
     );
     exit;
 }
@@ -74,7 +106,8 @@ if (! empty($message)) {
     unset($message);
 }
 
-$common_url_query =  PMA_generate_common_url('', '');
+$common_url_query =  PMA_URL_getCommon();
+$mysql_cur_user_and_host = '';
 
 // when $server > 0, a server has been chosen so we can display
 // all MySQL-related information
@@ -92,12 +125,12 @@ if ($server > 0) {
         }
     }
     if ($GLOBALS['cfg']['ShowServerInfo'] || empty($cfg['Server']['verbose'])) {
-        $server_info .= PMA_DBI_get_host_info();
+        $server_info .= $GLOBALS['dbi']->getHostInfo();
     }
     if (! empty($cfg['Server']['verbose']) && $GLOBALS['cfg']['ShowServerInfo']) {
         $server_info .= ')';
     }
-    $mysql_cur_user_and_host = PMA_DBI_fetch_value('SELECT USER();');
+    $mysql_cur_user_and_host = $GLOBALS['dbi']->fetchValue('SELECT USER();');
 
     // should we add the port info here?
     $short_server_info = (!empty($GLOBALS['cfg']['Server']['verbose'])
@@ -106,22 +139,37 @@ if ($server > 0) {
 }
 
 echo '<div id="maincontainer">' . "\n";
+// Anchor for favorite tables synchronization.
+echo PMA_RecentFavoriteTable::getInstance('favorite')->getHtmlSyncFavoriteTables();
 echo '<div id="main_pane_left">';
 if ($server > 0 || count($cfg['Servers']) > 1
 ) {
+    if ($cfg['DBG']['demo']) {
+        echo '<div class="group">';
+        echo '<h2>' . __('phpMyAdmin Demo Server') . '</h2>';
+        echo '<p style="margin: 0.5em 1em 0.5em 1em">';
+        printf(
+            __(
+                'You are using the demo server. You can do anything here, but '
+                . 'please do not change root, debian-sys-maint and pma users. '
+                . 'More information is available at %s.'
+            ),
+            '<a href="http://demo.phpmyadmin.net/">demo.phpmyadmin.net</a>'
+        );
+        echo '</p>';
+        echo '</div>';
+    }
     echo '<div class="group">';
-    echo '<h2>' . __('General Settings') . '</h2>';
+    echo '<h2>' . __('General settings') . '</h2>';
     echo '<ul>';
 
     /**
      * Displays the MySQL servers choice form
      */
-    if ($cfg['ServerDefault'] == 0 
+    if ($cfg['ServerDefault'] == 0
         || (! $cfg['NavigationDisplayServers']
-            && (count($cfg['Servers']) > 1 
-                || ($server == 0 && count($cfg['Servers']) == 1)
-            )
-        )
+        && (count($cfg['Servers']) > 1
+        || ($server == 0 && count($cfg['Servers']) == 1)))
     ) {
         echo '<li id="li_select_server" class="no_bullets" >';
         include_once 'libraries/select_server.lib.php';
@@ -140,9 +188,9 @@ if ($server > 0 || count($cfg['Servers']) > 1
             if ($cfg['ShowChgPassword']) {
                 $conditional_class = 'ajax';
                 PMA_printListItem(
-                    PMA_Util::getImage('s_passwd.png') . " " . __('Change password'),
+                    PMA_Util::getImage('s_passwd.png') . "&nbsp;" . __('Change password'),
                     'li_change_password',
-                    'user_password.php?' . $common_url_query,
+                    'user_password.php' . $common_url_query,
                     null,
                     null,
                     'change_password_anchor',
@@ -153,15 +201,12 @@ if ($server > 0 || count($cfg['Servers']) > 1
         } // end if
         echo '    <li id="li_select_mysql_collation" class="no_bullets" >';
         echo '        <form method="post" action="index.php">' . "\n"
-           . PMA_generate_common_hidden_inputs(null, null, 4, 'collation_connection')
+           . PMA_URL_getHiddenInputs(null, null, 4, 'collation_connection')
            . '            <label for="select_collation_connection">' . "\n"
-           . '                '. PMA_Util::getImage('s_asci.png') . " " 
+           . '                ' . PMA_Util::getImage('s_asci.png') . "&nbsp;"
                                . __('Server connection collation') . "\n"
            // put the doc link in the form so that it appears on the same line
-           . PMA_Util::showMySQLDocu(
-               'MySQL_Database_Administration',
-               'Charset-connection'
-           )
+           . PMA_Util::showMySQLDocu('Charset-connection')
            . ': ' .  "\n"
            . '            </label>' . "\n"
 
@@ -171,7 +216,6 @@ if ($server > 0 || count($cfg['Servers']) > 1
                'select_collation_connection',
                $collation_connection,
                true,
-               4,
                true
            )
            . '        </form>' . "\n"
@@ -182,7 +226,7 @@ if ($server > 0 || count($cfg['Servers']) > 1
 }
 
 echo '<div class="group">';
-echo '<h2>' . __('Appearance Settings') . '</h2>';
+echo '<h2>' . __('Appearance settings') . '</h2>';
 echo '  <ul>';
 
 // Displays language selection combo
@@ -212,9 +256,9 @@ echo '</ul>';
 if ($server > 0) {
     echo '<ul>';
     PMA_printListItem(
-        PMA_Util::getImage('b_tblops.png')." " .__('More settings'),
+        PMA_Util::getImage('b_tblops.png') . "&nbsp;" . __('More settings'),
         'li_user_preferences',
-        'prefs_manage.php?' . $common_url_query,
+        'prefs_manage.php' . $common_url_query,
         null,
         null,
         null,
@@ -236,37 +280,40 @@ if ($server > 0 && $GLOBALS['cfg']['ShowServerInfo']) {
     echo '<h2>' . __('Database server') . '</h2>';
     echo '<ul>' . "\n";
     PMA_printListItem(
-        __('Server') . ': ' . $server_info,
+        __('Server:') . ' ' . $server_info,
         'li_server_info'
     );
     PMA_printListItem(
-        __('Server type') . ': ' . PMA_Util::getServerType(),
+        __('Server type:') . ' ' . PMA_Util::getServerType(),
         'li_server_type'
     );
     PMA_printListItem(
-        __('Server version') . ': ' . PMA_MYSQL_STR_VERSION . ' - ' . PMA_MYSQL_VERSION_COMMENT,
+        __('Server version:')
+        . ' '
+        . PMA_MYSQL_STR_VERSION . ' - ' . PMA_MYSQL_VERSION_COMMENT,
         'li_server_version'
     );
     PMA_printListItem(
-        __('Protocol version') . ': ' . PMA_DBI_get_proto_info(),
+        __('Protocol version:') . ' ' . $GLOBALS['dbi']->getProtoInfo(),
         'li_mysql_proto'
     );
     PMA_printListItem(
-        __('User') . ': ' . htmlspecialchars($mysql_cur_user_and_host),
+        __('User:') . ' ' . htmlspecialchars($mysql_cur_user_and_host),
         'li_user_info'
     );
 
     echo '    <li id="li_select_mysql_charset">';
-    echo '        ' . __('Server charset') . ': '
+    echo '        ' . __('Server charset:') . ' '
        . '        <span lang="en" dir="ltr">';
     if (! PMA_DRIZZLE) {
-        echo '           ' . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']] . "\n";
+        echo '           '
+            . $mysql_charsets_descriptions[$mysql_charset_map['utf-8']];
     }
-    echo '           (' . $mysql_charset_map['utf-8'] . ')' . "\n"
-       . '        </span>' . "\n"
-       . '    </li>' . "\n";
-    echo '  </ul>';
-    echo ' </div>';
+    echo '           (' . $mysql_charset_map['utf-8'] . ')'
+       . '        </span>'
+       . '    </li>'
+       . '  </ul>'
+       . ' </div>';
 }
 
 if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
@@ -277,26 +324,35 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
         PMA_printListItem($_SERVER['SERVER_SOFTWARE'], 'li_web_server_software');
 
         if ($server > 0) {
-            $client_version_str = PMA_DBI_get_client_info();
-            if (preg_match('#\d+\.\d+\.\d+#', $client_version_str)
-                && in_array($GLOBALS['cfg']['Server']['extension'], array('mysql', 'mysqli'))
-            ) {
+            $client_version_str = $GLOBALS['dbi']->getClientInfo();
+            if (preg_match('#\d+\.\d+\.\d+#', $client_version_str)) {
                 $client_version_str = 'libmysql - ' . $client_version_str;
             }
             PMA_printListItem(
-                __('Database client version') . ': ' . $client_version_str,
+                __('Database client version:') . ' ' . $client_version_str,
                 'li_mysql_client_version'
             );
 
-            $php_ext_string = __('PHP extension') . ': '
-                . $GLOBALS['cfg']['Server']['extension'] . ' '
-                . PMA_Util::showPHPDocu(
-                    'book.' . $GLOBALS['cfg']['Server']['extension'] . '.php'
-                );
+            $php_ext_string = __('PHP extension:') . ' ';
+            if (PMA_DatabaseInterface::checkDbExtension('mysqli')) {
+                $extension = 'mysqli';
+            } else {
+                $extension = 'mysql';
+            }
+            $php_ext_string  .= $extension . ' '
+                . PMA_Util::showPHPDocu('book.' . $extension . '.php');
+
             PMA_printListItem(
                 $php_ext_string,
                 'li_used_php_extension'
             );
+
+            $php_version_string = __('PHP version:') . ' ' . phpversion();
+
+            PMA_printListItem(
+                $php_version_string,
+                'li_used_php_version'
+            );
         }
     }
 
@@ -304,7 +360,7 @@ if ($GLOBALS['cfg']['ShowServerInfo'] || $GLOBALS['cfg']['ShowPhpInfo']) {
         PMA_printListItem(
             __('Show PHP information'),
             'li_phpinfo',
-            'phpinfo.php?' . $common_url_query,
+            'phpinfo.php' . $common_url_query,
             null,
             '_blank'
         );
@@ -325,7 +381,7 @@ if ($GLOBALS['cfg']['VersionCheck']
     $class = 'jsversioncheck';
 }
 PMA_printListItem(
-    __('Version information') . ': ' . PMA_VERSION,
+    __('Version information:') . ' <span class="version">' . PMA_VERSION . '</span>',
     'li_pma_version',
     null,
     null,
@@ -359,33 +415,31 @@ PMA_printListItem(
 PMA_printListItem(
     __('Contribute'),
     'li_pma_contribute',
-    PMA_linkURL('http://www.phpmyadmin.net/home_page/improve.php'),
+    PMA_linkURL('https://www.phpmyadmin.net/contribute/'),
     null,
     '_blank'
 );
 PMA_printListItem(
     __('Get support'),
     'li_pma_support',
-    PMA_linkURL('http://www.phpmyadmin.net/home_page/support.php'),
+    PMA_linkURL('https://www.phpmyadmin.net/support/'),
     null,
     '_blank'
 );
 PMA_printListItem(
     __('List of changes'),
     'li_pma_changes',
-    PMA_linkURL('changelog.php'),
+    'changelog.php' . PMA_URL_getCommon(),
     null,
     '_blank'
 );
-?>
-    </ul>
- </div>
+echo '    </ul>';
+echo ' </div>';
 
-</div>
+echo '</div>';
 
-</div>
+echo '</div>';
 
-<?php
 /**
  * Warning if using the default MySQL privileged account
  */
@@ -394,42 +448,65 @@ if ($server != 0
     && $cfg['Server']['password'] == ''
 ) {
     trigger_error(
-        __('Your configuration file contains settings (root with no password) that correspond to the default MySQL privileged account. Your MySQL server is running with this default, is open to intrusion, and you really should fix this security hole by setting a password for user \'root\'.'),
+        __(
+            'You are connected as \'root\' with no password, which'
+            . ' corresponds to the default MySQL privileged account.'
+            . ' Your MySQL server is running with this default, is open to'
+            . ' intrusion, and you really should fix this security hole by'
+            . ' setting a password for user \'root\'.'
+        ),
         E_USER_WARNING
     );
 }
 
 /**
- * Nijel: As we try to handle charsets by ourself, mbstring overloads just
+ * As we try to handle charsets by ourself, mbstring overloads just
  * break it, see bug 1063821.
  */
 if (@extension_loaded('mbstring') && @ini_get('mbstring.func_overload') > 1) {
     trigger_error(
-        __('You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause some data to be corrupted!'),
+        __(
+            'You have enabled mbstring.func_overload in your PHP '
+            . 'configuration. This option is incompatible with phpMyAdmin '
+            . 'and might cause some data to be corrupted!'
+        ),
         E_USER_WARNING
     );
 }
 
 /**
- * Nijel: mbstring is used for handling multibyte inside parser, so it is good
+ * mbstring is used for handling multibytes inside parser, so it is good
  * to tell user something might be broken without it, see bug #1063149.
  */
 if (! @extension_loaded('mbstring')) {
     trigger_error(
-        __('The mbstring PHP extension was not found and you seem to be using a multibyte charset. Without the mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.'),
+        __(
+            'The mbstring PHP extension was not found and you seem to be using'
+            . ' a multibyte charset. Without the mbstring extension phpMyAdmin'
+            . ' is unable to split strings correctly and it may result in'
+            . ' unexpected results.'
+        ),
         E_USER_WARNING
     );
 }
 
-/**
- * Check whether session.gc_maxlifetime limits session validity.
- */
-$gc_time = (int)@ini_get('session.gc_maxlifetime');
-if ($gc_time < $GLOBALS['cfg']['LoginCookieValidity'] ) {
-    trigger_error(
-        __('Your PHP parameter [a@http://php.net/manual/en/session.configuration.php#ini.session.gc-maxlifetime@_blank]session.gc_maxlifetime[/a] is lower than cookie validity configured in phpMyAdmin, because of this, your login will expire sooner than configured in phpMyAdmin.'),
-        E_USER_WARNING
-    );
+if ($cfg['LoginCookieValidityDisableWarning'] == false) {
+    /**
+     * Check whether session.gc_maxlifetime limits session validity.
+     */
+    $gc_time = (int)@ini_get('session.gc_maxlifetime');
+    if ($gc_time < $GLOBALS['cfg']['LoginCookieValidity'] ) {
+        trigger_error(
+            __(
+                'Your PHP parameter [a@http://php.net/manual/en/session.' .
+                'configuration.php#ini.session.gc-maxlifetime@_blank]session.' .
+                'gc_maxlifetime[/a] is lower than cookie validity configured ' .
+                'in phpMyAdmin, because of this, your login might expire sooner ' .
+                'than configured in phpMyAdmin.'
+            ),
+            E_USER_WARNING
+        );
+    }
 }
 
 /**
@@ -439,7 +516,11 @@ if ($GLOBALS['cfg']['LoginCookieStore'] != 0
     && $GLOBALS['cfg']['LoginCookieStore'] < $GLOBALS['cfg']['LoginCookieValidity']
 ) {
     trigger_error(
-        __('Login cookie store is lower than cookie validity configured in phpMyAdmin, because of this, your login will expire sooner than configured in phpMyAdmin.'),
+        __(
+            'Login cookie store is lower than cookie validity configured in ' .
+            'phpMyAdmin, because of this, your login will expire sooner than ' .
+            'configured in phpMyAdmin.'
+        ),
         E_USER_WARNING
     );
 }
@@ -447,11 +528,13 @@ if ($GLOBALS['cfg']['LoginCookieStore'] != 0
 /**
  * Check if user does not have defined blowfish secret and it is being used.
  */
-if (! empty($_SESSION['auto_blowfish_secret'])
+if (! empty($_SESSION['encryption_key'])
     && empty($GLOBALS['cfg']['blowfish_secret'])
 ) {
     trigger_error(
-        __('The configuration file now needs a secret passphrase (blowfish_secret).'),
+        __(
+            'The configuration file now needs a secret passphrase (blowfish_secret).'
+        ),
         E_USER_WARNING
     );
 }
@@ -462,7 +545,13 @@ if (! empty($_SESSION['auto_blowfish_secret'])
  */
 if (file_exists('config')) {
     trigger_error(
-        __('Directory [code]config[/code], which is used by the setup script, still exists in your phpMyAdmin directory. You should remove it once phpMyAdmin has been configured.'),
+        __(
+            'Directory [code]config[/code], which is used by the setup script, ' .
+            'still exists in your phpMyAdmin directory. It is strongly ' .
+            'recommended to remove it once phpMyAdmin has been configured. ' .
+            'Otherwise the security of your server may be compromised by ' .
+            'unauthorized people downloading your configuration.'
+        ),
         E_USER_WARNING
     );
 }
@@ -472,9 +561,22 @@ if ($server > 0) {
     if (! $cfgRelation['allworks']
         && $cfg['PmaNoRelation_DisableWarning'] == false
     ) {
-        $msg = PMA_Message::notice(__('The phpMyAdmin configuration storage is not completely configured, some extended features have been deactivated. To find out why click %shere%s.'));
+        $msg_text = __(
+            'The phpMyAdmin configuration storage is not completely '
+            . 'configured, some extended features have been deactivated. '
+            . '%sFind out why%s. '
+        );
+        if ($cfg['ZeroConf'] == true) {
+            $msg_text .= '<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' .
+                __(
+                    'Or alternately go to \'Operations\' tab of any database '
+                    . 'to set it up there.'
+                );
+        }
+        $msg = PMA_Message::notice($msg_text);
         $msg->addParam(
-            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php?' . $common_url_query . '">',
+            '<a href="' . $cfg['PmaAbsoluteUri'] . 'chk_rel.php'
+            . $common_url_query . '">',
             false
         );
         $msg->addParam('</a>', false);
@@ -491,23 +593,35 @@ if ($server > 0) {
  * (a difference on the third digit does not count).
  * If someday there is a constant that we can check about mysqlnd,
  * we can use it instead of strpos().
- * If no default server is set, PMA_DBI_get_client_info() is not defined yet.
+ * If no default server is set, $GLOBALS['dbi'] is not defined yet.
  * Drizzle can speak MySQL protocol, so don't warn about version mismatch for
  * Drizzle servers.
+ * We also do not warn if MariaDB is detected, as it has its own version
+ * numbering.
  */
-if (function_exists('PMA_DBI_get_client_info')
+if (isset($GLOBALS['dbi'])
     && !PMA_DRIZZLE
     && $cfg['ServerLibraryDifference_DisableWarning'] == false
 ) {
-    $_client_info = PMA_DBI_get_client_info();
+    /** @var PMA_String $pmaString */
+    $pmaString = $GLOBALS['PMA_String'];
+
+    $_client_info = $GLOBALS['dbi']->getClientInfo();
     if ($server > 0
-        && strpos($_client_info, 'mysqlnd') === false
-        && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(PMA_MYSQL_INT_VERSION, 0, 3)
+        && /*overload*/mb_strpos($_client_info, 'mysqlnd') === false
+        && /*overload*/mb_strpos(PMA_MYSQL_STR_VERSION, 'MariaDB') === false
+        && substr(PMA_MYSQL_CLIENT_API, 0, 3) != substr(
+            PMA_MYSQL_INT_VERSION, 0, 3
+        )
     ) {
         trigger_error(
             PMA_sanitize(
                 sprintf(
-                    __('Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.'),
+                    __(
+                        'Your PHP MySQL library version %s differs from your ' .
+                        'MySQL server version %s. This may cause unpredictable ' .
+                        'behavior.'
+                    ),
                     $_client_info,
                     substr(
                         PMA_MYSQL_STR_VERSION,
@@ -523,16 +637,18 @@ if (function_exists('PMA_DBI_get_client_info')
 }
 
 /**
- * Warning about Suhosin
+ * Warning about Suhosin only if its simulation mode is not enabled
  */
 if ($cfg['SuhosinDisableWarning'] == false
     && @ini_get('suhosin.request.max_value_length')
-    // warn about Suhosin only if its simulation mode is not enabled
     && @ini_get('suhosin.simulation') == '0'
 ) {
     trigger_error(
         sprintf(
-            __('Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.'),
+            __(
+                'Server running with Suhosin. Please refer to %sdocumentation%s ' .
+                'for possible issues.'
+            ),
             '[doc@faq1-38]',
             '[/doc]'
         ),
@@ -540,15 +656,6 @@ if ($cfg['SuhosinDisableWarning'] == false
     );
 }
 
-/**
- * Warning about mcrypt.
- */
-if (! function_exists('mcrypt_encrypt')
-    && ! $GLOBALS['cfg']['McryptDisableWarning']
-) {
-    PMA_warnMissingExtension('mcrypt');
-}
-
 /**
  * Warning about incomplete translations.
  *
@@ -565,7 +672,9 @@ if (file_exists('libraries/language_stats.inc.php')) {
         && $GLOBALS['language_stats'][$lang] < $cfg['TranslationWarningThreshold']
     ) {
         trigger_error(
-            'You are using an incomplete translation, please help to make it better by [a@http://www.phpmyadmin.net/home_page/improve.php#translate@_blank]contributing[/a].',
+            'You are using an incomplete translation, please help to make it '
+            . 'better by [a@https://www.phpmyadmin.net/translate/'
+            . '@_blank]contributing[/a].',
             E_USER_NOTICE
         );
     }
@@ -575,7 +684,7 @@ if (file_exists('libraries/language_stats.inc.php')) {
  * prints list item for main page
  *
  * @param string $name            displayed text
- * @param string $id              id, used for css styles
+ * @param string $listId          id, used for css styles
  * @param string $url             make item as link with $url as target
  * @param string $mysql_help_page display a link to MySQL's manual
  * @param string $target          special target for $url
@@ -586,36 +695,23 @@ if (file_exists('libraries/language_stats.inc.php')) {
  *
  * @return void
  */
-function PMA_printListItem($name, $id = null, $url = null, $mysql_help_page = null,
-    $target = null, $a_id = null, $class = null, $a_class = null
+function PMA_printListItem($name, $listId = null, $url = null,
+    $mysql_help_page = null, $target = null, $a_id = null, $class = null,
+    $a_class = null
 ) {
-    echo '<li id="' . $id . '"';
-    if (null !== $class) {
-        echo ' class="' . $class . '"';
-    }
-    echo '>';
-    if (null !== $url) {
-        echo '<a href="' . $url . '"';
-        if (null !== $target) {
-            echo ' target="' . $target . '"';
-        }
-        if (null != $a_id) {
-            echo ' id="' . $a_id .'"';
-        }
-        if (null != $a_class) {
-            echo ' class="' . $a_class .'"';
-        }
-        echo '>';
-    }
-
-    echo $name;
-
-    if (null !== $url) {
-        echo '</a>' . "\n";
-    }
-    if (null !== $mysql_help_page) {
-        echo PMA_Util::showMySQLDocu('', $mysql_help_page);
-    }
-    echo '</li>';
+    echo PMA\Template::get('list/item')
+        ->render(
+            array(
+                'content' => $name,
+                'id' => $listId,
+                'class' => $class,
+                'url' => array(
+                    'href' => $url,
+                    'target' => $target,
+                    'id' => $a_id,
+                    'class' => $a_class,
+                ),
+                'mysql_help_page' => $mysql_help_page,
+            )
+        );
 }
-?>
