@@ -17,6 +17,25 @@ header('Content-Type: text/javascript; charset=UTF-8');
 // Enable browser cache for 1 hour
 header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');
 
+// When a token is not presented, even though whitelisted arrays are removed
+// in PMA_removeRequestVars(). This is a workaround for that.
+$_GET['scripts'] = json_encode($_GET['scripts']);
+
+// Avoid loading the full common.inc.php because this would add many
+// non-js-compatible stuff like DOCTYPE
+define('PMA_MINIMUM_COMMON', true);
+require_once './libraries/common.inc.php';
+
+require_once './libraries/OutputBuffering.class.php';
+$buffer = PMA_OutputBuffering::getInstance();
+$buffer->start();
+register_shutdown_function(
+    function () {
+        echo PMA_OutputBuffering::getInstance()->getContents();
+    }
+);
+
+$_GET['scripts'] = json_decode($_GET['scripts']);
 if (! empty($_GET['scripts']) && is_array($_GET['scripts'])) {
     foreach ($_GET['scripts'] as $script) {
         // Sanitise filename
@@ -42,4 +61,3 @@ if (! empty($_GET['scripts']) && is_array($_GET['scripts'])) {
 if (isset($_GET['call_done'])) {
     echo "AJAX.scriptHandler.done();";
 }
-?>
