@@ -26,6 +26,15 @@ session_write_close();
 require_once './libraries/js_escape.lib.php';
 require_once './libraries/Util.class.php';
 
+require_once './libraries/OutputBuffering.class.php';
+$buffer = PMA_OutputBuffering::getInstance();
+$buffer->start();
+register_shutdown_function(
+    function () {
+        echo PMA_OutputBuffering::getInstance()->getContents();
+    }
+);
+
 $js_messages['strNoDropDatabases'] = __('"DROP DATABASE" statements are disabled.');
 if ($cfg['AllowUserDropDatabase']) {
     $js_messages['strNoDropDatabases'] = '';
@@ -37,26 +46,77 @@ $js_messages['strDoYouReally'] = __('Do you really want to execute "%s"?');
 $js_messages['strDropDatabaseStrongWarning'] = __('You are about to DESTROY a complete database!');
 $js_messages['strDropTableStrongWarning'] = __('You are about to DESTROY a complete table!');
 $js_messages['strTruncateTableStrongWarning'] = __('You are about to TRUNCATE a complete table!');
-$js_messages['strDeleteTrackingData'] = __('Delete tracking data for this table');
+$js_messages['strDeleteTrackingData'] = __('Delete tracking data for this table?');
+$js_messages['strDeleteTrackingDataMultiple'] = __('Delete tracking data for these tables?');
+$js_messages['strDeleteTrackingVersion'] = __('Delete tracking data for this version?');
+$js_messages['strDeleteTrackingVersionMultiple'] = __('Delete tracking data for these versions?');
+$js_messages['strDeletingTrackingEntry'] = __('Delete entry from tracking report?');
 $js_messages['strDeletingTrackingData'] = __('Deleting tracking data');
 $js_messages['strDroppingPrimaryKeyIndex'] = __('Dropping Primary Key/Index');
+$js_messages['strDroppingForeignKey'] = __('Dropping Foreign key.');
 $js_messages['strOperationTakesLongTime'] = __('This operation could take a long time. Proceed anyway?');
 $js_messages['strDropUserGroupWarning'] = __('Do you really want to delete user group "%s"?');
 $js_messages['strConfirmDeleteQBESearch'] = __('Do you really want to delete the search "%s"?');
-$js_messages['strConfirmNavigation'] = __('Are you sure you want to navigate away from this page? Press OK to continue or Cancel to stay on the current page.');
+$js_messages['strConfirmNavigation'] = __('You have unsaved changes; are you sure you want to leave this page?');
+$js_messages['strDropUserWarning'] = __('Do you really want to revoke the selected user(s) ?');
+$js_messages['strDeleteCentralColumnWarning'] = __('Do you really want to delete this central column?');
+$js_messages['strDropRTEitems'] = __('Do you really want to delete the selected items?');
+$js_messages['strDropPartitionWarning'] = __('Do you really want to DROP the selected partition(s)? This will also DELETE the data related to the selected partition(s)!');
+$js_messages['strTruncatePartitionWarning'] = __('Do you really want to TRUNCATE the selected partition(s)?');
+$js_messages['strResetSlaveWarning'] = __('Do you really want to RESET SLAVE?');
+$js_messages['strChangeColumnCollation'] = __(
+    'This operation will attempt to convert your data to the new collation. In '
+    . 'rare cases, especially where a character doesn\'t exist in the new '
+    . 'collation, this process could cause the data to appear incorrectly under '
+    . 'the new collation; in this case we suggest you revert to the original '
+    . 'collation and refer to the tips at '
+)
+    . '<a href="%s" target="garbled_data_wiki">' . __('Garbled Data') . '</a>.'
+    . '<br/><br/>'
+    . __('Are you sure you wish to change the collation and convert the data?');
+$js_messages['strChangeAllColumnCollationsWarning'] = __(
+    'Through this operation, MySQL attempts to map the data values between collations. '
+    . 'If the character sets are incompatible, '
+    . 'there may be data loss and this lost data may <b>NOT</b> be recoverable simply '
+    . 'by changing back the column collation(s).'
+    . '<b> To convert existing data, it is suggested to use the column(s) editing feature '
+    . '(the "Change" Link) on the table structure page. </b>'
+)
+. '<br/><br/>'
+. __('Are you sure you wish to change all the column collations and convert the data?');
+
+/* For modal dialog buttons */
+$js_messages['strSaveAndClose'] = __('Save & close');
+$js_messages['strReset'] = __('Reset');
+$js_messages['strResetAll'] = __('Reset all');
 
 /* For indexes */
 $js_messages['strFormEmpty'] = __('Missing value in the form!');
 $js_messages['strRadioUnchecked'] = __('Select at least one of the options!');
 $js_messages['strEnterValidNumber'] = __('Please enter a valid number!');
 $js_messages['strEnterValidLength'] = __('Please enter a valid length!');
-$js_messages['strAddIndex'] = __('Add Index');
-$js_messages['strEditIndex'] = __('Edit Index');
+$js_messages['strAddIndex'] = __('Add index');
+$js_messages['strEditIndex'] = __('Edit index');
 $js_messages['strAddToIndex'] = __('Add %s column(s) to index');
+$js_messages['strCreateSingleColumnIndex'] = __('Create single-column index');
+$js_messages['strCreateCompositeIndex'] = __('Create composite index');
+$js_messages['strCompositeWith'] = __('Composite with:');
+$js_messages['strMissingColumn'] = __('Please select column(s) for the index.');
+
+/* For Create Table */
+$js_messages['strLeastColumnError'] = __('You have to add at least one column.');
+
+/* For Preview SQL*/
+$js_messages['strPreviewSQL'] = __('Preview SQL');
+
+/* For Simulate DML*/
+$js_messages['strSimulateDML'] = __('Simulate query');
+$js_messages['strMatchedRows'] = __('Matched rows:');
+$js_messages['strSQLQuery'] = __('SQL query:');
 
 /* Charts */
 /* l10n: Default label for the y-Axis of Charts */
-$js_messages['strYValues'] = __('Y Values');
+$js_messages['strYValues'] = __('Y values');
 
 /* For server_privileges.js */
 $js_messages['strHostEmpty'] = __('The host name is empty!');
@@ -66,6 +126,12 @@ $js_messages['strPasswordNotSame'] = __('The passwords aren\'t the same!');
 $js_messages['strRemovingSelectedUsers'] = __('Removing Selected Users');
 $js_messages['strClose'] = __('Close');
 
+/* For export.js */
+$js_messages['strTemplateCreated'] = __('Template was created.');
+$js_messages['strTemplateLoaded'] = __('Template was loaded.');
+$js_messages['strTemplateUpdated'] = __('Template was updated.');
+$js_messages['strTemplateDeleted'] = __('Template was deleted.');
+
 /* l10n: Other, small valued, queries */
 $js_messages['strOther'] = __('Other');
 /* l10n: Thousands separator */
@@ -83,7 +149,7 @@ $js_messages['strQueryCacheEfficiency'] = __('Query cache efficiency');
 $js_messages['strQueryCacheUsage'] = __('Query cache usage');
 $js_messages['strQueryCacheUsed'] = __('Query cache used');
 
-$js_messages['strSystemCPUUsage'] = __('System CPU Usage');
+$js_messages['strSystemCPUUsage'] = __('System CPU usage');
 $js_messages['strSystemMemory'] = __('System memory');
 $js_messages['strSystemSwap'] = __('System swap');
 
@@ -94,10 +160,10 @@ $js_messages['strBufferedMemory'] = __('Buffered memory');
 $js_messages['strFreeMemory'] = __('Free memory');
 $js_messages['strUsedMemory'] = __('Used memory');
 
-$js_messages['strTotalSwap'] = __('Total Swap');
-$js_messages['strCachedSwap'] = __('Cached Swap');
-$js_messages['strUsedSwap'] = __('Used Swap');
-$js_messages['strFreeSwap'] = __('Free Swap');
+$js_messages['strTotalSwap'] = __('Total swap');
+$js_messages['strCachedSwap'] = __('Cached swap');
+$js_messages['strUsedSwap'] = __('Used swap');
+$js_messages['strFreeSwap'] = __('Free swap');
 
 $js_messages['strBytesSent'] = __('Bytes sent');
 $js_messages['strBytesReceived'] = __('Bytes received');
@@ -112,7 +178,7 @@ $js_messages['strGiB'] = __('GiB');
 $js_messages['strTiB'] = __('TiB');
 $js_messages['strPiB'] = __('PiB');
 $js_messages['strEiB'] = __('EiB');
-$js_messages['strTables'] = __('%d table(s)');
+$js_messages['strNTables'] = __('%d table(s)');
 
 /* l10n: Questions is the name of a MySQL Status variable */
 $js_messages['strQuestions'] = __('Questions');
@@ -124,6 +190,8 @@ $js_messages['strAddOneSeriesWarning'] = __('Please add at least one variable to
 $js_messages['strNone'] = __('None');
 $js_messages['strResumeMonitor'] = __('Resume monitor');
 $js_messages['strPauseMonitor'] = __('Pause monitor');
+$js_messages['strStartRefresh'] = __('Start auto refresh');
+$js_messages['strStopRefresh'] = __('Stop auto refresh');
 /* Monitor: Instructions Dialog */
 $js_messages['strBothLogOn'] = __('general_log and slow_query_log are enabled.');
 $js_messages['strGenLogOn'] = __('general_log is enabled.');
@@ -149,7 +217,7 @@ $js_messages['strNoSuperUser'] = __(
 $js_messages['strChangeSettings'] = __('Change settings');
 $js_messages['strCurrentSettings'] = __('Current settings');
 
-$js_messages['strChartTitle'] = __('Chart Title');
+$js_messages['strChartTitle'] = __('Chart title');
 /* l10n: As in differential values */
 $js_messages['strDifferential'] = __('Differential');
 $js_messages['strDividedBy'] = __('Divided by %s');
@@ -205,7 +273,7 @@ $js_messages['strImportDialogTitle'] = __('Import monitor configuration');
 $js_messages['strImportDialogMessage'] = __('Please select the file you want to import.');
 $js_messages['strNoImportFile'] = __('No files available on server for import!');
 
-$js_messages['strAnalyzeQuery'] = __('Analyse Query');
+$js_messages['strAnalyzeQuery'] = __('Analyse query');
 
 /* Server status advisor */
 
@@ -218,34 +286,42 @@ $js_messages['strJustification'] = __('Justification');
 $js_messages['strFormula'] = __('Used variable / formula');
 $js_messages['strTest'] = __('Test');
 
+/* For query editor */
+$js_messages['strFormatting'] = __('Formatting SQL…');
 
 /* For inline query editing */
 $js_messages['strGo'] = __('Go');
 $js_messages['strCancel'] = __('Cancel');
 
+/* For page-related settings */
+$js_messages['strPageSettings'] = __('Page-related settings');
+$js_messages['strApply'] = __('Apply');
+
 /* For Ajax Notifications */
 $js_messages['strLoading'] = __('Loading…');
-$js_messages['strAbortedRequest'] = __('Request Aborted!!');
-$js_messages['strProcessingRequest'] = __('Processing Request');
-$js_messages['strErrorProcessingRequest'] = __('Error in Processing Request');
+$js_messages['strAbortedRequest'] = __('Request aborted!!');
+$js_messages['strProcessingRequest'] = __('Processing request');
+$js_messages['strRequestFailed'] = __('Request failed!!');
+$js_messages['strErrorProcessingRequest'] = __('Error in processing request');
 $js_messages['strErrorCode'] = __('Error code: %s');
 $js_messages['strErrorText'] = __('Error text: %s');
 $js_messages['strNoDatabasesSelected'] = __('No databases selected.');
-$js_messages['strDroppingColumn'] = __('Dropping Column');
-$js_messages['strAddingPrimaryKey'] = __('Adding Primary Key');
+$js_messages['strDroppingColumn'] = __('Dropping column');
+$js_messages['strAddingPrimaryKey'] = __('Adding primary key');
 $js_messages['strOK'] = __('OK');
 $js_messages['strDismiss'] = __('Click to dismiss this notification');
 
 /* For db_operations.js */
-$js_messages['strRenamingDatabases'] = __('Renaming Databases');
-$js_messages['strCopyingDatabase'] = __('Copying Database');
-$js_messages['strChangingCharset'] = __('Changing Charset');
+$js_messages['strRenamingDatabases'] = __('Renaming databases');
+$js_messages['strCopyingDatabase'] = __('Copying database');
+$js_messages['strChangingCharset'] = __('Changing charset');
 $js_messages['strNo'] = __('No');
 
+/* For Foreign key checks */
+$js_messages['strForeignKeyCheck'] = __('Enable foreign key checks');
+
 /* For db_stucture.js */
-$js_messages['strForeignKeyCheck'] = __('Foreign key check:');
-$js_messages['strForeignKeyCheckEnabled'] = __('(Enabled)');
-$js_messages['strForeignKeyCheckDisabled'] = __('(Disabled)');
+$js_messages['strErrorRealRowCount'] = __('Failed to get real row count.');
 
 /* For db_search.js */
 $js_messages['strSearching'] = __('Searching');
@@ -256,6 +332,7 @@ $js_messages['strDeleting'] = __('Deleting');
 
 /* For db_routines.js */
 $js_messages['MissingReturn'] = __('The definition of a stored function must contain a RETURN statement!');
+$js_messages['strExport'] = __('Export');
 
 /* For ENUM/SET editor*/
 $js_messages['enum_editor'] = __('ENUM/SET editor');
@@ -271,7 +348,48 @@ $js_messages['strImportCSV'] = __('Note: If the file contains multiple tables, t
 $js_messages['strHideQueryBox'] = __('Hide query box');
 $js_messages['strShowQueryBox'] = __('Show query box');
 $js_messages['strEdit'] = __('Edit');
+$js_messages['strDelete'] = __('Delete');
 $js_messages['strNotValidRowNumber'] = __('%d is not valid row number.');
+$js_messages['strBrowseForeignValues'] = __('Browse foreign values');
+$js_messages['strNoAutoSavedQuery'] = __('No auto-saved query');
+$js_messages['strBookmarkVariable'] = __('Variable %d:');
+
+/* For Central list of columns */
+$js_messages['pickColumn'] = __('Pick');
+$js_messages['pickColumnTitle'] = __('Column selector');
+$js_messages['searchList'] = __('Search this list');
+$js_messages['strEmptyCentralList'] = __('No columns in the central list. Make sure the Central columns list for database %s has columns that are not present in the current table.');
+$js_messages['seeMore'] = __('See more');
+$js_messages['confirmTitle'] = __('Are you sure?');
+$js_messages['makeConsistentMessage'] = __('This action may change some of the columns definition.<br/>Are you sure you want to continue?');
+$js_messages['strContinue'] = __('Continue');
+
+/** For normalization */
+$js_messages['strAddPrimaryKey'] = __('Add primary key');
+$js_messages['strPrimaryKeyAdded'] = __('Primary key added.');
+$js_messages['strToNextStep'] = __('Taking you to next step…');
+$js_messages['strFinishMsg'] = __("The first step of normalization is complete for table '%s'.");
+$js_messages['strEndStep'] = __("End of step");
+$js_messages['str2NFNormalization'] = __('Second step of normalization (2NF)');
+$js_messages['strDone'] = __('Done');
+$js_messages['strConfirmPd'] = __('Confirm partial dependencies');
+$js_messages['strSelectedPd'] = __('Selected partial dependencies are as follows:');
+$js_messages['strPdHintNote'] = __('Note: a, b -> d,f implies values of columns a and b combined together can determine values of column d and column f.');
+$js_messages['strNoPdSelected'] = __('No partial dependencies selected!');
+$js_messages['strBack'] = __('Back');
+$js_messages['strShowPossiblePd'] = __('Show me the possible partial dependencies based on data in the table');
+$js_messages['strHidePd'] = __('Hide partial dependencies list');
+$js_messages['strWaitForPd'] = __('Sit tight! It may take few seconds depending on data size and column count of the table.');
+$js_messages['strStep'] = __('Step');
+$js_messages['strMoveRepeatingGroup'] = '<ol><b>' . __('The following actions will be performed:') . '</b>'
+    . '<li>' . __('DROP columns %s from the table %s') . '</li>'
+    . '<li>' . __('Create the following table') . '</li>';
+$js_messages['strNewTablePlaceholder'] = 'Enter new table name';
+$js_messages['strNewColumnPlaceholder'] = 'Enter column name';
+$js_messages['str3NFNormalization'] = __('Third step of normalization (3NF)');
+$js_messages['strConfirmTd'] = __('Confirm transitive dependencies');
+$js_messages['strSelectedTd'] = __('Selected dependencies are as follows:');
+$js_messages['strNoTdSelected'] = __('No dependencies selected!');
 
 /* For server_variables.js */
 $js_messages['strSave'] = __('Save');
@@ -279,6 +397,11 @@ $js_messages['strSave'] = __('Save');
 /* For tbl_select.js */
 $js_messages['strHideSearchCriteria'] = __('Hide search criteria');
 $js_messages['strShowSearchCriteria'] = __('Show search criteria');
+$js_messages['strRangeSearch'] = __('Range search');
+$js_messages['strColumnMax'] = __('Column maximum:');
+$js_messages['strColumnMin'] = __('Column minimum:');
+$js_messages['strMinValue'] = __('Minimum value:');
+$js_messages['strMaxValue'] = __('Maximum value:');
 
 /* For tbl_find_replace.js */
 $js_messages['strHideFindNReplaceCriteria'] = __('Hide find and replace criteria');
@@ -298,6 +421,7 @@ $js_messages['strDisplayHelp'] = '<ul><li>'
     . '</li><li>'
     . __('The plot can be resized by dragging it along the bottom right corner.')
     . '</li></ul>';
+$js_messages['strHelpTitle'] = 'Zoom search instructions';
 $js_messages['strInputNull'] = '<strong>' . __('Select two columns') . '</strong>';
 $js_messages['strSameInputs'] = '<strong>'
     . __('Select two different columns')
@@ -314,15 +438,20 @@ $js_messages['strPointN'] = __('Point %d');
 $js_messages['strLineString'] = __('Linestring');
 $js_messages['strPolygon'] = __('Polygon');
 $js_messages['strGeometry'] = __('Geometry');
-$js_messages['strInnerRing'] = __('Inner Ring');
-$js_messages['strOuterRing'] = __('Outer Ring');
+$js_messages['strInnerRing'] = __('Inner ring');
+$js_messages['strOuterRing'] = __('Outer ring');
 $js_messages['strAddPoint'] = __('Add a point');
 $js_messages['strAddInnerRing'] = __('Add an inner ring');
-$js_messages['strFunctionHint'] = __('Shift + Click on function name to apply to all rows.');
 $js_messages['strYes'] = __('Yes');
 $js_messages['strCopyEncryptionKey'] = __('Do you want to copy encryption key?');
 $js_messages['strEncryptionKey'] = __('Encryption key');
 
+/* For Lock symbol Tooltip */
+$js_messages['strLockToolTip'] = __(
+    'Indicates that you have made changes to this page;'
+    . ' you will be prompted for confirmation before abandoning changes'
+);
+
 /* Designer (js/pmd/move.js) */
 $js_messages['strSelectReferencedKey'] = __('Select referenced key');
 $js_messages['strSelectForeignKey'] = __('Select Foreign Key');
@@ -332,17 +461,30 @@ $js_messages['strLeavingDesigner'] = __(
     'You haven\'t saved the changes in the layout. They will be lost if you'
     . ' don\'t save them. Do you want to continue?'
 );
+$js_messages['strPageName'] = __('Page name');
+$js_messages['strSavePage'] = __('Save page');
+$js_messages['strSavePageAs'] = __('Save page as');
+$js_messages['strOpenPage'] = __('Open page');
+$js_messages['strDeletePage'] = __('Delete page');
+$js_messages['strUntitled'] = __('Untitled');
+$js_messages['strSelectPage'] = __('Please select a page to continue');
+$js_messages['strEnterValidPageName'] = __('Please enter a valid page name');
+$js_messages['strLeavingPage'] = __('Do you want to save the changes to the current page?');
+$js_messages['strSuccessfulPageDelete'] = __('Successfully deleted the page');
+$js_messages['strExportRelationalSchema'] = __('Export relational schema');
+$js_messages['strModificationSaved'] = __('Modifications have been saved');
 
 /* Visual query builder (js/pmd/move.js) */
 $js_messages['strAddOption'] = __('Add an option for column "%s".');
 $js_messages['strObjectsCreated'] = __('%d object(s) created.');
+$js_messages['strSubmit'] = __('Submit');
 
 /* For makegrid.js (column reordering, show/hide column, grid editing) */
 $js_messages['strCellEditHint'] = __('Press escape to cancel editing.');
 $js_messages['strSaveCellWarning'] = __('You have edited some data and they have not been saved. Are you sure you want to leave this page before saving the data?');
 $js_messages['strColOrderHint'] = __('Drag to reorder.');
 $js_messages['strSortHint'] = __('Click to sort results by this column.');
-$js_messages['strMultiSortHint'] = __('Shift+Click to add this column to ORDER BY clause or to toggle ASC/DESC.<br />- Control+Click to remove column from ORDER BY clause');
+$js_messages['strMultiSortHint'] = __('Shift+Click to add this column to ORDER BY clause or to toggle ASC/DESC.<br />- Ctrl+Click or Alt+Click (Mac: Shift+Option+Click) to remove column from ORDER BY clause');
 $js_messages['strColMarkHint'] = __('Click to mark/unmark.');
 $js_messages['strColNameCopyHint'] = __('Double-click to copy column name.');
 $js_messages['strColVisibHint'] = __(
@@ -350,6 +492,18 @@ $js_messages['strColVisibHint'] = __(
 );
 $js_messages['strShowAllCol'] = __('Show all');
 $js_messages['strAlertNonUnique'] = __('This table does not contain a unique column. Features related to the grid edit, checkbox, Edit, Copy and Delete links may not work after saving.');
+$js_messages['strEnterValidHex'] = __('Please enter a valid hexadecimal string. Valid characters are 0-9, A-F.');
+$js_messages['strShowAllRowsWarning'] = __('Do you really want to see all of the rows? For a big table this could crash the browser.');
+$js_messages['strOriginalLength'] = __('Original length');
+
+/** Drag & Drop sql import messages */
+$js_messages['dropImportMessageCancel'] = __('cancel');
+$js_messages['dropImportMessageAborted'] = __('Aborted');
+$js_messages['dropImportMessageFailed'] = __('Failed');
+$js_messages['dropImportMessageSuccess'] = __('Success');
+$js_messages['dropImportImportResultHeader'] = __('Import status');
+$js_messages['dropImportDropFiles'] = __('Drop files here');
+$js_messages['dropImportSelectDB'] = __('Select database first');
 
 // this approach does not work when the parameter is changed via user prefs
 switch ($GLOBALS['cfg']['GridEditing']) {
@@ -365,20 +519,28 @@ default:
 $js_messages['strGoToLink'] = __('Go to link:');
 $js_messages['strColNameCopyTitle'] = __('Copy column name.');
 $js_messages['strColNameCopyText'] = __('Right-click the column name to copy it to your clipboard.');
-$js_messages['strShowDataRowLink'] = __('Show data row(s).');
 
 /* password generation */
 $js_messages['strGeneratePassword'] = __('Generate password');
 $js_messages['strGenerate'] = __('Generate');
-$js_messages['strChangePassword'] = __('Change Password');
+$js_messages['strChangePassword'] = __('Change password');
 
 /* navigation tabs */
 $js_messages['strMore'] = __('More');
 
 /* navigation panel */
-$js_messages['strShowPanel'] = __('Show Panel');
-$js_messages['strHidePanel'] = __('Hide Panel');
+$js_messages['strShowPanel'] = __('Show panel');
+$js_messages['strHidePanel'] = __('Hide panel');
 $js_messages['strUnhideNavItem'] = __('Show hidden navigation tree items.');
+$js_messages['linkWithMain'] = __('Link with main panel');
+$js_messages['unlinkWithMain'] = __('Unlink from main panel');
+$js_messages['strHoverDbFastFilter'] = __('To filter all databases on server, press Enter after a search term');
+$js_messages['strHoverFastFilter'] = __('To filter all %s in database, press Enter after a search term');
+$js_messages['strTables'] = __('tables');
+$js_messages['strViews'] = __('views');
+$js_messages['strProcedures'] = __('procedures');
+$js_messages['strEvents'] = __('events');
+$js_messages['strFunctions'] = __('functions');
 
 /* microhistory */
 $js_messages['strInvalidPage'] = __('The requested page was not found in the history, it may have expired.');
@@ -392,13 +554,13 @@ $js_messages['strUpToDate'] = __('up to date');
 $js_messages['strCreateView'] = __('Create view');
 
 /* Error Reporting */
-$js_messages['strSendErrorReport'] = __("Send Error Report");
-$js_messages['strSubmitErrorReport'] = __("Submit Error Report");
+$js_messages['strSendErrorReport'] = __("Send error report");
+$js_messages['strSubmitErrorReport'] = __("Submit error report");
 $js_messages['strErrorOccurred'] = __(
     "A fatal JavaScript error has occurred. Would you like to send an error report?"
 );
-$js_messages['strChangeReportSettings'] = __("Change Report Settings");
-$js_messages['strShowReportDetails'] = __("Show Report Details");
+$js_messages['strChangeReportSettings'] = __("Change report settings");
+$js_messages['strShowReportDetails'] = __("Show report details");
 $js_messages['strIgnore'] = __("Ignore");
 $js_messages['strTimeOutError'] = __(
     "Your export is incomplete, due to a low execution time limit at the PHP level!"
@@ -410,6 +572,40 @@ $js_messages['strTooManyInputs'] = __(
     . "max_input_vars configuration."
 );
 
+$js_messages['phpErrorsFound'] = '<div class="error">'
+    . __('Some errors have been detected on the server!')
+    . '<br/>'
+    . __('Please look at the bottom of this window.')
+    . '<div>'
+    . '<input id="pma_ignore_errors_popup" type="submit" value="'
+    . __('Ignore')
+    . '" class="floatright" style="margin-top: 20px;">'
+    . '<input id="pma_ignore_all_errors_popup" type="submit" value="'
+    . __('Ignore All')
+    . '" class="floatright" style="margin-top: 20px;">'
+    . '</div></div>';
+
+$js_messages['phpErrorsBeingSubmitted'] = '<div class="error">'
+    . __('Some errors have been detected on the server!')
+    . '<br/>'
+    . __('As per your settings, they are being submitted currently, please be patient.')
+    . '<br/>'
+    . '<img src="'
+    . ($_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif'))
+    . '" width="16" height="16" alt="ajax clock"/>'
+    . '</div>';
+
+// For console
+$js_messages['strConsoleRequeryConfirm'] = __('Execute this query again?');
+$js_messages['strConsoleDeleteBookmarkConfirm'] = __('Do you really want to delete this bookmark?');
+$js_messages['strConsoleDebugError'] = __('Some error occurred while getting SQL debug info.');
+$js_messages['strConsoleDebugSummary'] = __('%s queries executed %s times in %s seconds.');
+$js_messages['strConsoleDebugArgsSummary'] = __('%s argument(s) passed');
+$js_messages['strConsoleDebugShowArgs'] = __('Show arguments');
+$js_messages['strConsoleDebugHideArgs'] = __('Hide arguments');
+$js_messages['strConsoleDebugTimeTaken'] = __('Time taken:');
+$js_messages['strNoLocalStorage'] = __('There was a problem accessing your browser storage, some features may not work properly for you. It is likely that the browser doesn\'t support storage or the quota limit has been reached. In Firefox, corrupted storage can also cause such a problem, clearing your "Offline Website Data" might help. In Safari, such problem is commonly caused by "Private Mode Browsing".');
+
 echo "var PMA_messages = new Array();\n";
 foreach ($js_messages as $name => $js_message) {
     PMA_printJsValue("PMA_messages['" . $name . "']", $js_message);
@@ -422,15 +618,12 @@ echo "var themeCalendarImage = '" . $GLOBALS['pmaThemeImage']
 /* Image path */
 echo "var pmaThemeImage = '" . $GLOBALS['pmaThemeImage'] . "';\n";
 
-/* Version */
-echo "var pmaversion = '" . PMA_VERSION . "';\n";
-
 echo "var mysql_doc_template = '" . PMA_Util::getMySQLDocuURL('%s') . "';\n";
 
 //Max input vars allowed by PHP.
 $maxInputVars = ini_get('max_input_vars');
 echo 'var maxInputVars = '
-    . (false === $maxInputVars || '' == $maxInputVars ? 'false' : $maxInputVars)
+    . (false === $maxInputVars || '' == $maxInputVars ? 'false' : (int)$maxInputVars)
     . ';' . "\n";
 
 echo "if ($.datepicker) {\n";
@@ -468,29 +661,29 @@ PMA_printJsValue(
 PMA_printJsValue(
     "$.datepicker.regional['']['monthNamesShort']",
     array(
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Jan'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Feb'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Mar'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Apr'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         _pgettext('Short month name', 'May'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Jun'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Jul'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Aug'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Sep'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Oct'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Nov'),
-/* l10n: Short month name */
+        /* l10n: Short month name */
         __('Dec')
     )
 );
@@ -509,38 +702,38 @@ PMA_printJsValue(
 PMA_printJsValue(
     "$.datepicker.regional['']['dayNamesShort']",
     array(
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Sun'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Mon'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Tue'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Wed'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Thu'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Fri'),
-/* l10n: Short week day name */
+        /* l10n: Short week day name */
         __('Sat')
     )
 );
 PMA_printJsValue(
     "$.datepicker.regional['']['dayNamesMin']",
     array(
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Su'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Mo'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Tu'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('We'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Th'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Fr'),
-/* l10n: Minimal week day name */
+        /* l10n: Minimal week day name */
         __('Sa')
     )
 );
@@ -573,3 +766,33 @@ PMA_printJsValue("$.timepicker.regional['']['secondText']", __('Second'));
 ?>
 $.extend($.timepicker._defaults, $.timepicker.regional['']);
 } /* if ($.timepicker) */
+
+<?php
+/* Form validation */
+
+echo "function extendingValidatorMessages() {\n";
+echo "$.extend($.validator.messages, {\n";
+/* Default validation functions */
+PMA_printJsValueForFormValidation('required', __('This field is required'));
+PMA_printJsValueForFormValidation('remote', __('Please fix this field'));
+PMA_printJsValueForFormValidation('email', __('Please enter a valid email address'));
+PMA_printJsValueForFormValidation('url', __('Please enter a valid URL'));
+PMA_printJsValueForFormValidation('date', __('Please enter a valid date'));
+PMA_printJsValueForFormValidation('dateISO', __('Please enter a valid date ( ISO )'));
+PMA_printJsValueForFormValidation('number', __('Please enter a valid number'));
+PMA_printJsValueForFormValidation('creditcard', __('Please enter a valid credit card number'));
+PMA_printJsValueForFormValidation('digits', __('Please enter only digits'));
+PMA_printJsValueForFormValidation('equalTo', __('Please enter the same value again'));
+PMA_printJsValueForFormValidation('maxlength', __('Please enter no more than {0} characters'), true);
+PMA_printJsValueForFormValidation('minlength', __('Please enter at least {0} characters'), true);
+PMA_printJsValueForFormValidation('rangelength', __('Please enter a value between {0} and {1} characters long'), true);
+PMA_printJsValueForFormValidation('range', __('Please enter a value between {0} and {1}'), true);
+PMA_printJsValueForFormValidation('max', __('Please enter a value less than or equal to {0}'), true);
+PMA_printJsValueForFormValidation('min', __('Please enter a value greater than or equal to {0}'), true);
+/* customed functions */
+PMA_printJsValueForFormValidation('validationFunctionForDateTime', __('Please enter a valid date or time'), true);
+PMA_printJsValueForFormValidation('validationFunctionForHex', __('Please enter a valid HEX input'), true);
+PMA_printJsValueForFormValidation('validationFunctionForFuns', __('Error'), true, false);
+echo "\n});";
+echo "\n} /* if ($.validator) */";
+?>
