@@ -68,11 +68,8 @@ function loadChildNodes(isNode, $expandElem, callback) {
                     })
                     .slideDown('slow');
             }
-            if (data._debug){
-                $('#session_debug').replaceWith(data._debug);
-            }
             if (data._errors) {
-                $errors = $(data._errors);
+                var $errors = $(data._errors);
                 if ($errors.children().length > 0) {
                     $('#pma_errors').replaceWith(data._errors);
                 }
@@ -81,12 +78,16 @@ function loadChildNodes(isNode, $expandElem, callback) {
                 callback(data);
             }
         } else if(data.redirect_flag == "1") {
-            window.location.href += '&session_expired=1';
+            if (window.location.href.indexOf('?') === -1) {
+                window.location.href += '?session_expired=1';
+            } else {
+                window.location.href += '&session_expired=1';
+            }
             window.location.reload();
         } else {
             var $throbber = $expandElem.find('img.throbber');
             $throbber.hide();
-            $icon = $expandElem.find('img.ic_b_plus');
+            var $icon = $expandElem.find('img.ic_b_plus');
             $icon.show();
             PMA_ajaxShowMessage(data.error, false);
         }
@@ -122,7 +123,7 @@ function collapseTreeNode($expandElem) {
  */
 function traverseNavigationForPaths() {
     var params = {
-        pos: $('#pma_navigation_tree div.dbselector select').val()
+        pos: $('#pma_navigation_tree').find('div.dbselector select').val()
     };
     if ($('#navi_db_select').length) {
         return params;
@@ -204,7 +205,7 @@ $(function () {
         // reload icon object
         var $icon = $(this).find('img');
         // source of the hidden throbber icon
-        var icon_throbber_src = $('#pma_navigation .throbber').attr('src');
+        var icon_throbber_src = $('#pma_navigation').find('.throbber').attr('src');
         // source of the reload icon
         var icon_reload_src = $icon.attr('src');
         // replace the source of the reload icon with the one for throbber
@@ -217,6 +218,10 @@ $(function () {
     });
 
     $(document).on("change", '#navi_db_select',  function (event) {
+        if (! $(this).val()) {
+            PMA_commonParams.set('db', '');
+            PMA_reloadNavigation();
+        }
         $(this).closest('form').trigger('submit');
     });
 
@@ -226,7 +231,7 @@ $(function () {
      */
     $(document).on('click', '#pma_navigation_collapse', function (event) {
         event.preventDefault();
-        $('#pma_navigation_tree a.expander').each(function() {
+        $('#pma_navigation_tree').find('a.expander').each(function() {
             var $icon = $(this).find('img');
             if ($icon.is('.ic_b_minus')) {
                 $(this).click();
@@ -347,13 +352,12 @@ $(function () {
         dialog.editorDialog(1, $(this));
     });
 
-    /** Execute Routines */
+    /** Edit Routines, Triggers or Events */
     $(document).on('click', 'li.procedure > a.ajax, li.function > a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
-        dialog.executeDialog($(this));
+        dialog.editorDialog(0, $(this));
     });
-    /** Edit Triggers and Events */
     $(document).on('click', 'li.trigger > a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('trigger');
@@ -365,15 +369,16 @@ $(function () {
         dialog.editorDialog(0, $(this));
     });
 
-    /** Edit Routines */
+    /** Execute Routines */
     $(document).on('click', 'li.procedure div a.ajax img,' +
         ' li.function div a.ajax img', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
-        dialog.editorDialog(0, $(this).parent());
+        dialog.executeDialog($(this).parent());
     });
     /** Export Triggers and Events */
-    $(document).on('click', 'li.trigger div:eq(1) a.ajax img, li.event div:eq(1) a.ajax img', function (event) {
+    $(document).on('click', 'li.trigger div:eq(1) a.ajax img,' +
+        ' li.event div:eq(1) a.ajax img', function (event) {
         event.preventDefault();
         var dialog = new RTE.object();
         dialog.exportDialog($(this).parent());
@@ -487,7 +492,7 @@ $(function () {
             cache: false,
             type: 'POST',
             data: {
-                favorite_tables: (isStorageSupported('localStorage'))
+                favorite_tables: (isStorageSupported('localStorage') && typeof window.localStorage.favorite_tables !== 'undefined')
                     ? window.localStorage.favorite_tables
                     : ''
             },
@@ -510,7 +515,9 @@ $(function () {
             }
         });
     });
+});
 
+AJAX.registerOnload('navigation.js', function () {
     // Check if session storage is supported
     if (isStorageSupported('sessionStorage')) {
         var storage = window.sessionStorage;
@@ -519,8 +526,8 @@ $(function () {
             storage.removeItem('navTreePaths');
         });
         // Initialize if no previous state is defined
-        if ($('#pma_navigation_tree_content').length
-            && typeof storage.navTreePaths === 'undefined'
+        if ($('#pma_navigation_tree_content').length &&
+            typeof storage.navTreePaths === 'undefined'
         ) {
             navTreeStateUpdate();
         } else if (PMA_commonParams.get('server') === storage.server &&
@@ -578,7 +585,7 @@ function expandTreeNode($expandElem, callback) {
         }
         $children.promise().done(navTreeStateUpdate);
     } else {
-        var $throbber = $('#pma_navigation .throbber')
+        var $throbber = $('#pma_navigation').find('.throbber')
             .first()
             .clone()
             .css({visibility: 'visible', display: 'block'})
@@ -648,9 +655,27 @@ function PMA_showCurrentNavigation() {
         .removeClass('selected');
     if (db) {
         var $dbItem = findLoadedItem(
-            $('#pma_navigation_tree > div'), db, 'database', !table
+            $('#pma_navigation_tree').find('> div'), db, 'database', !table
         );
-        if ($dbItem) {
+        if ($('#navi_db_select').length &&
+            $('option:selected', $('#navi_db_select')).length
+        ) {
+            if (! PMA_selectCurrentDb()) {
+                return;
+            }
+            // If loaded database in navigation is not same as current one
+            if ($('#pma_navigation_tree_content').find('span.loaded_db:first').text()
+                !== $('#navi_db_select').val()
+            ) {
+                loadChildNodes(false, $('option:selected', $('#navi_db_select')), function (data) {
+                    handleTableOrDb(table, $('#pma_navigation_tree_content'));
+                    var $children = $('#pma_navigation_tree_content').children('div.list_container');
+                    $children.promise().done(navTreeStateUpdate);
+                });
+            } else {
+                handleTableOrDb(table, $('#pma_navigation_tree_content'));
+            }
+        } else if ($dbItem) {
             var $expander = $dbItem.children('div:first').children('a.expander');
             // if not loaded or loaded but collapsed
             if (! $expander.hasClass('loaded') ||
@@ -662,25 +687,9 @@ function PMA_showCurrentNavigation() {
             } else {
                 handleTableOrDb(table, $dbItem);
             }
-        } else if ($('#navi_db_select').length
-                && $('option:selected', $('#navi_db_select')).length
-        ) {
-            if (! PMA_selectCurrentDb()) {
-                return;
-            }
-            // If loaded database in navigation is not same as current one
-            if ( $('#pma_navigation_tree_content span.loaded_db:first').text()
-                !== $('#navi_db_select').val()
-            ) {
-                loadChildNodes(false, $('option:selected', $('#navi_db_select')), function (data) {
-                    handleTableOrDb(table, $('#pma_navigation_tree_content'));
-                    var $children = $('#pma_navigation_tree_content').children('div.list_container');
-                    $children.promise().done(navTreeStateUpdate);
-                });
-            } else {
-                handleTableOrDb(table, $('#pma_navigation_tree_content'));
-            }
         }
+    } else if ($('#navi_db_select').length && $('#navi_db_select').val()) {
+        $('#navi_db_select').val('').hide().trigger('change');
     }
     PMA_showFullName($('#pma_navigation_tree'));
 
@@ -725,7 +734,7 @@ function PMA_showCurrentNavigation() {
                     }
                     // taverse up and expand and parent navigation groups
                     $li.parents('.navGroup').each(function () {
-                        $cont = $(this).children('div.list_container');
+                        var $cont = $(this).children('div.list_container');
                         if (! $cont.is(':visible')) {
                             $(this)
                                 .children('div:first')
@@ -769,7 +778,7 @@ function PMA_showCurrentNavigation() {
                         .children('div:first')
                         .children('a.expander');
                     if (! $expander.hasClass('loaded')) {
-                    	loadAndShowTableOrView($expander, $containers[index], itemName);
+                        loadAndShowTableOrView($expander, $containers[index], itemName);
                     }
                 });
             // else if no subContainers
@@ -778,7 +787,7 @@ function PMA_showCurrentNavigation() {
                     .children('div:first')
                     .children('a.expander');
                 if (! $expander.hasClass('loaded')) {
-                	loadAndShowTableOrView($expander, $dbItem, itemName);
+                    loadAndShowTableOrView($expander, $dbItem, itemName);
                 }
             }
         }
@@ -819,6 +828,46 @@ function PMA_showCurrentNavigation() {
     }
 }
 
+/**
+ * Disable navigation panel settings
+ *
+ * @return void
+ */
+function PMA_disableNaviSettings() {
+    $('#pma_navigation_settings_icon').addClass('hide');
+    $('#pma_navigation_settings').remove();
+}
+
+/**
+ * Ensure that navigation panel settings is properly setup.
+ * If not, set it up
+ *
+ * @return void
+ */
+function PMA_ensureNaviSettings(selflink) {
+    $('#pma_navigation_settings_icon').removeClass('hide');
+
+    if (!$('#pma_navigation_settings').length) {
+        var params = {
+            getNaviSettings: true
+        };
+        var url = $('#pma_navigation').find('a.navigation_url').attr('href');
+        $.post(url, params, function (data) {
+            if (typeof data !== 'undefined' && data.success) {
+                $('#pma_navi_settings_container').html(data.message);
+                setupRestoreField();
+                setupValidation();
+                setupConfigTabs();
+                $('#pma_navigation_settings').find('form').attr('action', selflink);
+            } else {
+                PMA_ajaxShowMessage(data.error);
+            }
+        });
+    } else {
+        $('#pma_navigation_settings').find('form').attr('action', selflink);
+    }
+}
+
 /**
  * Reloads the whole navigation tree while preserving its state
  *
@@ -829,7 +878,8 @@ function PMA_showCurrentNavigation() {
  */
 function PMA_reloadNavigation(callback, paths) {
     var params = {
-        reload: true
+        reload: true,
+        no_debug: true
     };
     paths = paths || traverseNavigationForPaths();
     $.extend(params, paths);
@@ -862,13 +912,19 @@ function PMA_reloadNavigation(callback, paths) {
 }
 
 function PMA_selectCurrentDb() {
-    if ($('#navi_db_select').length) {
-        $('#navi_db_select').val(PMA_commonParams.get('db'));
-        if ($('#navi_db_select').val() !== PMA_commonParams.get('db')) {
-            return false;
-        }
-        return true;
+    var $naviDbSelect = $('#navi_db_select');
+
+    if (!$naviDbSelect.length) {
+        return false;
     }
+
+    if (PMA_commonParams.get('db')) { // db selected
+        $naviDbSelect.show();
+    }
+
+    $naviDbSelect.val(PMA_commonParams.get('db'));
+    return $naviDbSelect.val() === PMA_commonParams.get('db');
+
 }
 
 /**
@@ -905,8 +961,8 @@ function PMA_navigationTreePagination($this) {
         }
     }
     $.post(url, params, function (data) {
-        PMA_ajaxRemoveMessage($msgbox);
         if (typeof data !== 'undefined' && data.success) {
+            PMA_ajaxRemoveMessage($msgbox);
             if (isDbSelector) {
                 var val = PMA_fastFilter.getSearchClause();
                 $('#pma_navigation_tree')
@@ -936,6 +992,7 @@ function PMA_navigationTreePagination($this) {
             }
         } else {
             PMA_ajaxShowMessage(data.error);
+            PMA_handleRedirectAndReload(data);
         }
         navTreeStateUpdate();
     });
