@@ -16,13 +16,6 @@ AJAX.registerTeardown('server_status_variables.js', function () {
 });
 
 AJAX.registerOnload('server_status_variables.js', function () {
-    /*** Table sort tooltip ***/
-    PMA_tooltip(
-        $('table.sortable>thead>tr:first').find('th'),
-        'th',
-        PMA_messages.strSortHint
-    );
-    initTableSorter('statustabs_allvars');
 
     // Filters for status variables
     var textFilter = null;
@@ -45,8 +38,8 @@ AJAX.registerOnload('server_status_variables.js', function () {
     $('#dontFormat').change(function () {
         // Hiding the table while changing values speeds up the process a lot
         $('#serverstatusvariables').hide();
-        $('#serverstatusvariables td.value span.original').toggle(this.checked);
-        $('#serverstatusvariables td.value span.formatted').toggle(! this.checked);
+        $('#serverstatusvariables').find('td.value span.original').toggle(this.checked);
+        $('#serverstatusvariables').find('td.value span.formatted').toggle(! this.checked);
         $('#serverstatusvariables').show();
     }).trigger('change');
 
@@ -55,7 +48,15 @@ AJAX.registerOnload('server_status_variables.js', function () {
         if (word.length === 0) {
             textFilter = null;
         } else {
-            textFilter = new RegExp("(^| )" + word, 'i');
+            try {
+                textFilter = new RegExp("(^| )" + word, 'i');
+                $(this).removeClass('error');
+            } catch(e) {
+                if (e instanceof SyntaxError) {
+                    $(this).addClass('error');
+                    textFilter = null;
+                }
+            }
         }
         text = word;
         filterVariables();
@@ -71,7 +72,7 @@ AJAX.registerOnload('server_status_variables.js', function () {
         }
 
         if (section.length > 1) {
-            $('#linkSuggestions span').each(function () {
+            $('#linkSuggestions').find('span').each(function () {
                 if ($(this).attr('class').indexOf('status_' + section) != -1) {
                     useful_links++;
                     $(this).css('display', '');
@@ -88,7 +89,7 @@ AJAX.registerOnload('server_status_variables.js', function () {
         }
 
         odd_row = false;
-        $('#serverstatusvariables th.name').each(function () {
+        $('#serverstatusvariables').find('th.name').each(function () {
             if ((textFilter === null || textFilter.exec($(this).text())) &&
                 (! alertFilter || $(this).next().find('span.attention').length > 0) &&
                 (categoryFilter.length === 0 || $(this).parent().hasClass('s_' + categoryFilter))
