@@ -4,9 +4,8 @@
  * Unbind all event handlers before tearing down a page
  */
 AJAX.registerTeardown('server_variables.js', function () {
-    $('#serverVariables .var-row').unbind('hover');
     $('#filterText').unbind('keyup');
-    $('a.editLink').die('click');
+    $(document).off('click', 'a.editLink');
     $('#serverVariables').find('.var-name').find('a img').remove();
 });
 
@@ -16,23 +15,13 @@ AJAX.registerOnload('server_variables.js', function () {
     var $cancelLink = $('a.cancelLink');
     var $filterField = $('#filterText');
 
-    /* Show edit link on hover */
-    $('#serverVariables').delegate('.var-row', 'hover', function (event) {
-        if (event.type === 'mouseenter') {
-            var $elm = $(this).find('.var-value');
-            // Only add edit element if the element is not being edited
-            if ($elm.hasClass('editable') && ! $elm.hasClass('edit')) {
-                $elm.prepend($editLink.clone().show());
-            }
-        } else {
-            $(this).find('a.editLink').remove();
-        }
-    }).find('.var-name').find('a').append(
+
+    $('#serverVariables').find('.var-name').find('a').append(
         $('#docImage').clone().show()
     );
 
     /* Launches the variable editor */
-    $editLink.live('click', function (event) {
+    $(document).on('click', 'a.editLink', function (event) {
         event.preventDefault();
         editVariable(this);
     });
@@ -41,7 +30,15 @@ AJAX.registerOnload('server_variables.js', function () {
     $filterField.keyup(function () {
         var textFilter = null, val = $(this).val();
         if (val.length !== 0) {
-            textFilter = new RegExp("(^| )" + val.replace(/_/g, ' '), 'i');
+            try {
+                textFilter = new RegExp("(^| )" + val.replace(/_/g, ' '), 'i');
+                $(this).removeClass('error');
+            } catch(e) {
+                if (e instanceof SyntaxError) {
+                    $(this).addClass('error');
+                    textFilter = null;
+                }
+            }
         }
         filterVariables(textFilter);
     });
@@ -54,7 +51,7 @@ AJAX.registerOnload('server_variables.js', function () {
     /* Filters the rows by the user given regexp */
     function filterVariables(textFilter) {
         var mark_next = false, $row, odd_row = false;
-        $('#serverVariables .var-row').not('.var-header').each(function () {
+        $('#serverVariables').find('.var-row').not('.var-header').each(function () {
             $row = $(this);
             if (mark_next || textFilter === null ||
                 textFilter.exec($row.find('.var-name').text())
@@ -79,15 +76,15 @@ AJAX.registerOnload('server_variables.js', function () {
     /* Allows the user to edit a server variable */
     function editVariable(link) {
         var $cell = $(link).parent();
+        var $valueCell = $(link).parents('.var-row').find('.var-value');
         var varName = $cell.parent().find('.var-name').text().replace(/ /g, '_');
         var $mySaveLink = $saveLink.clone().show();
         var $myCancelLink = $cancelLink.clone().show();
         var $msgbox = PMA_ajaxShowMessage();
+        var $myEditLink = $cell.find('a.editLink');
 
-        $cell
-            .addClass('edit') // variable is being edited
-            .find('a.editLink')
-            .remove(); // remove edit link
+        $cell.addClass('edit'); // variable is being edited
+        $myEditLink.remove(); // remove edit link
 
         $mySaveLink.click(function () {
             var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
@@ -95,26 +92,25 @@ AJAX.registerOnload('server_variables.js', function () {
                     ajax_request: true,
                     type: 'setval',
                     varName: varName,
-                    varValue: $cell.find('input').val()
+                    varValue: $valueCell.find('input').val()
                 }, function (data) {
                     if (data.success) {
-                        $cell
+                        $valueCell
                             .html(data.variable)
                             .data('content', data.variable);
                         PMA_ajaxRemoveMessage($msgbox);
                     } else {
                         PMA_ajaxShowMessage(data.error, false);
-                        $cell.html($cell.data('content'));
+                        $valueCell.html($valueCell.data('content'));
                     }
-                    $cell.removeClass('edit');
+                    $cell.removeClass('edit').html($myEditLink);
                 });
             return false;
         });
 
         $myCancelLink.click(function () {
-            $cell
-                .html($cell.data('content'))
-                .removeClass('edit');
+            $valueCell.html($valueCell.data('content'));
+            $cell.removeClass('edit').html($myEditLink);
             return false;
         });
 
@@ -124,11 +120,11 @@ AJAX.registerOnload('server_variables.js', function () {
                 varName: varName
             }, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
-                    var $editor = $('<div />', {'class': 'serverVariableEditor'})
+                    var $links = $('<div />')
                         .append($myCancelLink)
-                        .append(' ')
-                        .append($mySaveLink)
-                        .append(' ')
+                        .append('&nbsp;&nbsp;&nbsp;')
+                        .append($mySaveLink);
+                    var $editor = $('<div />', {'class': 'serverVariableEditor'})
                         .append(
                             $('<div/>').append(
                                 $('<input />', {type: 'text'}).val(data.message)
@@ -136,7 +132,9 @@ AJAX.registerOnload('server_variables.js', function () {
                         );
                     // Save and replace content
                     $cell
-                    .data('content', $cell.html())
+                    .html($links);
+                    $valueCell
+                    .data('content', $valueCell.html())
                     .html($editor)
                     .find('input')
                     .focus()
@@ -149,7 +147,7 @@ AJAX.registerOnload('server_variables.js', function () {
                     });
                     PMA_ajaxRemoveMessage($msgbox);
                 } else {
-                    $cell.removeClass('edit');
+                    $cell.removeClass('edit').html($myEditLink);
                     PMA_ajaxShowMessage(data.error);
                 }
             });
