@@ -22,10 +22,18 @@ require_once './libraries/common.inc.php';
 // Close session early as we won't write anything there
 session_write_close();
 
+require_once './libraries/OutputBuffering.class.php';
+$buffer = PMA_OutputBuffering::getInstance();
+$buffer->start();
+register_shutdown_function(
+    function () {
+        echo PMA_OutputBuffering::getInstance()->getContents();
+    }
+);
+
 echo "var PMA_gotoWhitelist = new Array();\n";
 $i = -1;
 foreach ($GLOBALS['goto_whitelist'] as $one_whitelist) {
     $i++;
     echo 'PMA_gotoWhitelist[' . $i . ']="' . $one_whitelist . '";' . "\n";
 }
-?>
