@@ -20,7 +20,7 @@ class PMA_Menu
      * Server id
      *
      * @access private
-     * @var string
+     * @var int
      */
     private $_server;
     /**
@@ -95,15 +95,13 @@ class PMA_Menu
      */
     private function _getMenu()
     {
-        $tabs = array();
         $url_params = array('db' => $this->_db);
-        $level = '';
 
-        if (strlen($this->_table)) {
+        if (/*overload*/mb_strlen($this->_table)) {
             $tabs = $this->_getTableTabs();
             $url_params['table'] = $this->_table;
             $level = 'table';
-        } else if (strlen($this->_db)) {
+        } else if (/*overload*/mb_strlen($this->_db)) {
             $tabs = $this->_getDbTabs();
             $level = 'db';
         } else {
@@ -132,11 +130,11 @@ class PMA_Menu
         $allowedTabs = PMA_Util::getMenuTabList($level);
         $cfgRelation = PMA_getRelationsParam();
         if ($cfgRelation['menuswork']) {
-            $groupTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
+            $groupTable = PMA_Util::backquote($cfgRelation['db'])
                 . "."
-                . PMA_Util::backquote($GLOBALS['cfg']['Server']['usergroups']);
-            $userTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
-                . "." . PMA_Util::backquote($GLOBALS['cfg']['Server']['users']);
+                . PMA_Util::backquote($cfgRelation['usergroups']);
+            $userTable = PMA_Util::backquote($cfgRelation['db'])
+                . "." . PMA_Util::backquote($cfgRelation['users']);
 
             $sql_query = "SELECT `tab` FROM " . $groupTable
                 . " WHERE `allowed` = 'N'"
@@ -148,7 +146,10 @@ class PMA_Menu
             $result = PMA_queryAsControlUser($sql_query, false);
             if ($result) {
                 while ($row = $GLOBALS['dbi']->fetchAssoc($result)) {
-                    $tabName = substr($row['tab'], strpos($row['tab'], '_') + 1);
+                    $tabName = /*overload*/mb_substr(
+                        $row['tab'],
+                        /*overload*/mb_strpos($row['tab'], '_') + 1
+                    );
                     unset($allowedTabs[$tabName]);
                 }
             }
@@ -164,7 +165,11 @@ class PMA_Menu
     private function _getBreadcrumbs()
     {
         $retval = '';
-        $tbl_is_view = PMA_Table::isView($this->_db, $this->_table);
+        $tbl_is_view = $GLOBALS['dbi']->getTable($this->_db, $this->_table)
+            ->isView();
+        if (empty($GLOBALS['cfg']['Server']['host'])) {
+            $GLOBALS['cfg']['Server']['host'] = '';
+        }
         $server_info = ! empty($GLOBALS['cfg']['Server']['verbose'])
             ? $GLOBALS['cfg']['Server']['verbose']
             : $GLOBALS['cfg']['Server']['host'];
@@ -173,8 +178,7 @@ class PMA_Menu
             : ':' . $GLOBALS['cfg']['Server']['port'];
 
         $separator = "<span class='separator item'>&nbsp;»</span>";
-        $item = '<a href="%1$s?%2$s" class="item">';
-
+        $item = '<a href="%1$s%2$s" class="item">';
 
         if (PMA_Util::showText('TabsMode')) {
             $item .= '%4$s: ';
@@ -191,13 +195,15 @@ class PMA_Menu
         }
         $retval .= sprintf(
             $item,
-            $GLOBALS['cfg']['DefaultTabServer'],
+            PMA_Util::getScriptNameForOption(
+                $GLOBALS['cfg']['DefaultTabServer'], 'server'
+            ),
             PMA_URL_getCommon(),
             htmlspecialchars($server_info),
             __('Server')
         );
 
-        if (strlen($this->_db)) {
+        if (/*overload*/mb_strlen($this->_db)) {
             $retval .= $separator;
             if (PMA_Util::showIcons('TabsMode')) {
                 $retval .= PMA_Util::getImage(
@@ -208,14 +214,16 @@ class PMA_Menu
             }
             $retval .= sprintf(
                 $item,
-                $GLOBALS['cfg']['DefaultTabDatabase'],
-                PMA_URL_getCommon($this->_db),
+                PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+                ),
+                PMA_URL_getCommon(array('db' => $this->_db)),
                 htmlspecialchars($this->_db),
                 __('Database')
             );
             // if the table is being dropped, $_REQUEST['purge'] is set to '1'
             // so do not display the table name in upper div
-            if (strlen($this->_table)
+            if (/*overload*/mb_strlen($this->_table)
                 && ! (isset($_REQUEST['purge']) && $_REQUEST['purge'] == '1')
             ) {
                 include './libraries/tbl_info.inc.php';
@@ -231,8 +239,14 @@ class PMA_Menu
                 }
                 $retval .= sprintf(
                     $item,
-                    $GLOBALS['cfg']['DefaultTabTable'],
-                    PMA_URL_getCommon($this->_db, $this->_table),
+                    PMA_Util::getScriptNameForOption(
+                        $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                    ),
+                    PMA_URL_getCommon(
+                        array(
+                            'db' => $this->_db, 'table' => $this->_table
+                        )
+                    ),
                     str_replace(' ', '&nbsp;', htmlspecialchars($this->_table)),
                     $tbl_is_view ? __('View') : __('Table')
                 );
@@ -243,7 +257,7 @@ class PMA_Menu
                 if (! empty($show_comment)
                     && ! isset($GLOBALS['avoid_show_comment'])
                 ) {
-                    if (strstr($show_comment, '; InnoDB free')) {
+                    if (/*overload*/mb_strstr($show_comment, '; InnoDB free')) {
                         $show_comment = preg_replace(
                             '@; InnoDB free:.*?$@',
                             '',
@@ -260,7 +274,7 @@ class PMA_Menu
                 $cfgRelation = PMA_getRelationsParam();
 
                 // Get additional information about tables for tooltip is done
-                // in libraries/db_info.inc.php only once
+                // in PMA_Util::getDbInfo() only once
                 if ($cfgRelation['commwork']) {
                     $comment = PMA_getDbComment($this->_db);
                     /**
@@ -288,8 +302,11 @@ class PMA_Menu
     private function _getTableTabs()
     {
         $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
-        $tbl_is_view = PMA_Table::isView($this->_db, $this->_table);
+        $tbl_is_view = $GLOBALS['dbi']->getTable($this->_db, $this->_table)
+            ->isView();
         $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
 
         $tabs = array();
 
@@ -301,6 +318,10 @@ class PMA_Menu
         $tabs['structure']['icon'] = 'b_props.png';
         $tabs['structure']['link'] = 'tbl_structure.php';
         $tabs['structure']['text'] = __('Structure');
+        $tabs['structure']['active'] = in_array(
+            basename($GLOBALS['PMA_PHP_SELF']),
+            array('tbl_structure.php', 'tbl_relation.php')
+        );
 
         $tabs['sql']['icon'] = 'b_sql.png';
         $tabs['sql']['link'] = 'tbl_sql.php';
@@ -333,7 +354,9 @@ class PMA_Menu
             $tabs['import']['link'] = 'tbl_import.php';
             $tabs['import']['text'] = __('Import');
         }
-        if ($is_superuser && ! PMA_DRIZZLE && ! $db_is_system_schema) {
+        if (($is_superuser || $isCreateOrGrantUser)
+            && ! PMA_DRIZZLE && ! $db_is_system_schema
+        ) {
             $tabs['privileges']['link'] = 'server_privileges.php';
             $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
             $tabs['privileges']['args']['checkprivstable'] = $this->_table;
@@ -350,6 +373,15 @@ class PMA_Menu
             $tabs['operation']['link'] = 'tbl_operations.php';
             $tabs['operation']['text'] = __('Operations');
         }
+        /**
+         * Views support a limited number of operations
+         */
+        if ($tbl_is_view && ! $db_is_system_schema) {
+            $tabs['operation']['icon'] = 'b_tblops.png';
+            $tabs['operation']['link'] = 'view_operations.php';
+            $tabs['operation']['text'] = __('Operations');
+        }
+
         if (PMA_Tracker::isActive()) {
             $tabs['tracking']['icon'] = 'eye.png';
             $tabs['tracking']['text'] = __('Tracking');
@@ -369,15 +401,6 @@ class PMA_Menu
             $tabs['triggers']['icon'] = 'b_triggers.png';
         }
 
-        /**
-         * Views support a limited number of operations
-         */
-        if ($tbl_is_view && ! $db_is_system_schema) {
-            $tabs['operation']['icon'] = 'b_tblops.png';
-            $tabs['operation']['link'] = 'view_operations.php';
-            $tabs['operation']['text'] = __('Operations');
-        }
-
         return $tabs;
     }
 
@@ -391,6 +414,8 @@ class PMA_Menu
         $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
         $num_tables = count($GLOBALS['dbi']->getTables($this->_db));
         $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
 
         /**
          * Gets the relation settings
@@ -437,7 +462,7 @@ class PMA_Menu
             $tabs['operation']['text'] = __('Operations');
             $tabs['operation']['icon'] = 'b_tblops.png';
 
-            if ($is_superuser && ! PMA_DRIZZLE) {
+            if (($is_superuser || $isCreateOrGrantUser) && ! PMA_DRIZZLE) {
                 $tabs['privileges']['link'] = 'server_privileges.php';
                 $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
                 // stay on database view
@@ -450,8 +475,7 @@ class PMA_Menu
                 $tabs['routines']['text'] = __('Routines');
                 $tabs['routines']['icon'] = 'b_routines.png';
             }
-            if (PMA_MYSQL_INT_VERSION >= 50106
-                && ! PMA_DRIZZLE
+            if (! PMA_DRIZZLE
                 && PMA_Util::currentUserHasPrivilege('EVENT', $this->_db)
             ) {
                 $tabs['events']['link'] = 'db_events.php';
@@ -473,12 +497,20 @@ class PMA_Menu
             $tabs['tracking']['link'] = 'db_tracking.php';
         }
 
-        if (! $db_is_system_schema && $cfgRelation['designerwork']) {
+        if (! $db_is_system_schema) {
             $tabs['designer']['text'] = __('Designer');
             $tabs['designer']['icon'] = 'b_relations.png';
-            $tabs['designer']['link'] = 'pmd_general.php';
+            $tabs['designer']['link'] = 'db_designer.php';
+            $tabs['designer']['id'] = 'designer_tab';
         }
 
+        if (! $db_is_system_schema
+            && $cfgRelation['centralcolumnswork']
+        ) {
+            $tabs['central_columns']['text'] = __('Central columns');
+            $tabs['central_columns']['icon'] = 'centralColumns.png';
+            $tabs['central_columns']['link'] = 'db_central_columns.php';
+        }
         return $tabs;
     }
 
@@ -489,18 +521,23 @@ class PMA_Menu
      */
     private function _getServerTabs()
     {
-        $is_superuser = isset($GLOBALS['dbi']) && $GLOBALS['dbi']->isSuperuser();
+        $is_superuser = $GLOBALS['dbi']->isSuperuser();
+        $isCreateOrGrantUser = $GLOBALS['dbi']->isUserType('grant')
+            || $GLOBALS['dbi']->isUserType('create');
         $binary_logs = null;
-        $notDrizzle = ! defined('PMA_DRIZZLE')
-            || (defined('PMA_DRIZZLE') && ! PMA_DRIZZLE);
-        if (isset($GLOBALS['dbi']) && $notDrizzle) {
-            $binary_logs = $GLOBALS['dbi']->fetchResult(
-                'SHOW MASTER LOGS',
-                'Log_name',
-                null,
-                null,
-                PMA_DatabaseInterface::QUERY_STORE
-            );
+        if (! defined('PMA_DRIZZLE') || ! PMA_DRIZZLE) {
+            if (PMA_Util::cacheExists('binary_logs')) {
+                $binary_logs = PMA_Util::cacheGet('binary_logs');
+            } else {
+                $binary_logs = $GLOBALS['dbi']->fetchResult(
+                    'SHOW MASTER LOGS',
+                    'Log_name',
+                    null,
+                    null,
+                    PMA_DatabaseInterface::QUERY_STORE
+                );
+                PMA_Util::cacheSet('binary_logs', $binary_logs);
+            }
         }
 
         $tabs = array();
@@ -523,14 +560,15 @@ class PMA_Menu
                 'server_status_advisor.php',
                 'server_status_monitor.php',
                 'server_status_queries.php',
-                'server_status_variables.php'
+                'server_status_variables.php',
+                'server_status_processes.php'
             )
         );
 
-        if ($is_superuser && ! PMA_DRIZZLE) {
+        if (($is_superuser || $isCreateOrGrantUser) && ! PMA_DRIZZLE) {
             $tabs['rights']['icon'] = 's_rights.png';
             $tabs['rights']['link'] = 'server_privileges.php';
-            $tabs['rights']['text'] = __('Users');
+            $tabs['rights']['text'] = __('User accounts');
             $tabs['rights']['active'] = in_array(
                 basename($GLOBALS['PMA_PHP_SELF']),
                 array('server_privileges.php', 'server_user_groups.php')
@@ -578,6 +616,13 @@ class PMA_Menu
             $tabs['plugins']['icon'] = 'b_engine.png';
             $tabs['plugins']['link'] = 'server_plugins.php';
             $tabs['plugins']['text'] = __('Plugins');
+            $tabs['plugins']['active'] = in_array(
+                basename($GLOBALS['PMA_PHP_SELF']),
+                array(
+                    'server_plugins.php',
+                    'server_modules.php',
+                )
+            );
         } else {
             $tabs['engine']['icon'] = 'b_engine.png';
             $tabs['engine']['link'] = 'server_engines.php';
@@ -585,6 +630,18 @@ class PMA_Menu
         }
         return $tabs;
     }
+
+    /**
+     * Set current table
+     *
+     * @param string $table Current table
+     *
+     * @return $this
+     */
+    public function setTable($table)
+    {
+        $this->_table = $table;
+        return $this;
+    }
 }
 
-?>
