@@ -29,8 +29,8 @@ function PMA_Bookmark_getParams()
     if ($cfgRelation['bookmarkwork']) {
         $cfgBookmark = array(
             'user'  => $GLOBALS['cfg']['Server']['user'],
-            'db'    => $GLOBALS['cfg']['Server']['pmadb'],
-            'table' => $GLOBALS['cfg']['Server']['bookmarktable'],
+            'db'    => $cfgRelation['db'],
+            'table' => $cfgRelation['bookmark'],
         );
     } else {
         $cfgBookmark = false;
@@ -43,15 +43,18 @@ function PMA_Bookmark_getParams()
 /**
  * Gets the list of bookmarks defined for the current database
  *
- * @param string $db the current database name
+ * @param string|bool $db the current database name or false
  *
- * @return array the bookmarks list (key as index, label as value)
+ * @return array the bookmarks list (key as index, label as value),
+ *               or if param is empty, function will give more information,
+ *               array will be unindexed,
+ *               each struct: [db, id, label, shared, query]
  *
  * @access public
  *
  * @global resource $controllink the controluser db connection handle
  */
-function PMA_Bookmark_getList($db)
+function PMA_Bookmark_getList($db = false)
 {
     global $controllink;
 
@@ -61,32 +64,51 @@ function PMA_Bookmark_getList($db)
         return array();
     }
 
-    $query  = 'SELECT label, id FROM ' . PMA_Util::backquote($cfgBookmark['db'])
-        . '.' . PMA_Util::backquote($cfgBookmark['table'])
+    if ($db !== false) {
+        $query = 'SELECT query, label, id FROM ' . PMA_Util::backquote(
+            $cfgBookmark['db']
+        ) . '.' . PMA_Util::backquote($cfgBookmark['table'])
         . ' WHERE dbase = \'' . PMA_Util::sqlAddSlashes($db) . '\''
         . ' AND user = \'' . PMA_Util::sqlAddSlashes($cfgBookmark['user']) . '\''
         . ' ORDER BY label';
-    $per_user = $GLOBALS['dbi']->fetchResult(
-        $query, 'id', 'label', $controllink, PMA_DatabaseInterface::QUERY_STORE
-    );
+        $per_user = $GLOBALS['dbi']->fetchResult(
+            $query, 'id', null, $controllink, PMA_DatabaseInterface::QUERY_STORE
+        );
 
-    $query  = 'SELECT label, id FROM ' . PMA_Util::backquote($cfgBookmark['db'])
-        . '.' . PMA_Util::backquote($cfgBookmark['table'])
+        $query = 'SELECT query, label, id FROM ' . PMA_Util::backquote(
+            $cfgBookmark['db']
+        ) . '.' . PMA_Util::backquote($cfgBookmark['table'])
         . ' WHERE dbase = \'' . PMA_Util::sqlAddSlashes($db) . '\''
         . ' AND user = \'\''
         . ' ORDER BY label';
-    $global = $GLOBALS['dbi']->fetchResult(
-        $query, 'id', 'label', $controllink, PMA_DatabaseInterface::QUERY_STORE
-    );
+        $global = $GLOBALS['dbi']->fetchResult(
+            $query, 'id', null, $controllink, PMA_DatabaseInterface::QUERY_STORE
+        );
 
-    foreach ($global as $key => $val) {
-        $global[$key] = $val . ' (' . __('shared') . ')';
+        foreach ($global as $key => $val) {
+            $global[$key]['label'] = $val['label'] . ' (' . __('shared') . ')';
+        }
+
+        $ret = $global + $per_user;
+
+        asort($ret);
+    } else {
+        $query = "SELECT `label`, `id`, `query`, `dbase` AS `db`,"
+            . " IF (`user` = '', true, false) AS `shared`"
+            . " FROM " . PMA_Util::backquote($cfgBookmark['db'])
+            . "." . PMA_Util::backquote($cfgBookmark['table'])
+            . " WHERE `user` = '' OR"
+            . " `user` = '" . PMA_Util::sqlAddSlashes($cfgBookmark['user'])  . "'";
+
+        $ret = $GLOBALS['dbi']->fetchResult(
+            $query,
+            null,
+            null,
+            $controllink,
+            PMA_DatabaseInterface::QUERY_STORE
+        );
     }
 
-    $ret = $global + $per_user;
-
-    asort($ret);
-
     return $ret;
 } // end of the 'PMA_Bookmark_getList()' function
 
@@ -156,7 +178,10 @@ function PMA_Bookmark_save($bkm_fields, $all_users = false)
 
     $cfgBookmark = PMA_Bookmark_getParams();
 
-    if (empty($cfgBookmark)) {
+    if (!(isset($bkm_fields['bkm_sql_query']) && isset($bkm_fields['bkm_label'])
+        && /*overload*/mb_strlen($bkm_fields['bkm_sql_query']) > 0
+        && /*overload*/mb_strlen($bkm_fields['bkm_label']) > 0)
+    ) {
         return false;
     }
 
@@ -205,11 +230,47 @@ function PMA_Bookmark_delete($id)
     return $GLOBALS['dbi']->tryQuery($query, $controllink);
 } // end of the 'PMA_Bookmark_delete()' function
 
+/**
+ * Returns the number of variables in a bookmark
+ *
+ * @param string $query bookmarked query
+ *
+ * @return number number of variables
+ */
+function PMA_Bookmark_getVariableCount($query)
+{
+    $matches = array();
+    preg_match_all("/\[VARIABLE[0-9]*\]/", $query, $matches, PREG_SET_ORDER);
+    return count($matches);
+}
 
 /**
- * Bookmark Support
+ * Replace the placeholders in the bookmark query with variables
+ *
+ * @param string $query bookmarked query
+ *
+ * @return string query with variables applied
  */
-if (!defined('TESTSUITE')) {
-    $GLOBALS['cfg']['Bookmark'] = PMA_Bookmark_getParams();
+function PMA_Bookmark_applyVariables($query)
+{
+    // remove comments that encloses a variable placeholder
+    $query = preg_replace(
+        '|/\*(.*\[VARIABLE[0-9]*\].*)\*/|imsU',
+        '${1}',
+        $query
+    );
+    // replace variable placeholders with values
+    $number_of_variables = PMA_Bookmark_getVariableCount($query);
+    for ($i = 1; $i <= $number_of_variables; $i++) {
+        $var = '';
+        if (! empty($_REQUEST['bookmark_variable'][$i])) {
+            $var = PMA_Util::sqlAddSlashes($_REQUEST['bookmark_variable'][$i]);
+        }
+        $query = str_replace('[VARIABLE' . $i . ']', $var, $query);
+        // backward compatibility
+        if ($i == 1) {
+            $query = str_replace('[VARIABLE]', $var, $query);
+        }
+    }
+    return $query;
 }
-?>
