@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 
 /**
- * HTML geneartor for database listing
+ * HTML generator for database listing
  *
  * @package PhpMyAdmin
  */
@@ -49,11 +49,9 @@ function PMA_getColumnOrder()
         'format'    => 'byte',
         'footer'    => 0,
     );
-    $column_order['SCHEMA_DATA_FREE'] = array(
-        'disp_name' => __('Overhead'),
-        'format'    => 'byte',
-        'footer'    => 0,
-    );
+    // At this point we were preparing the display of Overhead using DATA_FREE
+    // but its content does not represent the real overhead in the case
+    // of InnoDB
 
     return $column_order;
 }
@@ -89,8 +87,10 @@ function PMA_buildHtmlForDb(
         $out .= ' /></td>';
     }
     $out .= '<td class="name">'
-           . '<a href="' . $GLOBALS['cfg']['DefaultTabDatabase']
-           . '?' . $url_query . '&amp;db='
+           . '<a href="' . PMA_Util::getScriptNameForOption(
+               $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+           )
+           . $url_query . '&amp;db='
            . urlencode($current['SCHEMA_NAME']) . '" title="'
            . sprintf(
                __('Jump to database'),
@@ -103,6 +103,7 @@ function PMA_buildHtmlForDb(
 
     foreach ($column_order as $stat_name => $stat) {
         if (array_key_exists($stat_name, $current)) {
+            $unit = '';
             if (is_numeric($stat['footer'])) {
                 $column_order[$stat_name]['footer'] += $current[$stat_name];
             }
@@ -132,6 +133,7 @@ function PMA_buildHtmlForDb(
             }
         }
     }
+
     foreach ($replication_types as $type) {
         if ($replication_info[$type]['status']) {
             $out .= '<td class="tool" style="text-align: center;">';
@@ -140,15 +142,16 @@ function PMA_buildHtmlForDb(
                 $current["SCHEMA_NAME"],
                 $replication_info[$type]['Ignore_DB']
             );
-            if (strlen($key) > 0) {
+            if (/*overload*/mb_strlen($key) > 0) {
                 $out .= PMA_Util::getIcon('s_cancel.png',  __('Not replicated'));
             } else {
                 $key = array_search(
                     $current["SCHEMA_NAME"], $replication_info[$type]['Do_DB']
                 );
 
-                if (strlen($key) > 0
-                    || ($replication_info[$type]['Do_DB'][0] == ""
+                if (/*overload*/mb_strlen($key) > 0
+                    || (isset($replication_info[$type]['Do_DB'][0])
+                    && $replication_info[$type]['Do_DB'][0] == ""
                     && count($replication_info[$type]['Do_DB']) == 1)
                 ) {
                     // if ($key != null) did not work for index "0"
@@ -165,7 +168,7 @@ function PMA_buildHtmlForDb(
                . '<a onclick="'
                . 'PMA_commonActions.setDb(\''
                . PMA_jsFormat($current['SCHEMA_NAME']) . '\');'
-               . '" href="server_privileges.php?' . $url_query
+               . '" href="server_privileges.php' . $url_query
                . '&amp;db=' . urlencode($current['SCHEMA_NAME'])
                . '&amp;checkprivsdb=' . urlencode($current['SCHEMA_NAME'])
                . '" title="'
@@ -175,9 +178,8 @@ function PMA_buildHtmlForDb(
                )
                . '">'
                . ' '
-               . PMA_Util::getIcon('s_rights.png', __('Check Privileges'))
+               . PMA_Util::getIcon('s_rights.png', __('Check privileges'))
                . '</a></td>';
     }
     return array($column_order, $out);
 }
-?>
