@@ -42,15 +42,8 @@ if (getcwd() == dirname(__FILE__)) {
  * Minimum PHP version; can't call PMA_fatalError() which uses a
  * PHP 5 function, so cannot easily localize this message.
  */
-if (version_compare(PHP_VERSION, '5.2.0', 'lt')) {
-    die('PHP 5.2+ is required');
-}
-
-/**
-  * Backward compatibility for PHP 5.2
-  */
-if (!defined('E_DEPRECATED')) {
-    define('E_DEPRECATED', 8192);
+if (version_compare(PHP_VERSION, '5.5.0', 'lt')) {
+    die('PHP 5.5+ is required');
 }
 
 /**
@@ -58,6 +51,13 @@ if (!defined('E_DEPRECATED')) {
  */
 define('PHPMYADMIN', true);
 
+
+/**
+ * String handling (security)
+ */
+require_once './libraries/String.class.php';
+$PMA_String = new PMA_String();
+
 /**
  * the error handler
  */
@@ -67,18 +67,6 @@ require './libraries/Error_Handler.class.php';
  * initialize the error handler
  */
 $GLOBALS['error_handler'] = new PMA_Error_Handler();
-$cfg['Error_Handler']['display'] = true;
-
-/*
- * This setting was removed in PHP 5.3. But at this point PMA_PHP_INT_VERSION
- * is not yet defined so we use another way to find out the PHP version.
- */
-if (version_compare(phpversion(), '5.3', 'lt')) {
-    /**
-     * Avoid object cloning errors
-     */
-    @ini_set('zend.ze1_compatibility_mode', false);
-}
 
 /**
  * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
@@ -88,7 +76,7 @@ if (version_compare(phpversion(), '5.4', 'lt')) {
     /**
      * Avoid problems with magic_quotes_runtime
      */
-    @ini_set('magic_quotes_runtime', false);
+    @ini_set('magic_quotes_runtime', 'false');
 }
 
 /**
@@ -108,6 +96,12 @@ if (! function_exists('mb_detect_encoding')) {
     PMA_warnMissingExtension('mbstring', $fatal = true);
 }
 
+/**
+ * Set utf-8 encoding for PHP
+ */
+ini_set('default_charset', 'utf-8');
+mb_internal_encoding('utf-8');
+
 /**
  * the PMA_Theme class
  */
@@ -143,7 +137,7 @@ require './libraries/Table.class.php';
  */
 require './libraries/Types.class.php';
 
-if (! defined('PMA_MINIMUM_COMMON')) {
+if (! defined('PMA_MINIMUM_COMMON') || defined('PMA_SETUP')) {
     /**
      * common functions
      */
@@ -175,9 +169,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 $PMA_PHP_SELF = PMA_getenv('PHP_SELF');
 $_PATH_INFO = PMA_getenv('PATH_INFO');
 if (! empty($_PATH_INFO) && ! empty($PMA_PHP_SELF)) {
-    $path_info_pos = strrpos($PMA_PHP_SELF, $_PATH_INFO);
-    if ($path_info_pos + strlen($_PATH_INFO) === strlen($PMA_PHP_SELF)) {
-        $PMA_PHP_SELF = substr($PMA_PHP_SELF, 0, $path_info_pos);
+    $path_info_pos = /*overload*/mb_strrpos($PMA_PHP_SELF, $_PATH_INFO);
+    $pathLength = $path_info_pos + /*overload*/mb_strlen($_PATH_INFO);
+    if ($pathLength === /*overload*/mb_strlen($PMA_PHP_SELF)) {
+        $PMA_PHP_SELF = /*overload*/mb_substr($PMA_PHP_SELF, 0, $path_info_pos);
     }
 }
 $PMA_PHP_SELF = htmlspecialchars($PMA_PHP_SELF);
@@ -201,7 +196,8 @@ $variables_whitelist = array (
     'error_handler',
     'PMA_PHP_SELF',
     'variables_whitelist',
-    'key'
+    'key',
+    'PMA_String'
 );
 
 foreach (get_defined_vars() as $key => $value) {
@@ -219,7 +215,7 @@ unset($key, $value, $variables_whitelist);
  *
  * <code>
  * <form ...>
- * ... main form elments ...
+ * ... main form elements ...
  * <input type="hidden" name="subform[action1][id]" value="1" />
  * ... other subform data ...
  * <input type="submit" name="usesubform[action1]" value="do action1" />
@@ -227,7 +223,7 @@ unset($key, $value, $variables_whitelist);
  * <input type="hidden" name="subform[actionX][id]" value="X" />
  * ... other subform data ...
  * <input type="submit" name="usesubform[actionX]" value="do actionX" />
- * ... main form elments ...
+ * ... main form elements ...
  * <input type="submit" name="main_action" value="submit form" />
  * </form>
  * </code>
@@ -235,7 +231,7 @@ unset($key, $value, $variables_whitelist);
  * so we now check if a subform is submitted
  */
 $__redirect = null;
-if (isset($_POST['usesubform'])) {
+if (isset($_POST['usesubform']) && ! defined('PMA_MINIMUM_COMMON')) {
     // if a subform is present and should be used
     // the rest of the form is deprecated
     $subform_id = key($_POST['usesubform']);
@@ -265,17 +261,14 @@ if (isset($_POST['usesubform'])) {
 // end check if a subform is submitted
 
 /**
- * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
- * is not yet defined so we use another way to find out the PHP version.
+ * This setting was removed in PHP 5.4, but get_magic_quotes_gpc
+ * always returns False since then.
  */
-if (version_compare(phpversion(), '5.4', 'lt')) {
-    // remove quotes added by PHP
-    if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
-        PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
-    }
+if (get_magic_quotes_gpc()) {
+    PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
 }
 
 /**
@@ -327,16 +320,17 @@ $GLOBALS['PMA_Config']->enableBc();
  * when changing something related to PMA cookies, increment the cookie version
  */
 $pma_cookie_version = 4;
-if (isset($_COOKIE)
-    && (isset($_COOKIE['pmaCookieVer'])
-    && $_COOKIE['pmaCookieVer'] < $pma_cookie_version)
-) {
-    // delete all cookies
-    foreach ($_COOKIE as $cookie_name => $tmp) {
-        $GLOBALS['PMA_Config']->removeCookie($cookie_name);
+if (isset($_COOKIE)) {
+    if (! isset($_COOKIE['pmaCookieVer'])
+        || $_COOKIE['pmaCookieVer'] != $pma_cookie_version
+    ) {
+        // delete all cookies
+        foreach ($_COOKIE as $cookie_name => $tmp) {
+            $GLOBALS['PMA_Config']->removeCookie($cookie_name);
+        }
+        $_COOKIE = array();
+        $GLOBALS['PMA_Config']->setCookie('pmaCookieVer', $pma_cookie_version);
     }
-    $_COOKIE = array();
-    $GLOBALS['PMA_Config']->setCookie('pmaCookieVer', $pma_cookie_version);
 }
 
 
@@ -344,12 +338,13 @@ if (isset($_COOKIE)
  * check HTTPS connection
  */
 if ($GLOBALS['PMA_Config']->get('ForceSSL')
-    && ! $GLOBALS['PMA_Config']->get('is_https')
+    && ! $GLOBALS['PMA_Config']->detectHttps()
 ) {
+    require './libraries/select_lang.lib.php';
     // grab SSL URL
     $url = $GLOBALS['PMA_Config']->getSSLUri();
     // Actually redirect
-    PMA_sendHeaderLocation($url . PMA_generate_common_url($_GET, 'text'));
+    PMA_sendHeaderLocation($url . PMA_URL_getCommon($_GET, 'text'));
     // delete the current session, otherwise we get problems (see bug #2397877)
     $GLOBALS['PMA_Config']->removeCookie($GLOBALS['session_name']);
     exit;
@@ -389,7 +384,6 @@ $goto_whitelist = array(
     'db_structure.php',
     'db_import.php',
     'db_operations.php',
-    'db_printview.php',
     'db_search.php',
     'db_routines.php',
     'export.php',
@@ -401,7 +395,6 @@ $goto_whitelist = array(
     'pdf_pages.php',
     'pdf_schema.php',
     //'phpinfo.php',
-    'querywindow.php',
     'server_binlog.php',
     'server_collations.php',
     'server_databases.php',
@@ -422,8 +415,6 @@ $goto_whitelist = array(
     'tbl_create.php',
     'tbl_import.php',
     'tbl_indexes.php',
-    'tbl_move_copy.php',
-    'tbl_printview.php',
     'tbl_sql.php',
     'tbl_export.php',
     'tbl_operations.php',
@@ -481,8 +472,10 @@ if (PMA_checkPageValidity($_REQUEST['back'], $goto_whitelist)) {
  * f.e. lang, server, collation_connection in PMA_Config
  */
 $token_mismatch = true;
+$token_provided = false;
 if (PMA_isValid($_REQUEST['token'])) {
-    $token_mismatch = ($_SESSION[' PMA_token '] != $_REQUEST['token']);
+    $token_provided = true;
+    $token_mismatch = ! hash_equals($_SESSION[' PMA_token '], $_REQUEST['token']);
 }
 
 if ($token_mismatch) {
@@ -500,10 +493,17 @@ if ($token_mismatch) {
         'pma_lang', 'pma_collation_connection',
         /* Possible login form */
         'pma_servername', 'pma_username', 'pma_password',
+        'g-recaptcha-response',
         /* Needed to send the correct reply */
         'ajax_request',
         /* Permit to log out even if there is a token mismatch */
-        'old_usr'
+        'old_usr',
+        /* Permit redirection with token-mismatch in url.php */
+        'url',
+        /* Permit session expiry flag */
+        'session_expired',
+        /* JS loading */
+        'scripts', 'call_done'
     );
     /**
      * Allow changing themes in test/theme.php
@@ -518,7 +518,7 @@ if ($token_mismatch) {
     /**
      * Do actual cleanup
      */
-    PMA_remove_request_vars($allow_list);
+    PMA_removeRequestVars($allow_list);
 
 }
 
@@ -527,25 +527,13 @@ if ($token_mismatch) {
  * current selected database
  * @global string $GLOBALS['db']
  */
-$GLOBALS['db'] = '';
-if (PMA_isValid($_REQUEST['db'])) {
-    // can we strip tags from this?
-    // only \ and / is not allowed in db names for MySQL
-    $GLOBALS['db'] = $_REQUEST['db'];
-    $GLOBALS['url_params']['db'] = $GLOBALS['db'];
-}
+PMA_setGlobalDbOrTable('db');
 
 /**
  * current selected table
  * @global string $GLOBALS['table']
  */
-$GLOBALS['table'] = '';
-if (PMA_isValid($_REQUEST['table'])) {
-    // can we strip tags from this?
-    // only \ and / is not allowed in table names for MySQL
-    $GLOBALS['table'] = $_REQUEST['table'];
-    $GLOBALS['url_params']['table'] = $GLOBALS['table'];
-}
+PMA_setGlobalDbOrTable('table');
 
 /**
  * Store currently selected recent table.
@@ -596,9 +584,12 @@ if ($GLOBALS['text_dir'] == 'ltr') {
 $GLOBALS['PMA_Config']->checkPermissions();
 
 if ($GLOBALS['PMA_Config']->error_config_file) {
-    $error = '[strong]' . __('Failed to read configuration file') . '[/strong]'
+    $error = '[strong]' . __('Failed to read configuration file!') . '[/strong]'
         . '[br][br]'
-        . __('This usually means there is a syntax error in it, please check any errors shown below.')
+        . __(
+            'This usually means there is a syntax error in it, '
+            . 'please check any errors shown below.'
+        )
         . '[br][br]'
         . '[conferr]';
     trigger_error($error, E_USER_ERROR);
@@ -612,7 +603,10 @@ if ($GLOBALS['PMA_Config']->error_config_default_file) {
 }
 if ($GLOBALS['PMA_Config']->error_pma_uri) {
     trigger_error(
-        __('The [code]$cfg[\'PmaAbsoluteUri\'][/code] directive MUST be set in your configuration file!'),
+        __(
+            'The [code]$cfg[\'PmaAbsoluteUri\'][/code]'
+            . ' directive MUST be set in your configuration file!'
+        ),
         E_USER_ERROR
     );
 }
@@ -656,7 +650,10 @@ if (! isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
         if ($each_server['connect_type'] == 'tcp' && empty($each_server['host'])) {
             trigger_error(
                 sprintf(
-                    __('Invalid hostname for server %1$s. Please review your configuration.'),
+                    __(
+                        'Invalid hostname for server %1$s. '
+                        . 'Please review your configuration.'
+                    ),
                     $server_index
                 ),
                 E_USER_ERROR
@@ -672,7 +669,7 @@ if (! isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
             && empty($each_server['host'])
             && empty($each_server['verbose'])
         ) {
-            $each_server['verbose'] = __('Server') . $server_index;
+            $each_server['verbose'] = sprintf(__('Server %d'), $server_index);
         }
 
         $new_servers[$server_index] = $each_server;
@@ -754,11 +751,6 @@ if (! defined('PMA_MINIMUM_COMMON')) {
      */
     include_once './libraries/charset_conversion.lib.php';
 
-    /**
-     * String handling
-     */
-    include_once './libraries/string.lib.php';
-
     /**
      * Lookup server by name
      * (see FAQ 4.8)
@@ -768,7 +760,13 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         && ! is_numeric($_REQUEST['server'])
     ) {
         foreach ($cfg['Servers'] as $i => $server) {
-            if ($server['host'] == $_REQUEST['server']) {
+            $verboseToLower = /*overload*/mb_strtolower($server['verbose']);
+            $serverToLower = /*overload*/mb_strtolower($_REQUEST['server']);
+            if ($server['host'] == $_REQUEST['server']
+                || $server['verbose'] == $_REQUEST['server']
+                || $verboseToLower == $serverToLower
+                || md5($verboseToLower) == $serverToLower
+            ) {
                 $_REQUEST['server'] = $i;
                 break;
             }
@@ -834,7 +832,7 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         /**
          * Loads the proper database interface for this server
          */
-        include_once './libraries/database_interface.lib.php';
+        include_once './libraries/database_interface.inc.php';
 
         include_once './libraries/logging.lib.php';
 
@@ -842,8 +840,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // no generic solution for loading preferences from cache as some settings
         // need to be kept for processing in PMA_Config::loadUserPreferences()
         $cache_key = 'server_' . $GLOBALS['server'];
-        if (isset($_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'])) {
-            $value = $_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'];
+        if (isset($_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'])
+        ) {
+            $value
+                = $_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'];
             $GLOBALS['PMA_Config']->set('LoginCookieValidity', $value);
             $GLOBALS['cfg']['LoginCookieValidity'] = $value;
             unset($value);
@@ -854,36 +854,43 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // and run authentication
 
         // to allow HTTP or http
-        $cfg['Server']['auth_type'] = strtolower($cfg['Server']['auth_type']);
+        $cfg['Server']['auth_type']
+            = /*overload*/mb_strtolower($cfg['Server']['auth_type']);
 
         /**
          * the required auth type plugin
          */
         $auth_class = "Authentication" . ucfirst($cfg['Server']['auth_type']);
-        if (! file_exists('./libraries/plugins/auth/' . $auth_class . '.class.php')) {
+        if (! file_exists(
+            './libraries/plugins/auth/'
+            . $auth_class . '.class.php'
+        )) {
             PMA_fatalError(
                 __('Invalid authentication method set in configuration:')
                 . ' ' . $cfg['Server']['auth_type']
             );
         }
+        if (isset($_REQUEST['pma_password'])) {
+            $_REQUEST['pma_password'] = substr($_REQUEST['pma_password'], 0, 256);
+        }
         include_once  './libraries/plugins/auth/' . $auth_class . '.class.php';
         // todo: add plugin manager
         $plugin_manager = null;
+        /** @var AuthenticationPlugin $auth_plugin */
         $auth_plugin = new $auth_class($plugin_manager);
 
         if (! $auth_plugin->authCheck()) {
             /* Force generating of new session on login */
-            PMA_secureSession();
+            if ($token_provided) {
+                PMA_secureSession();
+            }
             $auth_plugin->auth();
         } else {
             $auth_plugin->authSetUser();
         }
 
-         // Check IP-based Allow/Deny rules as soon as possible to reject the
-        // user
-        // Based on mod_access in Apache:
-        // http://cvs.apache.org/viewcvs.cgi/httpd-2.0/modules/aaa/mod_access.c?rev=1.37&content-type=text/vnd.viewcvs-markup
-        // Look at: "static int check_dir_access(request_rec *r)"
+        // Check IP-based Allow/Deny rules as soon as possible to reject the
+        // user based on mod_access in Apache
         if (isset($cfg['Server']['AllowDeny'])
             && isset($cfg['Server']['AllowDeny']['order'])
         ) {
@@ -919,27 +926,29 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 
             // Ejects the user if banished
             if ($allowDeny_forbidden) {
-                PMA_log_user($cfg['Server']['user'], 'allow-denied');
+                PMA_logUser($cfg['Server']['user'], 'allow-denied');
                 $auth_plugin->authFails();
             }
         } // end if
 
         // is root allowed?
-        if (!$cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
+        if (! $cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
             $allowDeny_forbidden = true;
-            PMA_log_user($cfg['Server']['user'], 'root-denied');
+            PMA_logUser($cfg['Server']['user'], 'root-denied');
             $auth_plugin->authFails();
         }
 
         // is a login without password allowed?
-        if (!$cfg['Server']['AllowNoPassword'] && $cfg['Server']['password'] == '') {
+        if (! $cfg['Server']['AllowNoPassword']
+            && $cfg['Server']['password'] == ''
+        ) {
             $login_without_password_is_forbidden = true;
-            PMA_log_user($cfg['Server']['user'], 'empty-denied');
+            PMA_logUser($cfg['Server']['user'], 'empty-denied');
             $auth_plugin->authFails();
         }
 
         // if using TCP socket is not needed
-        if (strtolower($cfg['Server']['connect_type']) == 'tcp') {
+        if (/*overload*/mb_strtolower($cfg['Server']['connect_type']) == 'tcp') {
             $cfg['Server']['socket'] = '';
         }
 
@@ -949,15 +958,34 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // scripts)
         $controllink = false;
         if ($cfg['Server']['controluser'] != '') {
-            if (! empty($cfg['Server']['controlhost'])) {
-                $controllink = PMA_DBI_connect(
+            if (! empty($cfg['Server']['controlhost'])
+                || ! empty($cfg['Server']['controlport'])
+            ) {
+                $server_details = array();
+                if (! empty($cfg['Server']['controlhost'])) {
+                    $server_details['host'] = $cfg['Server']['controlhost'];
+                } else {
+                    $server_details['host'] = $cfg['Server']['host'];
+                }
+                if (! empty($cfg['Server']['controlport'])) {
+                    $server_details['port'] = $cfg['Server']['controlport'];
+                } elseif ($server_details['host'] == $cfg['Server']['host']) {
+                    // Evaluates to true when controlhost == host
+                    // or controlhost is not defined (hence it defaults to host)
+                    // In such case we can use the value of port.
+                    $server_details['port'] = $cfg['Server']['port'];
+                }
+                // otherwise we leave the $server_details['port'] unset,
+                // allowing it to take default mysql port
+
+                $controllink = $GLOBALS['dbi']->connect(
                     $cfg['Server']['controluser'],
                     $cfg['Server']['controlpass'],
                     true,
-                    array('host' => $cfg['Server']['controlhost'])
+                    $server_details
                 );
             } else {
-                $controllink = PMA_DBI_connect(
+                $controllink = $GLOBALS['dbi']->connect(
                     $cfg['Server']['controluser'],
                     $cfg['Server']['controlpass'],
                     true
@@ -966,26 +994,55 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         }
 
         // Connects to the server (validates user's login)
-        $userlink = PMA_DBI_connect(
+        /** @var PMA_DatabaseInterface $userlink */
+        $userlink = $GLOBALS['dbi']->connect(
             $cfg['Server']['user'], $cfg['Server']['password'], false
         );
 
+        // Set timestamp for the session, if required.
+        if ($cfg['Server']['SessionTimeZone'] != '') {
+            $sql_query_tz = 'SET ' . PMA_Util::backquote('time_zone') . ' = '
+                . '\''
+                . PMA_Util::sqlAddSlashes($cfg['Server']['SessionTimeZone'])
+                . '\'';
+
+            if (! $userlink->query($sql_query_tz)) {
+                $error_message_tz = sprintf(
+                    __(
+                        'Unable to use timezone %1$s for server %2$d. '
+                        . 'Please check your configuration setting for '
+                        . '[em]$cfg[\'Servers\'][%3$d][\'SessionTimeZone\'][/em]. '
+                        . 'phpMyAdmin is currently using the default time zone '
+                        . 'of the database server.'
+                    ),
+                    $cfg['Servers'][$GLOBALS['server']]['SessionTimeZone'],
+                    $GLOBALS['server'],
+                    $GLOBALS['server']
+                );
+
+                $GLOBALS['error_handler']->addError(
+                    $error_message_tz,
+                    E_USER_WARNING,
+                    '',
+                    '',
+                    false
+                );
+            }
+        }
+
         if (! $controllink) {
             $controllink = $userlink;
         }
 
-        /* Log success */
-        PMA_log_user($cfg['Server']['user']);
+        $auth_plugin->storeUserCredentials();
 
-        /**
-         * with phpMyAdmin 3 we support MySQL >=5
-         * but only production releases:
-         *  - > 5.0.15
-         */
-        if (PMA_MYSQL_INT_VERSION < 50015) {
+        /* Log success */
+        PMA_logUser($cfg['Server']['user']);
+
+        if (PMA_MYSQL_INT_VERSION < $cfg['MysqlMinVersion']['internal']) {
             PMA_fatalError(
                 __('You should upgrade to %s %s or later.'),
-                array('MySQL', '5.0.15')
+                array('MySQL', $cfg['MysqlMinVersion']['human'])
             );
         }
 
@@ -1007,14 +1064,32 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         }
 
         /**
-         * SQL Parser code
+         * Charset information
          */
-        include_once './libraries/sqlparser.lib.php';
+        if (!PMA_DRIZZLE) {
+            include_once './libraries/mysql_charsets.inc.php';
+        }
+        if (!isset($mysql_charsets)) {
+            $mysql_charsets = array();
+            $mysql_collations_flat = array();
+        }
 
         /**
-         * SQL Validator interface code
+         * Initializes the SQL parsing library.
          */
-        include_once './libraries/sqlvalidator.lib.php';
+        include_once SQL_PARSER_AUTOLOAD;
+
+        // Loads closest context to this version.
+        SqlParser\Context::loadClosest(
+            (PMA_DRIZZLE ? 'Drizzle' : 'MySql') . PMA_MYSQL_INT_VERSION
+        );
+
+        // Sets the default delimiter (if specified).
+        if (!empty($_REQUEST['sql_delimiter'])) {
+            SqlParser\Lexer::$DEFAULT_DELIMITER = $_REQUEST['sql_delimiter'];
+        }
+
+        // TODO: Set SQL modes too.
 
         /**
          * the PMA_List_Database class
@@ -1027,14 +1102,20 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         /**
          * some resetting has to be done when switching servers
          */
-        if (isset($_SESSION['tmp_user_values']['previous_server'])
-            && $_SESSION['tmp_user_values']['previous_server'] != $GLOBALS['server']
+        if (isset($_SESSION['tmpval']['previous_server'])
+            && $_SESSION['tmpval']['previous_server'] != $GLOBALS['server']
         ) {
-            unset($_SESSION['tmp_user_values']['navi_limit_offset']);
+            unset($_SESSION['tmpval']['navi_limit_offset']);
         }
-        $_SESSION['tmp_user_values']['previous_server'] = $GLOBALS['server'];
+        $_SESSION['tmpval']['previous_server'] = $GLOBALS['server'];
 
-    } // end server connecting
+    } else { // end server connecting
+        // No need to check for 'PMA_BYPASS_GET_INSTANCE' since this execution path
+        // applies only to initial login
+        $response = PMA_Response::getInstance();
+        $response->getHeader()->disableMenuAndConsole();
+        $response->getFooter()->setMinimal();
+    }
 
     /**
      * check if profiling was requested and remember it
@@ -1048,6 +1129,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // the checkbox was unchecked
         unset($_SESSION['profiling']);
     }
+
+    // load user preferences
+    $GLOBALS['PMA_Config']->loadUserPreferences();
+
     /**
      * Inclusion of profiling scripts is needed on various
      * pages like sql, tbl_sql, db_sql, tbl_select
@@ -1058,13 +1143,11 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     if (isset($_SESSION['profiling'])) {
         $header   = $response->getHeader();
         $scripts  = $header->getScripts();
-        /* < IE 9 doesn't support canvas natively */
-        if (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER < 9) {
-            $scripts->addFile('canvg/flashcanvas.js');
-        }
         $scripts->addFile('jqplot/jquery.jqplot.js');
         $scripts->addFile('jqplot/plugins/jqplot.pieRenderer.js');
+        $scripts->addFile('jqplot/plugins/jqplot.highlighter.js');
         $scripts->addFile('canvg/canvg.js');
+        $scripts->addFile('jquery/jquery.tablesorter.js');
     }
 
     /*
@@ -1079,10 +1162,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         );
         exit;
     }
-} // end if !defined('PMA_MINIMUM_COMMON')
-
-// load user preferences
-$GLOBALS['PMA_Config']->loadUserPreferences();
+} else { // end if !defined('PMA_MINIMUM_COMMON')
+    // load user preferences
+    $GLOBALS['PMA_Config']->loadUserPreferences();
+}
 
 // remove sensitive values from session
 $GLOBALS['PMA_Config']->set('blowfish_secret', '');
@@ -1106,18 +1189,6 @@ if (isset($_REQUEST['ajax_request']) && $_REQUEST['ajax_request'] == true) {
     $GLOBALS['is_ajax_request'] = false;
 }
 
-/**
- * @global  boolean $GLOBALS['grid_edit']
- *
- * Set to true if this is a request made during an grid edit process.  This
- * request is made to retrieve the non-truncated/transformed values.
- */
-if (isset($_REQUEST['grid_edit']) && $_REQUEST['grid_edit'] == true) {
-    $GLOBALS['grid_edit'] = true;
-} else {
-    $GLOBALS['grid_edit'] = false;
-}
-
 if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS'])) {
     PMA_fatalError(__("GLOBALS overwrite attempt"));
 }
@@ -1142,7 +1213,8 @@ unset($dummy);
 
 // here, the function does not exist with this configuration:
 // $cfg['ServerDefault'] = 0;
-$GLOBALS['is_superuser'] = function_exists('PMA_isSuperuser') && PMA_isSuperuser();
+$GLOBALS['is_superuser']
+    = isset($GLOBALS['dbi']) && $GLOBALS['dbi']->isSuperuser();
 
 if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     /**
@@ -1152,4 +1224,28 @@ if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     exit();
 }
 
-?>
+// If Zero configuration mode enabled, check PMA tables in current db.
+if (! defined('PMA_MINIMUM_COMMON')
+    && ! empty($GLOBALS['server'])
+    && isset($GLOBALS['cfg']['ZeroConf'])
+    && $GLOBALS['cfg']['ZeroConf'] == true
+) {
+    if (! empty($GLOBALS['db'])) {
+        $cfgRelation = PMA_getRelationsParam();
+        if (empty($cfgRelation['db'])) {
+            PMA_fixPMATables($GLOBALS['db'], false);
+        }
+    }
+    $cfgRelation = PMA_getRelationsParam();
+    if (empty($cfgRelation['db'])) {
+        foreach ($GLOBALS['pma']->databases as $database) {
+            if ($database == 'phpmyadmin') {
+                PMA_fixPMATables($database, false);
+            }
+        }
+    }
+}
+
+if (! defined('PMA_MINIMUM_COMMON')) {
+    include_once 'libraries/config/page_settings.class.php';
+}
