@@ -1,10 +1,10 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * List of avaible forms, each form is described as an array of fields to display.
+ * List of available forms, each form is described as an array of fields to display.
  * Fields MUST have their counterparts in the $cfg array.
  *
- * To define form field, use the notatnion below:
+ * To define form field, use the notation below:
  * $forms['Form group']['Form name'] = array('Option/path');
  *
  * You can assign default values set by special button ("set value: ..."), eg.:
@@ -26,16 +26,18 @@ $forms['Features']['General'] = array(
     'NaturalOrder',
     'InitialSlidersState',
     'LoginCookieValidity',
-    'Servers/1/only_db', // saves to Server/only_db
-    'Servers/1/hide_db', // saves to Server/hide_db
     'SkipLockedTables',
     'DisableMultiTableMaintenance',
-    'MaxDbList',
     'MaxTableList',
-    'NumRecentTables',
-    'NumFavoriteTables',
     'ShowHint',
-    'SendErrorReports');
+    'SendErrorReports',
+    'ConsoleEnterExecutes'
+);
+$forms['Features']['Databases'] = array(
+    'Servers/1/only_db', // saves to Server/only_db
+    'Servers/1/hide_db', // saves to Server/hide_db
+    'MaxDbList'
+);
 $forms['Features']['Text_fields'] = array(
     'CharEditing',
     'MinSizeForInputField',
@@ -54,11 +56,11 @@ $forms['Features']['Warnings'] = array(
     'ServerLibraryDifference_DisableWarning',
     'PmaNoRelation_DisableWarning',
     'SuhosinDisableWarning',
+    'LoginCookieValidityDisableWarning',
     'ReservedWordDisableWarning');
 // settings from this form are treated specially,
 // see prefs_forms.php and user_preferences.lib.php
 $forms['Features']['Developer'] = array(
-    'Error_Handler/display',
     'DBG/sql');
 $forms['Sql_queries']['Sql_queries'] = array(
     'ShowSQL',
@@ -66,32 +68,44 @@ $forms['Sql_queries']['Sql_queries'] = array(
     'QueryHistoryMax',
     'IgnoreMultiSubmitErrors',
     'MaxCharactersInDisplayedSQL',
-    'EditInWindow',
-    //'QueryWindowWidth', // overridden in theme
-    //'QueryWindowHeight',
-    'QueryWindowDefTab',
     'RetainQueryBox',
-    'CodemirrorEnable');
+    'CodemirrorEnable',
+    'LintEnable',
+    'EnableAutocompleteForTablesAndColumns',
+    'DefaultForeignKeyChecks');
 $forms['Sql_queries']['Sql_box'] = array(
     'SQLQuery/Edit',
     'SQLQuery/Explain',
     'SQLQuery/ShowAsPHP',
     'SQLQuery/Refresh');
 $forms['Navi_panel']['Navi_panel'] = array(
+    'ShowDatabasesNavigationAsTree',
+    'NavigationLinkWithMainPanel',
     'NavigationDisplayLogo',
     'NavigationLogoLink',
     'NavigationLogoLinkWindow',
     'NavigationTreePointerEnable',
     'FirstLevelNavigationItems',
+    'NavigationTreeDisplayItemFilterMinimum',
+    'NumRecentTables',
+    'NumFavoriteTables'
+);
+$forms['Navi_panel']['Navi_tree'] = array(
     'MaxNavigationItems',
     'NavigationTreeEnableGrouping',
-    'NavigationTreeDisableDatabaseExpansion',
-    'NavigationTreeDisplayItemFilterMinimum');
+    'NavigationTreeEnableExpansion',
+    'NavigationTreeShowTables',
+    'NavigationTreeShowViews',
+    'NavigationTreeShowFunctions',
+    'NavigationTreeShowProcedures',
+    'NavigationTreeShowEvents'
+);
 $forms['Navi_panel']['Navi_databases'] = array(
     'NavigationTreeDisplayDbFilterMinimum',
     'NavigationTreeDbSeparator');
 $forms['Navi_panel']['Navi_tables'] = array(
     'NavigationTreeDefaultTabTable',
+    'NavigationTreeDefaultTabTable2',
     'NavigationTreeTableSeparator',
     'NavigationTreeTableLevel',
 );
@@ -100,6 +114,7 @@ $forms['Main_panel']['Startup'] = array(
     'ShowStats',
     'ShowServerInfo');
 $forms['Main_panel']['DbStructure'] = array(
+    'ShowDbStructureComment',
     'ShowDbStructureCreation',
     'ShowDbStructureLastUpdate',
     'ShowDbStructureLastCheck');
@@ -111,17 +126,17 @@ $forms['Main_panel']['Browse'] = array(
     'ShowAll',
     'MaxRows',
     'Order',
-    'DisplayBinaryAsHex',
     'BrowsePointerEnable',
     'BrowseMarkerEnable',
     'GridEditing',
     'SaveCellsAtOnce',
-    'ShowDisplayDirection',
     'RepeatCells',
     'LimitChars',
     'RowActionLinks',
-    'DefaultDisplay',
-    'RememberSorting');
+    'RowActionLinksWithoutUnique',
+    'TablePrimaryKeyOrder',
+    'RememberSorting',
+    'RelationalDisplay');
 $forms['Main_panel']['Edit'] = array(
     'ProtectBinary',
     'ShowFunctionFields',
@@ -141,10 +156,12 @@ $forms['Import']['Import_defaults'] = array(
     'Import/format',
     'Import/charset',
     'Import/allow_interrupt',
-    'Import/skip_queries');
+    'Import/skip_queries'
+);
 $forms['Import']['Sql'] = array(
     'Import/sql_compatibility',
-    'Import/sql_no_auto_value_on_zero');
+    'Import/sql_no_auto_value_on_zero',
+    'Import/sql_read_as_multibytes');
 $forms['Import']['Csv'] = array(
     ':group:' . __('CSV'),
         'Import/csv_replace',
@@ -177,6 +194,8 @@ $forms['Export']['Export_defaults'] = array(
         'Export/format',
         'Export/compression',
         'Export/charset',
+        'Export/lock_tables',
+        'Export/as_separate_files',
         'Export/asfile' => ':group',
             'Export/onserver',
             'Export/onserver_overwrite',
@@ -193,21 +212,20 @@ $forms['Export']['Sql'] = array(
     'Export/sql_use_transaction',
     'Export/sql_disable_fk',
     'Export/sql_views_as_tables',
+    'Export/sql_metadata',
     'Export/sql_compatibility',
-    ':group:' . __('Database export options'),
-        'Export/sql_drop_database',
-        'Export/sql_structure_or_data',
-        ':group:end',
+    'Export/sql_structure_or_data',
     ':group:' . __('Structure'),
+        'Export/sql_drop_database',
+        'Export/sql_create_database',
         'Export/sql_drop_table',
-        'Export/sql_create_table',
-        'Export/sql_create_view',
-        'Export/sql_procedure_function',
-        'Export/sql_create_trigger',
-        'Export/sql_create_table_statements' => ':group',
+        'Export/sql_create_table' => ':group',
             'Export/sql_if_not_exists',
             'Export/sql_auto_increment',
             ':group:end',
+        'Export/sql_create_view',
+        'Export/sql_procedure_function',
+        'Export/sql_create_trigger',
         'Export/sql_backquotes',
         ':group:end',
     ':group:' . __('Data'),
@@ -277,4 +295,3 @@ $forms['Export']['Texy'] = array(
     ':group:' . __('Data'),
         'Export/texytext_null',
         'Export/texytext_columns');
-?>
