@@ -19,14 +19,18 @@ require_once 'libraries/Index.class.php';
  */
 function PMA_getHtmlForDisplayIndexes()
 {
-    $html_output = '<div id="index_div" class="ajax" >';
+    $html_output = '<div id="index_div" class="ajax';
+    if ($GLOBALS['cfg']['InitialSlidersState'] != 'disabled') {
+        $html_output .= ' print_ignore';
+    }
+    $html_output .= '" >';
 
     $html_output .= PMA_Util::getDivForSliderEffect(
         'indexes', __('Indexes')
     );
-    $html_output .= PMA_Index::getView($GLOBALS['table'], $GLOBALS['db']);
-    $html_output .= '<fieldset class="tblFooters" style="text-align: left;">'
-        . '<form action="tbl_indexes.php" method="post">';
+    $html_output .= PMA_Index::getHtmlForIndexes($GLOBALS['table'], $GLOBALS['db']);
+    $html_output .= '<fieldset class="tblFooters print_ignore" style="text-align: '
+        . 'left;"><form action="tbl_indexes.php" method="post">';
     $html_output .= PMA_URL_getHiddenInputs(
         $GLOBALS['db'], $GLOBALS['table']
     );
