@@ -12,20 +12,18 @@ if (! defined('PHPMYADMIN')) {
 /**
  * Generate charset dropdown box
  *
- * @param int         $type               Type
- * @param null|string $name               Element name
- * @param null|string $id                 Element id
- * @param null|string $default            Default value
- * @param bool        $label              Label
- * @param int         $indent             Indent
- * @param bool        $submitOnChange     Submit on change
- * @param bool        $displayUnavailable Display unavailable
+ * @param int         $type           Type
+ * @param string      $name           Element name
+ * @param string      $id             Element id
+ * @param null|string $default        Default value
+ * @param bool        $label          Label
+ * @param bool        $submitOnChange Submit on change
  *
  * @return string
  */
 function PMA_generateCharsetDropdownBox($type = PMA_CSDROPDOWN_COLLATION,
-    $name = null, $id = null, $default = null, $label = true, $indent = 0,
-    $submitOnChange = false, $displayUnavailable = false
+    $name = null, $id = null, $default = null, $label = true,
+    $submitOnChange = false
 ) {
     global $mysql_charsets, $mysql_charsets_descriptions,
         $mysql_charsets_available, $mysql_collations, $mysql_collations_available;
@@ -86,15 +84,21 @@ function PMA_generateCharsetDropdownBox($type = PMA_CSDROPDOWN_COLLATION,
 /**
  * Generate the charset query part
  *
- * @param string $collation Collation
+ * @param string           $collation Collation
+ * @param boolean optional $override  force 'CHARACTER SET' keyword
  *
  * @return string
  */
-function PMA_generateCharsetQueryPart($collation)
+function PMA_generateCharsetQueryPart($collation, $override = false)
 {
     if (!PMA_DRIZZLE) {
         list($charset) = explode('_', $collation);
-        return ' CHARACTER SET ' . $charset
+        $keyword = ' CHARSET=';
+
+        if ($override) {
+            $keyword = ' CHARACTER SET ';
+        }
+        return $keyword . $charset
             . ($charset == $collation ? '' : ' COLLATE ' . $collation);
     } else {
         return ' COLLATE ' . $collation;
@@ -116,14 +120,24 @@ function PMA_getDbCollation($db)
         return 'utf8_general_ci';
     }
 
-    $sql = PMA_DRIZZLE
-        ? 'SELECT DEFAULT_COLLATION_NAME FROM data_dictionary.SCHEMAS'
-        . ' WHERE SCHEMA_NAME = \'' . PMA_Util::sqlAddSlashes($db)
-        . '\' LIMIT 1'
-        : 'SELECT DEFAULT_COLLATION_NAME FROM information_schema.SCHEMATA'
-        . ' WHERE SCHEMA_NAME = \'' . PMA_Util::sqlAddSlashes($db)
-        . '\' LIMIT 1';
-    return $GLOBALS['dbi']->fetchValue($sql);
+    if (! $GLOBALS['cfg']['Server']['DisableIS']) {
+        // this is slow with thousands of databases
+        $sql = PMA_DRIZZLE
+            ? 'SELECT DEFAULT_COLLATION_NAME FROM data_dictionary.SCHEMAS'
+            . ' WHERE SCHEMA_NAME = \'' . PMA_Util::sqlAddSlashes($db)
+            . '\' LIMIT 1'
+            : 'SELECT DEFAULT_COLLATION_NAME FROM information_schema.SCHEMATA'
+            . ' WHERE SCHEMA_NAME = \'' . PMA_Util::sqlAddSlashes($db)
+            . '\' LIMIT 1';
+        return $GLOBALS['dbi']->fetchValue($sql);
+    } else {
+        $GLOBALS['dbi']->selectDb($db);
+        $return = $GLOBALS['dbi']->fetchValue('SELECT @@collation_database');
+        if ($db !== $GLOBALS['db']) {
+            $GLOBALS['dbi']->selectDb($GLOBALS['db']);
+        }
+        return $return;
+    }
 }
 
 /**
@@ -133,9 +147,7 @@ function PMA_getDbCollation($db)
  */
 function PMA_getServerCollation()
 {
-    return $GLOBALS['dbi']->fetchValue(
-        'SHOW VARIABLES LIKE \'collation_server\'', 0, 1
-    );
+    return $GLOBALS['dbi']->fetchValue('SELECT @@collation_server');
 }
 
 /**
@@ -229,6 +241,9 @@ function PMA_getCollationDescr($collation)
     case 'romanian':
         $descr = __('Romanian');
         break;
+    case 'sinhala':
+        $descr = __('Sinhalese');
+        break;
     case 'slovak':
         $descr = __('Slovak');
         break;
@@ -256,6 +271,10 @@ function PMA_getCollationDescr($collation)
     case 'unicode':
         $descr = __('Unicode') . ' (' . __('multilingual') . ')';
         break;
+    case 'vietnamese':
+        $descr = __('Vietnamese');
+        break;
+    /** @noinspection PhpMissingBreakStatementInspection */
     case 'bin':
         $is_bin = true;
         // no break; statement here, continuing with 'general' section:
@@ -366,4 +385,3 @@ function PMA_getCollationDescr($collation)
 
     return $descr;
 }
-?>
