@@ -10,22 +10,31 @@ if (! defined('PHPMYADMIN')) {
 }
 
 /**
- * Represents a node that is a concrete child of a database node
+ * Represents a node that is a child of a database node
+ * This may either be a concrete child such as table or a container
+ * such as table container
  *
  * @package PhpMyAdmin-Navigation
  */
 abstract class Node_DatabaseChild extends Node
 {
     /**
-     * Returns HTML for hide button displayed infront of the database child node
+     * Returns the type of the item represented by the node.
      *
-     * @return String HTML for hide button
+     * @return string type of the item
+     */
+    protected abstract function getItemType();
+
+    /**
+     * Returns HTML for control buttons displayed infront of a node
+     *
+     * @return String HTML for control buttons
      */
     public function getHtmlForControlButtons()
     {
         $ret = '';
         $cfgRelation = PMA_getRelationsParam();
-        if (isset($cfgRelation['navwork']) && $cfgRelation['navwork']) {
+        if ($cfgRelation['navwork']) {
             $db   = $this->realParent()->real_name;
             $item = $this->real_name;
             $ret  = '<span class="navItemControls">'
@@ -41,12 +50,4 @@ abstract class Node_DatabaseChild extends Node
         }
         return $ret;
     }
-
-    /**
-     * Returns the type of the item represented by the node.
-     *
-     * @return string type of the item
-     */
-    protected abstract function getItemType();
 }
-?>
