@@ -22,8 +22,6 @@ class Node_Database_Container extends Node
      * Initialises the class
      *
      * @param string $name An identifier for the new node
-     *
-     * @return Node_Database_Container
      */
     public function __construct($name)
     {
@@ -39,13 +37,12 @@ class Node_Database_Container extends Node
             $new->icon  = PMA_Util::getImage('b_newdb.png', '');
             $new->links = array(
                 'text' => 'server_databases.php?server=' . $GLOBALS['server']
-                        . '&amp;token=' . $GLOBALS['token'],
+                        . '&amp;token=' . $_SESSION[' PMA_token '],
                 'icon' => 'server_databases.php?server=' . $GLOBALS['server']
-                        . '&amp;token=' . $GLOBALS['token'],
+                        . '&amp;token=' . $_SESSION[' PMA_token '],
             );
             $new->classes = 'new_database italics';
             $this->addChild($new);
         }
     }
 }
-?>
