@@ -9,17 +9,17 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/navigation/Nodes/Node_DatabaseChild_Container.class.php';
+
 /**
  * Represents a container for events nodes in the navigation tree
  *
  * @package PhpMyAdmin-Navigation
  */
-class Node_Event_Container extends Node
+class Node_Event_Container extends Node_DatabaseChild_Container
 {
     /**
      * Initialises the class
-     *
-     * @return Node_Event_Container
      */
     public function __construct()
     {
@@ -27,9 +27,9 @@ class Node_Event_Container extends Node
         $this->icon  = PMA_Util::getImage('b_events.png', '');
         $this->links = array(
             'text' => 'db_events.php?server=' . $GLOBALS['server']
-                    . '&amp;db=%1$s&amp;token=' . $GLOBALS['token'],
+                    . '&amp;db=%1$s&amp;token=' . $_SESSION[' PMA_token '],
             'icon' => 'db_events.php?server=' . $GLOBALS['server']
-                    . '&amp;db=%1$s&amp;token=' . $GLOBALS['token'],
+                    . '&amp;db=%1$s&amp;token=' . $_SESSION[' PMA_token '],
         );
         $this->real_name = 'events';
 
@@ -40,10 +40,10 @@ class Node_Event_Container extends Node
         $new->icon  = PMA_Util::getImage('b_event_add.png', '');
         $new->links = array(
             'text' => 'db_events.php?server=' . $GLOBALS['server']
-                    . '&amp;db=%2$s&amp;token=' . $GLOBALS['token']
+                    . '&amp;db=%2$s&amp;token=' . $_SESSION[' PMA_token ']
                     . '&add_item=1',
             'icon' => 'db_events.php?server=' . $GLOBALS['server']
-                    . '&amp;db=%2$s&amp;token=' . $GLOBALS['token']
+                    . '&amp;db=%2$s&amp;token=' . $_SESSION[' PMA_token ']
                     . '&add_item=1',
         );
         $new->classes = 'new_event italics';
@@ -51,4 +51,3 @@ class Node_Event_Container extends Node
     }
 }
 
-?>
