@@ -9,12 +9,14 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/navigation/Nodes/Node_DatabaseChild.class.php';
+
 /**
  * Represents a procedure node in the navigation tree
  *
  * @package PhpMyAdmin-Navigation
  */
-class Node_Procedure extends Node
+class Node_Procedure extends Node_DatabaseChild
 {
     /**
      * Initialises the class
@@ -23,23 +25,30 @@ class Node_Procedure extends Node
      * @param int    $type     Type of node, may be one of CONTAINER or OBJECT
      * @param bool   $is_group Whether this object has been created
      *                         while grouping nodes
-     *
-     * @return Node_Procedure
      */
     public function __construct($name, $type = Node::OBJECT, $is_group = false)
     {
         parent::__construct($name, $type, $is_group);
-        $this->icon  = PMA_Util::getImage('b_routines.png');
+        $this->icon  = PMA_Util::getImage('b_routines.png', __('Procedure'));
         $this->links = array(
             'text' => 'db_routines.php?server=' . $GLOBALS['server']
                     . '&amp;db=%2$s&amp;item_name=%1$s&amp;item_type=PROCEDURE'
-                    . '&amp;edit_item=1&amp;token=' . $GLOBALS['token'],
+                    . '&amp;edit_item=1&amp;token=' . $_SESSION[' PMA_token '],
             'icon' => 'db_routines.php?server=' . $GLOBALS['server']
                     . '&amp;db=%2$s&amp;item_name=%1$s&amp;item_type=PROCEDURE'
-                    . '&amp;export_item=1&amp;token=' . $GLOBALS['token']
+                    . '&amp;execute_dialog=1&amp;token=' . $_SESSION[' PMA_token ']
         );
         $this->classes = 'procedure';
     }
+
+    /**
+     * Returns the type of the item represented by the node.
+     *
+     * @return string type of the item
+     */
+    protected function getItemType()
+    {
+        return 'procedure';
+    }
 }
 
-?>
