@@ -41,6 +41,7 @@ class ExportJson extends ExportPlugin
         include_once "$props/options/groups/OptionsPropertyRootGroup.class.php";
         include_once "$props/options/groups/OptionsPropertyMainGroup.class.php";
         include_once "$props/options/items/HiddenPropertyItem.class.php";
+        include_once "$props/options/items/BoolPropertyItem.class.php";
 
         $exportPluginProperties = new ExportPluginProperties();
         $exportPluginProperties->setText('JSON');
@@ -61,6 +62,17 @@ class ExportJson extends ExportPlugin
         $leaf = new HiddenPropertyItem();
         $leaf->setName("structure_or_data");
         $generalOptions->addProperty($leaf);
+
+        // JSON_PRETTY_PRINT is available since 5.4.0
+        if (version_compare(PHP_VERSION, '5.4.0', '>=')) {
+            $leaf = new BoolPropertyItem();
+            $leaf->setName('pretty_print');
+            $leaf->setText(
+                __('Output pretty-printed JSON (Use human-readable formatting)')
+            );
+            $generalOptions->addProperty($leaf);
+        }
+
         // add the main group to the root group
         $exportSpecificOptions->addProperty($generalOptions);
 
@@ -69,25 +81,12 @@ class ExportJson extends ExportPlugin
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header
      *
      * @return bool Whether it succeeded
      */
-    public function exportHeader ()
+    public function exportHeader()
     {
         PMA_exportOutputHandler(
             '/**' . $GLOBALS['crlf']
@@ -103,7 +102,7 @@ class ExportJson extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportFooter ()
+    public function exportFooter()
     {
         return true;
     }
@@ -111,13 +110,19 @@ class ExportJson extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader($db, $db_alias = '')
     {
-        PMA_exportOutputHandler('// Database \'' . $db . '\'' . $GLOBALS['crlf']);
+        if (empty($db_alias)) {
+            $db_alias = $db;
+        }
+        PMA_exportOutputHandler(
+            '// Database \'' . $db_alias . '\'' . $GLOBALS['crlf']
+        );
         return true;
     }
 
@@ -128,7 +133,7 @@ class ExportJson extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBFooter ($db)
+    public function exportDBFooter($db)
     {
         return true;
     }
@@ -136,11 +141,13 @@ class ExportJson extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db          Database name
+     * @param string $export_type 'server', 'database', 'table'
+     * @param string $db_alias    Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $export_type, $db_alias = '')
     {
         return true;
     }
@@ -153,11 +160,17 @@ class ExportJson extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
+
         $result = $GLOBALS['dbi']->query(
             $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
         );
@@ -165,11 +178,13 @@ class ExportJson extends ExportPlugin
 
         $columns = array();
         for ($i = 0; $i < $columns_cnt; $i++) {
-            $columns[$i] = stripslashes($GLOBALS['dbi']->fieldName($result, $i));
+            $col_as = $GLOBALS['dbi']->fieldName($result, $i);
+            if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
+                $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
+            }
+            $columns[$i] = stripslashes($col_as);
         }
-        unset($i);
 
-        $buffer = '';
         $record_cnt = 0;
         while ($record = $GLOBALS['dbi']->fetchRow($result)) {
 
@@ -177,7 +192,8 @@ class ExportJson extends ExportPlugin
 
             // Output table name as comment if this is the first record of the table
             if ($record_cnt == 1) {
-                $buffer = '// ' . $db . '.' . $table . $crlf . $crlf;
+                $buffer = $crlf . '// ' . $db_alias . '.' . $table_alias
+                    . $crlf . $crlf;
                 $buffer .= '[';
             } else {
                 $buffer = ', ';
@@ -193,13 +209,21 @@ class ExportJson extends ExportPlugin
                 $data[$columns[$i]] = $record[$i];
             }
 
-            if (! PMA_exportOutputHandler(json_encode($data))) {
+            if (isset($GLOBALS['json_pretty_print'])
+                && $GLOBALS['json_pretty_print']
+            ) {
+                $encoded = json_encode($data, JSON_PRETTY_PRINT);
+            } else {
+                $encoded = json_encode($data);
+            }
+
+            if (! PMA_exportOutputHandler($encoded)) {
                 return false;
             }
         }
 
         if ($record_cnt) {
-            if (! PMA_exportOutputHandler(']')) {
+            if (! PMA_exportOutputHandler(']' . $crlf)) {
                 return false;
             }
         }
@@ -208,4 +232,3 @@ class ExportJson extends ExportPlugin
         return true;
     }
 }
-?>
