@@ -22,6 +22,7 @@ if (! file_exists(TCPDF_INC)) {
 require_once 'libraries/plugins/ExportPlugin.class.php';
 /* Get the PMA_ExportPdf class */
 require_once 'libraries/plugins/export/PMA_ExportPdf.class.php';
+require_once 'libraries/transformations.lib.php';
 
 /**
  * Handles the export for the PDF class
@@ -80,9 +81,8 @@ class ExportPdf extends ExportPlugin
         include_once "$props/plugins/ExportPluginProperties.class.php";
         include_once "$props/options/groups/OptionsPropertyRootGroup.class.php";
         include_once "$props/options/groups/OptionsPropertyMainGroup.class.php";
-        include_once "$props/options/items/MessageOnlyPropertyItem.class.php";
+        include_once "$props/options/items/RadioPropertyItem.class.php";
         include_once "$props/options/items/TextPropertyItem.class.php";
-        include_once "$props/options/items/HiddenPropertyItem.class.php";
 
         $exportPluginProperties = new ExportPluginProperties();
         $exportPluginProperties->setText('PDF');
@@ -101,46 +101,41 @@ class ExportPdf extends ExportPlugin
         $generalOptions = new OptionsPropertyMainGroup();
         $generalOptions->setName("general_opts");
         // create primary items and add them to the group
-        $leaf = new MessageOnlyPropertyItem();
-        $leaf->setName("explanation");
-        $leaf->setText(
-            __('(Generates a report containing the data of a single table)')
-        );
-        $generalOptions->addProperty($leaf);
         $leaf = new TextPropertyItem();
         $leaf->setName("report_title");
         $leaf->setText(__('Report title:'));
         $generalOptions->addProperty($leaf);
-        $leaf = new HiddenPropertyItem();
-        $leaf->setName("structure_or_data");
-        $generalOptions->addProperty($leaf);
-        // add the main group to the root group
+        // add the group to the root group
         $exportSpecificOptions->addProperty($generalOptions);
 
+        // what to dump (structure/data/both) main group
+        $dumpWhat = new OptionsPropertyMainGroup();
+        $dumpWhat->setName("dump_what");
+        $dumpWhat->setText(__('Dump table'));
+        $leaf = new RadioPropertyItem();
+        $leaf->setName("structure_or_data");
+        $leaf->setValues(
+            array(
+                'structure' => __('structure'),
+                'data' => __('data'),
+                'structure_and_data' => __('structure and data')
+            )
+        );
+        $dumpWhat->addProperty($leaf);
+        // add the group to the root group
+        $exportSpecificOptions->addProperty($dumpWhat);
+
         // set the options for the export plugin property item
         $exportPluginProperties->setOptions($exportSpecificOptions);
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header
      *
      * @return bool Whether it succeeded
      */
-    public function exportHeader ()
+    public function exportHeader()
     {
         $pdf_report_title = $this->_getPdfReportTitle();
         $pdf = $this->_getPdf();
@@ -158,7 +153,7 @@ class ExportPdf extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportFooter ()
+    public function exportFooter()
     {
         $pdf = $this->_getPdf();
 
@@ -173,11 +168,12 @@ class ExportPdf extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader($db, $db_alias = '')
     {
         return true;
     }
@@ -189,7 +185,7 @@ class ExportPdf extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBFooter ($db)
+    public function exportDBFooter($db)
     {
         return true;
     }
@@ -197,11 +193,13 @@ class ExportPdf extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db          Database name
+     * @param string $export_type 'server', 'database', 'table'
+     * @param string $db_alias    Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $export_type, $db_alias = '')
     {
         return true;
     }
@@ -213,20 +211,119 @@ class ExportPdf extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
         $pdf = $this->_getPdf();
-
-        $attr = array('currentDb' => $db, 'currentTable' => $table);
+        $attr = array(
+            'currentDb' => $db, 'currentTable' => $table,
+            'dbAlias' => $db_alias, 'tableAlias' => $table_alias,
+            'aliases' => $aliases
+        );
         $pdf->setAttributes($attr);
+        $pdf->purpose = __('Dumping data');
         $pdf->mysqlReport($sql_query);
 
         return true;
     } // end of the 'PMA_exportData()' function
 
+    /**
+     * Outputs table structure
+     *
+     * @param string $db          database name
+     * @param string $table       table name
+     * @param string $crlf        the end of line sequence
+     * @param string $error_url   the url to go back in case of error
+     * @param string $export_mode 'create_table', 'triggers', 'create_view',
+     *                                'stand_in'
+     * @param string $export_type 'server', 'database', 'table'
+     * @param bool   $do_relation whether to include relation comments
+     * @param bool   $do_comments whether to include the pmadb-style column
+     *                                comments as comments in the structure;
+     *                                this is deprecated but the parameter is
+     *                                left here because export.php calls
+     *                                PMA_exportStructure() also for other
+     *                                export types which use this parameter
+     * @param bool   $do_mime     whether to include mime comments
+     * @param bool   $dates       whether to include creation/update/check dates
+     * @param array  $aliases     aliases for db/table/columns
+     *
+     * @return bool Whether it succeeded
+     */
+    public function exportStructure(
+        $db,
+        $table,
+        $crlf,
+        $error_url,
+        $export_mode,
+        $export_type,
+        $do_relation = false,
+        $do_comments = false,
+        $do_mime = false,
+        $dates = false,
+        $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
+        $pdf = $this->_getPdf();
+        // getting purpose to show at top
+        switch($export_mode) {
+        case 'create_table':
+            $purpose = __('Table structure');
+            break;
+        case 'triggers':
+            $purpose = __('Triggers');
+            break;
+        case 'create_view':
+            $purpose = __('View structure');
+            break;
+        case 'stand_in':
+            $purpose = __('Stand in');
+        } // end switch
+
+        $attr = array(
+            'currentDb' => $db, 'currentTable' => $table,
+            'dbAlias' => $db_alias, 'tableAlias' => $table_alias,
+            'aliases' => $aliases, 'purpose' => $purpose
+        );
+        $pdf->setAttributes($attr);
+        /**
+         * comment display set true as presently in pdf
+         * format, no option is present to take user input.
+         */
+        $do_comments = true;
+        switch($export_mode) {
+        case 'create_table':
+            $pdf->getTableDef(
+                $db, $table, $do_relation, $do_comments, $do_mime, false, $aliases
+            );
+            break;
+        case 'triggers':
+            $pdf->getTriggers($db, $table);
+            break;
+        case 'create_view':
+            $pdf->getTableDef(
+                $db, $table, $do_relation, $do_comments, $do_mime, false, $aliases
+            );
+            break;
+        case 'stand_in':
+            /* export a stand-in definition to resolve view dependencies
+             * Yet to develop this function
+             * $pdf->getTableDefStandIn($db, $table, $crlf);
+             */
+        } // end switch
+
+        return true;
+    }
+
 
     /* ~~~~~~~~~~~~~~~~~~~~ Getters and Setters ~~~~~~~~~~~~~~~~~~~~ */
 
@@ -244,7 +341,7 @@ class ExportPdf extends ExportPlugin
     /**
      * Instantiates the PMA_ExportPdf class
      *
-     * @param string $pdf PMA_ExportPdf instance
+     * @param PMA_ExportPdf $pdf The instance
      *
      * @return void
      */
@@ -275,4 +372,3 @@ class ExportPdf extends ExportPlugin
         $this->_pdfReportTitle = $pdfReportTitle;
     }
 }
-?>
