@@ -69,25 +69,12 @@ class ExportPhparray extends ExportPlugin
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header
      *
      * @return bool Whether it succeeded
      */
-    public function exportHeader ()
+    public function exportHeader()
     {
         PMA_exportOutputHandler(
             '<?php' . $GLOBALS['crlf']
@@ -104,7 +91,7 @@ class ExportPhparray extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportFooter ()
+    public function exportFooter()
     {
         return true;
     }
@@ -112,15 +99,19 @@ class ExportPhparray extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader($db, $db_alias = '')
     {
+        if (empty($db_alias)) {
+            $db_alias = $db;
+        }
         PMA_exportOutputHandler(
             '//' . $GLOBALS['crlf']
-            . '// Database ' . PMA_Util::backquote($db)
+            . '// Database ' . PMA_Util::backquote($db_alias)
             . $GLOBALS['crlf'] . '//' . $GLOBALS['crlf']
         );
         return true;
@@ -133,7 +124,7 @@ class ExportPhparray extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBFooter ($db)
+    public function exportDBFooter($db)
     {
         return true;
     }
@@ -141,11 +132,13 @@ class ExportPhparray extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db          Database name
+     * @param string $export_type 'server', 'database', 'table'
+     * @param string $db_alias    Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $export_type, $db_alias = '')
     {
         return true;
     }
@@ -158,11 +151,17 @@ class ExportPhparray extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
+
         $result = $GLOBALS['dbi']->query(
             $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
         );
@@ -170,22 +169,27 @@ class ExportPhparray extends ExportPlugin
         $columns_cnt = $GLOBALS['dbi']->numFields($result);
         $columns = array();
         for ($i = 0; $i < $columns_cnt; $i++) {
-            $columns[$i] = stripslashes($GLOBALS['dbi']->fieldName($result, $i));
+            $col_as = $GLOBALS['dbi']->fieldName($result, $i);
+            if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
+                $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
+            }
+            $columns[$i] = stripslashes($col_as);
         }
-        unset($i);
 
         // fix variable names (based on
         // http://www.php.net/manual/language.variables.basics.php)
         if (! preg_match(
             '/^[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*$/',
-            $table
+            $table_alias
         )) {
             // fix invalid characters in variable names by replacing them with
             // underscores
-            $tablefixed = preg_replace('/[^a-zA-Z0-9_\x7f-\xff]/', '_', $table);
+            $tablefixed = preg_replace(
+                '/[^a-zA-Z0-9_\x7f-\xff]/', '_', $table_alias
+            );
 
             // variable name must not start with a number or dash...
-            if (preg_match('/^[a-zA-Z_\x7f-\xff]/', $tablefixed) == false) {
+            if (preg_match('/^[a-zA-Z_\x7f-\xff]/', $tablefixed) === 0) {
                 $tablefixed = '_' . $tablefixed;
             }
         } else {
@@ -196,8 +200,8 @@ class ExportPhparray extends ExportPlugin
         $record_cnt = 0;
         // Output table name as comment
         $buffer .= $crlf . '// '
-            . PMA_Util::backquote($db) . '.'
-            . PMA_Util::backquote($table) . $crlf;
+            . PMA_Util::backquote($db_alias) . '.'
+            . PMA_Util::backquote($table_alias) . $crlf;
         $buffer .= '$' . $tablefixed . ' = array(';
 
         while ($record = $GLOBALS['dbi']->fetchRow($result)) {
@@ -227,4 +231,3 @@ class ExportPhparray extends ExportPlugin
         return true;
     }
 }
-?>
