@@ -9,7 +9,7 @@
 if (! defined('PHPMYADMIN')) {
     exit;
 }
-if (! strlen($GLOBALS['db'])) { /* Can't do server export */
+if (!/*overload*/mb_strlen($GLOBALS['db'])) { /* Can't do server export */
     $GLOBALS['skip_import'] = true;
     return;
 }
@@ -147,26 +147,13 @@ class ExportXml extends ExportPlugin
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header. It is the first method to be called, so all
      * the required variables are initialized here.
      *
      * @return bool Whether it succeeded
      */
-    public function exportHeader ()
+    public function exportHeader()
     {
         $this->initSpecificVariables();
         global $crlf, $cfg, $db;
@@ -181,7 +168,7 @@ class ExportXml extends ExportPlugin
         $export_data = isset($GLOBALS['xml_export_contents']) ? true : false;
 
         if ($GLOBALS['output_charset_conversion']) {
-            $charset = $GLOBALS['charset_of_file'];
+            $charset = $GLOBALS['charset'];
         } else {
             $charset = 'utf-8';
         }
@@ -190,7 +177,7 @@ class ExportXml extends ExportPlugin
                .  '<!--' . $crlf
                .  '- phpMyAdmin XML Dump' . $crlf
                .  '- version ' . PMA_VERSION . $crlf
-               .  '- http://www.phpmyadmin.net' . $crlf
+               .  '- https://www.phpmyadmin.net' . $crlf
                .  '-' . $crlf
                .  '- ' . __('Host:') . ' ' . $cfg['Server']['host'];
         if (! empty($cfg['Server']['port'])) {
@@ -250,7 +237,7 @@ class ExportXml extends ExportPlugin
                 );
                 $tbl =  $result[$table][1];
 
-                $is_view = PMA_Table::isView($db, $table);
+                $is_view = $GLOBALS['dbi']->getTable($db, $table)->isView();
 
                 if ($is_view) {
                     $type = 'view';
@@ -287,7 +274,7 @@ class ExportXml extends ExportPlugin
                                 . $trigger['name'] . '">' . $crlf;
 
                             // Do some formatting
-                            $code = substr(rtrim($code), 0, -3);
+                            $code = /*overload*/mb_substr(rtrim($code), 0, -3);
                             $code = "                " . htmlspecialchars($code);
                             $code = str_replace("\n", "\n                ", $code);
 
@@ -362,31 +349,29 @@ class ExportXml extends ExportPlugin
             if (isset($GLOBALS['xml_export_events'])
                 && $GLOBALS['xml_export_events']
             ) {
-                if (PMA_MYSQL_INT_VERSION > 50100) {
-                    // Export events
-                    $events = $GLOBALS['dbi']->fetchResult(
-                        "SELECT EVENT_NAME FROM information_schema.EVENTS "
-                        . "WHERE EVENT_SCHEMA='" . PMA_Util::sqlAddslashes($db) . "'"
-                    );
-                    if ($events) {
-                        foreach ($events as $event) {
-                            $head .= '            <pma:event name="'
-                                . $event . '">' . $crlf;
+                // Export events
+                $events = $GLOBALS['dbi']->fetchResult(
+                    "SELECT EVENT_NAME FROM information_schema.EVENTS "
+                    . "WHERE EVENT_SCHEMA='" . PMA_Util::sqlAddslashes($db) . "'"
+                );
+                if ($events) {
+                    foreach ($events as $event) {
+                        $head .= '            <pma:event name="'
+                            . $event . '">' . $crlf;
 
-                            $sql = $GLOBALS['dbi']->getDefinition(
-                                $db, 'EVENT', $event
-                            );
-                            $sql = rtrim($sql);
-                            $sql = "                " . htmlspecialchars($sql);
-                            $sql = str_replace("\n", "\n                ", $sql);
+                        $sql = $GLOBALS['dbi']->getDefinition(
+                            $db, 'EVENT', $event
+                        );
+                        $sql = rtrim($sql);
+                        $sql = "                " . htmlspecialchars($sql);
+                        $sql = str_replace("\n", "\n                ", $sql);
 
-                            $head .= $sql . $crlf;
-                            $head .= '            </pma:event>' . $crlf;
-                        }
-
-                        unset($event);
-                        unset($events);
+                        $head .= $sql . $crlf;
+                        $head .= '            </pma:event>' . $crlf;
                     }
+
+                    unset($event);
+                    unset($events);
                 }
             }
 
@@ -408,7 +393,7 @@ class ExportXml extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportFooter ()
+    public function exportFooter()
     {
         $foot = '</pma_xml_export>';
 
@@ -418,21 +403,26 @@ class ExportXml extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader($db, $db_alias = '')
     {
         global $crlf;
 
+        if (empty($db_alias)) {
+            $db_alias = $db;
+        }
         if (isset($GLOBALS['xml_export_contents'])
             && $GLOBALS['xml_export_contents']
         ) {
             $head = '    <!--' . $crlf
-                  . '    - ' . __('Database:') . ' ' .  '\'' . $db . '\'' . $crlf
-                  . '    -->' . $crlf
-                  . '    <database name="' . htmlspecialchars($db) . '">' . $crlf;
+                  . '    - ' . __('Database:') . ' ' .  '\''
+                  . $db_alias . '\'' . $crlf
+                  . '    -->' . $crlf . '    <database name="'
+                  . htmlspecialchars($db_alias) . '">' . $crlf;
 
             return PMA_exportOutputHandler($head);
         } else {
@@ -447,7 +437,7 @@ class ExportXml extends ExportPlugin
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBFooter ($db)
+    public function exportDBFooter($db)
     {
         global $crlf;
 
@@ -463,11 +453,13 @@ class ExportXml extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db          Database name
+     * @param string $export_type 'server', 'database', 'table'
+     * @param string $db_alias    Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $export_type, $db_alias = '')
     {
         return true;
     }
@@ -480,11 +472,21 @@ class ExportXml extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData ($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        // Do not export data for merge tables
+        if ($GLOBALS['dbi']->getTable($db, $table)->isMerge()) {
+            return true;
+        }
+
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
         if (isset($GLOBALS['xml_export_contents'])
             && $GLOBALS['xml_export_contents']
         ) {
@@ -499,22 +501,29 @@ class ExportXml extends ExportPlugin
             }
             unset($i);
 
-            $buffer = '        <!-- ' . __('Table') . ' ' . $table . ' -->' . $crlf;
+            $buffer = '        <!-- ' . __('Table') . ' '
+                . $table_alias . ' -->' . $crlf;
             if (! PMA_exportOutputHandler($buffer)) {
                 return false;
             }
 
             while ($record = $GLOBALS['dbi']->fetchRow($result)) {
                 $buffer = '        <table name="'
-                    . htmlspecialchars($table) . '">' . $crlf;
+                    . htmlspecialchars($table_alias) . '">' . $crlf;
                 for ($i = 0; $i < $columns_cnt; $i++) {
+                    $col_as = $columns[$i];
+                    if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])
+                    ) {
+                        $col_as
+                            = $aliases[$db]['tables'][$table]['columns'][$col_as];
+                    }
                     // If a cell is NULL, still export it to preserve
                     // the XML structure
                     if (! isset($record[$i]) || is_null($record[$i])) {
                         $record[$i] = 'NULL';
                     }
                     $buffer .= '            <column name="'
-                        . htmlspecialchars($columns[$i]) . '">'
+                        . htmlspecialchars($col_as) . '">'
                         . htmlspecialchars((string)$record[$i])
                         .  '</column>' . $crlf;
                 }
@@ -578,4 +587,3 @@ class ExportXml extends ExportPlugin
         $this->_tables = $tables;
     }
 }
-?>
