@@ -103,19 +103,6 @@ class ImportOds extends ImportPlugin
         $this->properties = $importPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Handles the whole import logic
      *
@@ -176,6 +163,7 @@ class ImportOds extends ImportPlugin
             );
             $GLOBALS['error'] = true;
         } else {
+            /** @var SimpleXMLElement $root */
             $root = $xml->children('office', true)->{'body'}->{'spreadsheet'};
             if (empty($root)) {
                 $sheets = array();
@@ -200,17 +188,23 @@ class ImportOds extends ImportPlugin
         $rows = array();
 
         /* Iterate over tables */
+        /** @var SimpleXMLElement $sheet */
         foreach ($sheets as $sheet) {
             $col_names_in_first_row = isset($_REQUEST['ods_col_names']);
 
             /* Iterate over rows */
+            /** @var SimpleXMLElement $row */
             foreach ($sheet as $row) {
                 $type = $row->getName();
                 if (strcmp('table-row', $type)) {
                     continue;
                 }
                 /* Iterate over columns */
+                $cellCount = count($row);
+                $a = 0;
+                /** @var SimpleXMLElement $cell */
                 foreach ($row as $cell) {
+                    $a++;
                     $text = $cell->children('text', true);
                     $cell_attrs = $cell->attributes('office', true);
 
@@ -234,8 +228,8 @@ class ImportOds extends ImportPlugin
                         continue;
                     }
 
-                    /* Number of blank columns repeated */
-                    if ($col_count >= count($row->children('table', true)) - 1) {
+                    // skip empty repeats in the last row
+                    if ($a == $cellCount) {
                         continue;
                     }
 
@@ -340,9 +334,10 @@ class ImportOds extends ImportPlugin
         /**
          * Bring accumulated rows into the corresponding table
          */
-        $num_tbls = count($tables);
-        for ($i = 0; $i < $num_tbls; ++$i) {
-            for ($j = 0; $j < count($rows); ++$j) {
+        $num_tables = count($tables);
+        for ($i = 0; $i < $num_tables; ++$i) {
+            $num_rows = count($rows);
+            for ($j = 0; $j < $num_rows; ++$j) {
                 if (strcmp($tables[$i][TBL_NAME], $rows[$j][TBL_NAME])) {
                     continue;
                 }
@@ -381,13 +376,7 @@ class ImportOds extends ImportPlugin
          */
 
         /* Set database name to the currently selected one, if applicable */
-        if (strlen($db)) {
-            $db_name = $db;
-            $options = array('create_db' => false);
-        } else {
-            $db_name = 'ODS_DB';
-            $options = null;
-        }
+        list($db_name, $options) = $this->getDbnameAndOptions($db, 'ODS_DB');
 
         /* Non-applicable parameters */
         $create = null;
