@@ -27,7 +27,7 @@ class PMA_ShapeFile extends ShapeFile
      *
      * @return boolean whether the 'dbase' extension is loaded
      */
-    function _isDbaseLoaded()
+    private function _isDbaseLoaded()
     {
         return extension_loaded('dbase');
     }
@@ -36,12 +36,12 @@ class PMA_ShapeFile extends ShapeFile
      * Loads ESRI shape data from the imported file
      *
      * @param string $FileName not used, it's here only to match the method
-     *                         signature of the method being overidden
+     *                         signature of the method being overridden
      *
      * @return void
      * @see ShapeFile::loadFromFile()
      */
-    function loadFromFile($FileName)
+    public function loadFromFile($FileName)
     {
         $this->_loadHeaders();
         $this->_loadRecords();
@@ -56,7 +56,7 @@ class PMA_ShapeFile extends ShapeFile
      * @return void
      * @see ShapeFile::_loadHeaders()
      */
-    function _loadHeaders()
+    public function _loadHeaders()
     {
         ImportShp::readFromBuffer(24);
         $this->fileLength = loadData("N", ImportShp::readFromBuffer(4));
@@ -81,7 +81,7 @@ class PMA_ShapeFile extends ShapeFile
      * @return boolean|void
      * @see ShapeFile::_loadRecords()
      */
-    function _loadRecords()
+    public function _loadRecords()
     {
         global $eof;
         ImportShp::readFromBuffer(32);
@@ -99,4 +99,3 @@ class PMA_ShapeFile extends ShapeFile
         }
     }
 }
-?>
