@@ -46,12 +46,12 @@ function PMA_getHtmlForMasterReplication()
         $html .= '<legend>' . __('Master replication') . '</legend>';
         $html .= __('This server is configured as master in a replication process.');
         $html .= '<ul>';
-        $html .= '  <li><a href="#" id="master_status_href">';
+        $html .= '  <li><a href="#master_status_href" id="master_status_href">';
         $html .= __('Show master status') . '</a>';
         $html .= PMA_getHtmlForReplicationStatusTable('master', true, false);
         $html .= '  </li>';
 
-        $html .= '  <li><a href="#" id="master_slaves_href">';
+        $html .= '  <li><a href="#master_slaves_href" id="master_slaves_href">';
         $html .= __('Show connected slaves') . '</a>';
         $html .= PMA_getHtmlForReplicationSlavesTable(true);
         $html .= '  </li>';
@@ -87,12 +87,12 @@ function PMA_getHtmlForMasterConfiguration()
     $html  = '<fieldset>';
     $html .= '<legend>' . __('Master configuration') . '</legend>';
     $html .= __(
-        'This server is not configured as master server in a '
+        'This server is not configured as a master server in a '
         . 'replication process. You can choose from either replicating '
-        . 'all databases and ignoring certain (useful if you want to replicate '
-        . 'majority of databases) or you can choose to ignore all databases by '
-        . 'default and allow only certain databases to be replicated. '
-        . 'Please select the mode:'
+        . 'all databases and ignoring some of them (useful if you want to '
+        . 'replicate a majority of the databases) or you can choose to ignore '
+        . 'all databases by default and allow only certain databases to be '
+        . 'replicated. Please select the mode:'
     ) . '<br /><br />';
 
     $html .= '<select name="db_type" id="db_type">';
@@ -139,6 +139,29 @@ function PMA_getHtmlForSlaveConfiguration(
 ) {
     $html  = '<fieldset>';
     $html .= '<legend>' . __('Slave replication') . '</legend>';
+    /**
+     * check for multi-master replication functionality
+     */
+    $server_slave_multi_replication = $GLOBALS['dbi']->fetchResult(
+        'SHOW ALL SLAVES STATUS'
+    );
+    if ($server_slave_multi_replication) {
+        $html .= __('Master connection:');
+        $html .= '<form method="get" action="server_replication.php">';
+        $html .= PMA_URL_getHiddenInputs($GLOBALS['url_params']);
+        $html .= ' <select name="master_connection">';
+        $html .= '<option value="">' . __('Default') . '</option>';
+        foreach ($server_slave_multi_replication as $server) {
+            $html .= '<option' . (isset($_REQUEST['master_connection'])
+                && $_REQUEST['master_connection'] == $server['Connection_name'] ?
+                    ' selected="selected"' : '') . '>' . $server['Connection_name']
+                . '</option>';
+        }
+        $html .= '</select>';
+        $html .= ' <input type="submit" value="' . __('Go') . '" id="goButton" />';
+        $html .= '</form>';
+        $html .= '<br /><br />';
+    }
     if ($server_slave_status) {
         $html .= '<div id="slave_configuration_gui">';
 
@@ -183,6 +206,7 @@ function PMA_getHtmlForSlaveConfiguration(
             . PMA_URL_getCommon($_url_params);
 
         $_url_params = $GLOBALS['url_params'];
+        $_url_params['sr_take_action'] = true;
         $_url_params['sr_slave_skip_error'] = true;
         $slave_skip_error_link = 'server_replication.php'
             . PMA_URL_getCommon($_url_params);
@@ -205,15 +229,18 @@ function PMA_getHtmlForSlaveConfiguration(
         $reconfiguremaster_link = 'server_replication.php'
             . PMA_URL_getCommon($_url_params);
 
-        $html .= __('Server is configured as slave in a replication process. Would you like to:');
+        $html .= __(
+            'Server is configured as slave in a replication process. Would you ' .
+            'like to:'
+        );
         $html .= '<br />';
         $html .= '<ul>';
-        $html .= ' <li><a href="#" id="slave_status_href">';
+        $html .= ' <li><a href="#slave_status_href" id="slave_status_href">';
         $html .= __('See slave status table') . '</a>';
         $html .= PMA_getHtmlForReplicationStatusTable('slave', true, false);
         $html .= ' </li>';
 
-        $html .= ' <li><a href="#" id="slave_control_href">';
+        $html .= ' <li><a href="#slave_control_href" id="slave_control_href">';
         $html .= __('Control slave:') . '</a>';
         $html .= ' <div id="slave_control_gui" style="display: none">';
         $html .= '  <ul>';
@@ -222,7 +249,8 @@ function PMA_getHtmlForSlaveConfiguration(
                    $server_slave_replication[0]['Slave_SQL_Running'] == 'No')
                  ? __('Full start')
                  : __('Full stop')) . ' </a></li>';
-        $html .= '   <li><a href="' . $slave_control_reset_link . '">';
+        $html .= '   <li><a class="ajax" id="reset_slave"'
+            . ' href="' . $slave_control_reset_link . '">';
         $html .= __('Reset slave') . '</a></li>';
         if ($server_slave_replication[0]['Slave_SQL_Running'] == 'No') {
             $html .= '   <li><a href="' . $slave_control_sql_link . '">';
@@ -276,7 +304,8 @@ function PMA_getHtmlForSlaveConfiguration(
  */
 function PMA_getHtmlForSlaveErrorManagement($slave_skip_error_link)
 {
-    $html  = '<a href="#" id="slave_errormanagement_href">';
+    $html  = '<a href="#slave_errormanagement_href" '
+        . 'id="slave_errormanagement_href">';
     $html .= __('Error management:') . '</a>';
     $html .= ' <div id="slave_errormanagement_gui" style="display: none">';
     $html .= PMA_Message::error(
@@ -346,9 +375,10 @@ function PMA_getHtmlForReplicationDbMultibox()
         $multi_values .= $current_db . '</option>';
     } // end while
 
-    $multi_values .= '</select>';
-    $multi_values .= '<br /><a href="#" id="db_reset_href">';
-    $multi_values .= __('Uncheck All') . '</a>';
+    $multi_values .= '</select><br />';
+    $multi_values .= '<a href="#" id="db_select_href">' . __('Select all') . '</a>';
+    $multi_values .= '&nbsp;/&nbsp;';
+    $multi_values .= '<a href="#" id="db_reset_href">' . __('Unselect all') . '</a>';
 
     return $multi_values;
 }
@@ -360,7 +390,6 @@ function PMA_getHtmlForReplicationDbMultibox()
  *
  * @return String HTML code
  */
-
 function PMA_getHtmlForReplicationChangeMaster($submitname)
 {
     $html = '';
@@ -525,7 +554,6 @@ function PMA_getHtmlForReplicationStatusTable($type, $hidden = false, $title = t
         $html .= '     </td>';
         $html .= '     <td class="value">';
 
-
         // TODO change to regexp or something, to allow for negative match
         if (isset(${"{$type}_variables_alerts"}[$variable])
             && ${"{$type}_variables_alerts"}[$variable] == ${"server_{$type}_replication"}[0][$variable]
@@ -533,8 +561,7 @@ function PMA_getHtmlForReplicationStatusTable($type, $hidden = false, $title = t
             $html .= '<span class="attention">';
 
         } elseif (isset(${"{$type}_variables_oks"}[$variable])
-            && ${"{$type}_variables_oks"}[$variable]
-            == ${"server_{$type}_replication"}[0][$variable]
+            && ${"{$type}_variables_oks"}[$variable] == ${"server_{$type}_replication"}[0][$variable]
         ) {
             $html .= '<span class="allfine">';
         } else {
@@ -626,7 +653,6 @@ function PMA_getHtmlForReplicationSlavesTable($hidden = false)
  *
  * @return array   username length, hostname length
  */
-
 function PMA_replicationGetUsernameHostnameLength()
 {
     $fields_info = $GLOBALS['dbi']->getColumns('mysql', 'user');
@@ -661,7 +687,9 @@ function PMA_getHtmlForReplicationMasterAddSlaveuser()
     list($username_length, $hostname_length)
         = PMA_replicationGetUsernameHostnameLength();
 
-    if (isset($_REQUEST['username']) && strlen($_REQUEST['username']) === 0) {
+    if (isset($_REQUEST['username'])
+        && /*overload*/mb_strlen($_REQUEST['username']) === 0
+    ) {
         $GLOBALS['pred_username'] = 'any';
     }
     $html .= '<div id="master_addslaveuser_gui">';
@@ -685,7 +713,10 @@ function PMA_getHtmlForReplicationMasterAddSlaveuser()
         $thishost = str_replace(
             "'",
             '',
-            substr($_current_user, (strrpos($_current_user, '@') + 1))
+            /*overload*/mb_substr(
+                $_current_user,
+                (/*overload*/mb_strrpos($_current_user, '@') + 1)
+            )
         );
         if ($thishost == 'localhost' || $thishost == '127.0.0.1') {
             unset($thishost);
@@ -706,7 +737,7 @@ function PMA_getHtmlForReplicationMasterAddSlaveuser()
 
     // when we start editing a user, $GLOBALS['pred_hostname'] is not defined
     if (! isset($GLOBALS['pred_hostname']) && isset($_REQUEST['hostname'])) {
-        switch (strtolower($_REQUEST['hostname'])) {
+        switch (/*overload*/mb_strtolower($_REQUEST['hostname'])) {
         case 'localhost':
         case '127.0.0.1':
             $GLOBALS['pred_hostname'] = 'localhost';
@@ -862,7 +893,7 @@ function PMA_getHtmlForTableInfoForm($hostname_length)
         . '</div>'
         . '<div class="item">'
         . '<label for="button_generate_password">'
-        . '    ' . __('Generate Password:')
+        . '    ' . __('Generate password:')
         . '</label>'
         . '<span class="options">'
         . '    <input type="button" class="button" '
@@ -926,12 +957,14 @@ function PMA_handleControlRequest()
                 $response->isSuccess($result);
                 $response->addJSON(
                     'message',
-                    $result ? PMA_Message::success($messageSuccess) : PMA_Message::error($messageError)
+                    $result
+                    ? PMA_Message::success($messageSuccess)
+                    : PMA_Message::error($messageError)
                 );
             } else {
                 PMA_sendHeaderLocation(
                     $GLOBALS['cfg']['PmaAbsoluteUri'] . 'server_replication.php'
-                    . PMA_URL_getCommon($GLOBALS['url_params'], '&')
+                    . PMA_URL_getCommon($GLOBALS['url_params'], 'text')
                 );
             }
         }
@@ -953,7 +986,7 @@ function PMA_handleRequestForSlaveChangeMaster()
     $_SESSION['replication']['m_hostname'] = $sr['hostname']
         = PMA_Util::sqlAddSlashes($_REQUEST['hostname']);
     $_SESSION['replication']['m_port']     = $sr['port']
-        = PMA_Util::sqlAddSlashes($_REQUEST['port']);
+        = PMA_Util::sqlAddSlashes($_REQUEST['text_port']);
     $_SESSION['replication']['m_correct']  = '';
     $_SESSION['replication']['sr_action_status'] = 'error';
     $_SESSION['replication']['sr_action_info'] = __('Unknown error');
@@ -1063,4 +1096,3 @@ function PMA_handleRequestForSlaveSkipError()
 
     return $result;
 }
-?>
