@@ -46,11 +46,45 @@ if (! defined('PHPMYADMIN')) {
  */
 $GLOBALS['special_schema_links'] = array(
     'mysql' => array(
-        'db' => array(
-            'db' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
+        'columns_priv' => array(
+            'user' => array(
+                'link_param' => 'username',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'hostname',
+                        'column_name' => 'host'
+                    )
+                ),
+                'default_page' => 'server_privileges.php'
             ),
+            'table_name' => array(
+                'link_param' => 'table',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'Db'
+                    ),
+                ),
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
+            ),
+            'column_name' => array(
+                'link_param' => 'field',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'Db'
+                    ),
+                    1 => array(
+                        'param_info' => 'table',
+                        'column_name' => 'Table_name'
+                    )
+                ),
+                'default_page' => 'tbl_structure.php?change_column=1'
+            ),
+        ),
+        'db' => array(
             'user' => array(
                 'link_param' => 'username',
                 'link_dependancy_params' => array(
@@ -62,11 +96,152 @@ $GLOBALS['special_schema_links'] = array(
                 'default_page' => 'server_privileges.php'
             )
         ),
+        'event' => array(
+            'name' => array(
+                'link_param' => 'item_name',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'db'
+                    )
+                ),
+                'default_page' => 'db_events.php?edit_item=1'
+            ),
+
+        ),
+        'innodb_index_stats' => array(
+            'table_name' => array(
+                'link_param' => 'table',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'database_name'
+                    ),
+                ),
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
+            ),
+            'index_name' => array(
+                'link_param' => 'index',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'database_name'
+                    ),
+                    1 => array(
+                        'param_info' => 'table',
+                        'column_name' => 'table_name'
+                    )
+                ),
+                'default_page' => 'tbl_structure.php'
+            ),
+        ),
+        'innodb_table_stats' => array(
+            'table_name' => array(
+                'link_param' => 'table',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'database_name'
+                    ),
+                ),
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
+            ),
+        ),
         'proc' => array(
-            'db' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
+            'name' => array(
+                'link_param' => 'item_name',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'db'
+                    ),
+                    1 => array(
+                        'param_info' => 'item_type',
+                        'column_name' => 'type'
+                    )
+                ),
+                'default_page' => 'db_routines.php?edit_item=1'
+            ),
+            'specific_name' => array(
+                'link_param' => 'item_name',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'db'
+                    ),
+                    1 => array(
+                        'param_info' => 'item_type',
+                        'column_name' => 'type'
+                    )
+                ),
+                'default_page' => 'db_routines.php?edit_item=1'
+            ),
+        ),
+        'proc_priv' => array(
+            'user' => array(
+                'link_param' => 'username',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'hostname',
+                        'column_name' => 'Host'
+                    )
+                ),
+                'default_page' => 'server_privileges.php'
+            ),
+            'routine_name' => array(
+                'link_param' => 'item_name',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'Db'
+                    ),
+                    1 => array(
+                        'param_info' => 'item_type',
+                        'column_name' => 'Routine_type'
+                    )
+                ),
+                'default_page' => 'db_routines.php?edit_item=1'
+            ),
+        ),
+        'proxies_priv' => array(
+            'user' => array(
+                'link_param' => 'username',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'hostname',
+                        'column_name' => 'Host'
+                    )
+                ),
+                'default_page' => 'server_privileges.php'
+            ),
+        ),
+        'tables_priv' => array(
+            'user' => array(
+                'link_param' => 'username',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'hostname',
+                        'column_name' => 'Host'
+                    )
+                ),
+                'default_page' => 'server_privileges.php'
+            ),
+            'table_name' => array(
+                'link_param' => 'table',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'Db'
+                    ),
+                ),
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
+            ),
         ),
         'user' => array(
             'user' => array(
@@ -83,10 +258,6 @@ $GLOBALS['special_schema_links'] = array(
     ),
     'information_schema' => array(
         'columns' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
             'table_name' => array(
                 'link_param' => 'table',
                 'link_dependancy_params' => array(
@@ -95,14 +266,12 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
             'column_name' => array(
-                'link_param' => array(
-                    'sql_query',
-                    'table_schema',
-                    'table_name'
-                ),
+                'link_param' => 'field',
                 'link_dependancy_params' => array(
                     0 => array(
                         'param_info' => 'db',
@@ -113,25 +282,7 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_name'
                     )
                 ),
-                'default_page' => 'sql.php'
-            )
-        ),
-        'column_privileges' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        ),
-        'events' => array(
-            'event_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        ),
-        'files' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
+                'default_page' => 'tbl_structure.php?change_column=1'
             )
         ),
         'key_column_usage' => array(
@@ -143,14 +294,12 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'constraint_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
             'column_name' => array(
-                'link_param' => array(
-                    'sql_query',
-                    'table_schema',
-                    'table_name'
-                ),
+                'link_param' => 'field',
                 'link_dependancy_params' => array(
                     0 => array(
                         'param_info' => 'db',
@@ -161,19 +310,7 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_name'
                     )
                 ),
-                'default_page' => 'sql.php'
-            ),
-            'constraint_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'referenced_table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
+                'default_page' => 'tbl_structure.php?change_column=1'
             ),
             'referenced_table_name' => array(
                 'link_param' => 'table',
@@ -183,14 +320,12 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'referenced_table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
             'referenced_column_name' => array(
-                'link_param' => array(
-                    'sql_query',
-                    'referenced_table_schema',
-                    'referenced_table_name'
-                ),
+                'link_param' => 'field',
                 'link_dependancy_params' => array(
                     0 => array(
                         'param_info' => 'db',
@@ -201,20 +336,10 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'referenced_table_name'
                     )
                 ),
-                'default_page' => 'sql.php'
-            )
-        ),
-        'parameters' => array(
-            'specific_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
+                'default_page' => 'tbl_structure.php?change_column=1'
             )
         ),
         'partitions' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
             'table_name' => array(
                 'link_param' => 'table',
                 'link_dependancy_params' => array(
@@ -223,14 +348,12 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             )
         ),
         'processlist' => array(
-            'db' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
             'user' => array(
                 'link_param' => 'username',
                 'link_dependancy_params' => array(
@@ -243,14 +366,6 @@ $GLOBALS['special_schema_links'] = array(
             )
         ),
         'referential_constraints' => array(
-            'constraint_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'unique_constraint_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
             'table_name' => array(
                 'link_param' => 'table',
                 'link_dependancy_params' => array(
@@ -259,7 +374,9 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'constraint_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
             'referenced_table_name' => array(
                 'link_param' => 'table',
@@ -269,7 +386,9 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'constraint_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             )
         ),
         'routines' => array(
@@ -287,32 +406,16 @@ $GLOBALS['special_schema_links'] = array(
                 ),
                 'default_page' => 'db_routines.php'
             ),
-            'routine_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
         ),
         'schemata' => array(
             'schema_name' => array(
                 'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        ),
-        'schema_privileges' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             )
         ),
         'statistics' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'index_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
             'table_name' => array(
                 'link_param' => 'table',
                 'link_dependancy_params' => array(
@@ -321,14 +424,12 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
             'column_name' => array(
-                'link_param' => array(
-                    'sql_query',
-                    'table_schema',
-                    'table_name'
-                ),
+                'link_param' => 'field',
                 'link_dependancy_params' => array(
                     0 => array(
                         'param_info' => 'db',
@@ -339,7 +440,7 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_name'
                     )
                 ),
-                'default_page' => 'sql.php'
+                'default_page' => 'tbl_structure.php?change_column=1'
             )
         ),
         'tables' => array(
@@ -351,12 +452,10 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
         ),
         'table_constraints' => array(
             'table_name' => array(
@@ -367,40 +466,25 @@ $GLOBALS['special_schema_links'] = array(
                         'column_name' => 'table_schema'
                     )
                 ),
-                'default_page' => $GLOBALS['cfg']['DefaultTabTable']
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
             ),
-            'constraint_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        ),
-        'table_privileges' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        ),
-        'triggers' => array(
-            'trigger_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            ),
-            'event_object_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
         ),
         'views' => array(
-            'table_schema' => array(
-                'link_param' => 'db',
-                'default_page' => $GLOBALS['cfg']['DefaultTabDatabase']
-            )
-        )
+            'table_name' => array(
+                'link_param' => 'table',
+                'link_dependancy_params' => array(
+                    0 => array(
+                        'param_info' => 'db',
+                        'column_name' => 'table_schema'
+                    )
+                ),
+                'default_page' => PMA_Util::getScriptNameForOption(
+                    $GLOBALS['cfg']['DefaultTabTable'], 'table'
+                )
+            ),
+        ),
     )
 );
 
-?>
