@@ -8,7 +8,6 @@
  * @usedby  tbl_sql.php
  * @usedby  tbl_structure.php
  * @usedby  tbl_tracking.php
- * @usedby  querywindow.php
  * @package PhpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
@@ -26,10 +25,10 @@ require_once './libraries/bookmark.lib.php'; // used for bookmarks
  *
  * @param boolean|string $query       query to display in the textarea
  *                                    or true to display last executed
- * @param boolean|string $display_tab sql|files|history|full|false
+ * @param boolean|string $display_tab sql|full|false
  *                                    what part to display
  *                                    false if not inside querywindow
- * @param string         $delimiter   delimeter
+ * @param string         $delimiter   delimiter
  *
  * @return string
  *
@@ -38,20 +37,14 @@ require_once './libraries/bookmark.lib.php'; // used for bookmarks
  * @usedby  tbl_sql.php
  * @usedby  tbl_structure.php
  * @usedby  tbl_tracking.php
- * @usedby  querywindow.php
  */
 function PMA_getHtmlForSqlQueryForm(
     $query = true, $display_tab = false, $delimiter = ';'
 ) {
     $html = '';
-    // check tab to display if inside querywindow
     if (! $display_tab) {
         $display_tab = 'full';
-        $is_querywindow = false;
-    } else {
-        $is_querywindow = true;
     }
-
     // query to show
     if (true === $query) {
         $query = $GLOBALS['sql_query'];
@@ -66,11 +59,11 @@ function PMA_getHtmlForSqlQueryForm(
 
     $table  = '';
     $db     = '';
-    if (! strlen($GLOBALS['db'])) {
+    if (! /*overload*/mb_strlen($GLOBALS['db'])) {
         // prepare for server related
         $goto   = empty($GLOBALS['goto']) ?
                     'server_sql.php' : $GLOBALS['goto'];
-    } elseif (! strlen($GLOBALS['table'])) {
+    } elseif (! /*overload*/mb_strlen($GLOBALS['table'])) {
         // prepare for db related
         $db     = $GLOBALS['db'];
         $goto   = empty($GLOBALS['goto']) ?
@@ -83,25 +76,10 @@ function PMA_getHtmlForSqlQueryForm(
     }
 
     // start output
-    if ($is_querywindow) {
-        $html .= '<form method="post" id="sqlqueryform"';
-        $html .= ' action="import.php" ' . $enctype . ' name="sqlform">';
-    } else {
-        $html .= '<form method="post" action="import.php" ' . $enctype;
-        $html .= ' class="ajax"';
-        $html .= ' id="sqlqueryform" name="sqlform">' . "\n";
-    }
+    $html .= '<form method="post" action="import.php" ' . $enctype;
+    $html .= ' class="ajax lock-page"';
+    $html .= ' id="sqlqueryform" name="sqlform">' . "\n";
 
-    if ($is_querywindow) {
-        $html .= '<input type="hidden" name="focus_querywindow"'
-            . ' value="true" />' . "\n";
-        if ($display_tab != 'sql' && $display_tab != 'full') {
-            $html .= '<input type="hidden" name="sql_query"'
-                . ' value="" />' . "\n";
-            $html .= '<input type="hidden" name="show_query"'
-                . ' value="1" />' . "\n";
-        }
-    }
     $html .= '<input type="hidden" name="is_js_confirmed" value="0" />'
         . "\n" . PMA_URL_getHiddenInputs($db, $table) . "\n"
         . '<input type="hidden" name="pos" value="0" />' . "\n"
@@ -115,18 +93,14 @@ function PMA_getHtmlForSqlQueryForm(
     // display querybox
     if ($display_tab === 'full' || $display_tab === 'sql') {
         $html .= PMA_getHtmlForSqlQueryFormInsert(
-            $query, $is_querywindow, $delimiter
+            $query, $delimiter
         );
     }
 
-    // display uploads
-    if ($display_tab === 'files' && $GLOBALS['is_upload']) {
-        $html .= PMA_getHtmlForSqlQueryFormUpload();
-    }
-
     // Bookmark Support
-    if ($display_tab === 'full' || $display_tab === 'history') {
-        if (! empty($GLOBALS['cfg']['Bookmark'])) {
+    if ($display_tab === 'full') {
+        $cfgBookmark = PMA_Bookmark_getParams();
+        if ($cfgBookmark) {
             $html .= PMA_getHtmlForSqlQueryFormBookmark();
         }
     }
@@ -139,46 +113,24 @@ function PMA_getHtmlForSqlQueryForm(
     $html .= '</form>' . "\n";
     // print an empty div, which will be later filled with
     // the sql query results by ajax
-    $html .= '<div id="sqlqueryresults"></div>';
+    $html .= '<div id="sqlqueryresultsouter"></div>';
 
     return $html;
 }
 
 /**
- * return HTML for Sql Query Form Insert
+ * Get initial values for Sql Query Form Insert
  *
- * @param string  $query          query to display in the textarea
- * @param boolean $is_querywindow if inside querywindow or not
- * @param string  $delimiter      default delimiter to use
+ * @param string $query query to display in the textarea
  *
- * @return string
+ * @return array ($legend, $query, $columns_list)
  *
- * @usedby  PMA_getHtmlForSqlQueryForm()
+ * @usedby  PMA_getHtmlForSqlQueryFormInsert()
  */
-function PMA_getHtmlForSqlQueryFormInsert(
-    $query = '', $is_querywindow = false, $delimiter = ';'
-) {
-    // enable auto select text in textarea
-    if ($GLOBALS['cfg']['TextareaAutoSelect']) {
-        $auto_sel = ' onclick="selectContent(this, sql_box_locked, true);"';
-    } else {
-        $auto_sel = '';
-    }
-
-    // enable locking if inside query window
-    if ($is_querywindow) {
-        $locking = ' onkeypress="document.sqlform.elements[\'LockFromUpdate\'].'
-            . 'checked = true;"';
-        $height = $GLOBALS['cfg']['TextareaRows'] * 1.25;
-    } else {
-        $locking = '';
-        $height = $GLOBALS['cfg']['TextareaRows'] * 2;
-    }
-
-    $table          = '';
-    $db             = '';
-    $fields_list    = array();
-    if (! strlen($GLOBALS['db'])) {
+function PMA_initQueryForm($query)
+{
+    $columns_list    = array();
+    if (! /*overload*/mb_strlen($GLOBALS['db'])) {
         // prepare for server related
         $legend = sprintf(
             __('Run SQL query/queries on server %s'),
@@ -188,20 +140,16 @@ function PMA_getHtmlForSqlQueryFormInsert(
                 : $GLOBALS['cfg']['Servers'][$GLOBALS['server']]['host']
             ) . '&quot;'
         );
-    } elseif (! strlen($GLOBALS['table'])) {
+    } elseif (! /*overload*/mb_strlen($GLOBALS['table'])) {
         // prepare for db related
         $db     = $GLOBALS['db'];
         // if you want navigation:
-        $tmp_db_link = '<a href="' . $GLOBALS['cfg']['DefaultTabDatabase']
-            . '?' . PMA_URL_getCommon($db) . '"';
-        if ($is_querywindow) {
-            $tmp_db_link .= ' target="_self"'
-                . ' onclick="this.target=window.opener.frame_content.name"';
-        }
+        $tmp_db_link = '<a href="' . PMA_Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
+        )
+            . PMA_URL_getCommon(array('db' => $db)) . '"';
         $tmp_db_link .= '>'
             . htmlspecialchars($db) . '</a>';
-        // else use
-        // $tmp_db_link = htmlspecialchars($db);
         $legend = sprintf(__('Run SQL query/queries on database %s'), $tmp_db_link);
         if (empty($query)) {
             $query = PMA_Util::expandUserString(
@@ -209,28 +157,21 @@ function PMA_getHtmlForSqlQueryFormInsert(
             );
         }
     } else {
-        $table  = $GLOBALS['table'];
         $db     = $GLOBALS['db'];
+        $table  = $GLOBALS['table'];
         // Get the list and number of fields
         // we do a try_query here, because we could be in the query window,
-        // trying to synchonize and the table has not yet been created
-        $fields_list = $GLOBALS['dbi']->getColumns(
+        // trying to synchronize and the table has not yet been created
+        $columns_list = $GLOBALS['dbi']->getColumns(
             $db, $GLOBALS['table'], null, true
         );
 
-        $tmp_db_link = '<a href="' . $GLOBALS['cfg']['DefaultTabDatabase']
-            . '?' . PMA_URL_getCommon($db) . '"';
-        if ($is_querywindow) {
-            $tmp_db_link .= 'target="_parent" '
-                . 'onclick="window.opener.location.href = \''
-                . $GLOBALS['cfg']['DefaultTabDatabase']
-                . '?' . PMA_URL_getCommon($db) . '\';return false;"';
-        }
-        $tmp_db_link .= '>'
-            . htmlspecialchars($db) . '</a>';
-        // else use
-        // $tmp_db_link = htmlspecialchars($db);
-        $legend = sprintf(__('Run SQL query/queries on database %s'), $tmp_db_link);
+        $tmp_tbl_link = '<a href="' . PMA_Util::getScriptNameForOption(
+            $GLOBALS['cfg']['DefaultTabTable'], 'table'
+        ) . PMA_URL_getCommon(array('db' => $db, 'table' => $table)) . '" >';
+        $tmp_tbl_link .= htmlspecialchars($db)
+            . '.' . htmlspecialchars($table) . '</a>';
+        $legend = sprintf(__('Run SQL query/queries on table %s'), $tmp_tbl_link);
         if (empty($query)) {
             $query = PMA_Util::expandUserString(
                 $GLOBALS['cfg']['DefaultQueryTable'], 'backquote'
@@ -239,7 +180,35 @@ function PMA_getHtmlForSqlQueryFormInsert(
     }
     $legend .= ': ' . PMA_Util::showMySQLDocu('SELECT');
 
-    if (count($fields_list)) {
+    return array($legend, $query, $columns_list);
+}
+
+/**
+ * return HTML for Sql Query Form Insert
+ *
+ * @param string $query     query to display in the textarea
+ * @param string $delimiter default delimiter to use
+ *
+ * @return string
+ *
+ * @usedby  PMA_getHtmlForSqlQueryForm()
+ */
+function PMA_getHtmlForSqlQueryFormInsert(
+    $query = '', $delimiter = ';'
+) {
+    // enable auto select text in textarea
+    if ($GLOBALS['cfg']['TextareaAutoSelect']) {
+        $auto_sel = ' onclick="selectContent(this, sql_box_locked, true);"';
+    } else {
+        $auto_sel = '';
+    }
+
+    $locking = '';
+    $height = $GLOBALS['cfg']['TextareaRows'] * 2;
+
+    list($legend, $query, $columns_list) = PMA_initQueryForm($query);
+
+    if (! empty($columns_list)) {
         $sqlquerycontainer_id = 'sqlquerycontainer';
     } else {
         $sqlquerycontainer_id = 'sqlquerycontainerfull';
@@ -254,13 +223,13 @@ function PMA_getHtmlForSqlQueryFormInsert(
         . '<textarea tabindex="100" name="sql_query" id="sqlquery"'
         . '  cols="' . $GLOBALS['cfg']['TextareaCols'] . '"'
         . '  rows="' . $height . '"'
-        . '  dir="' . $GLOBALS['text_dir'] . '"'
         . $auto_sel . $locking . '>'
         . htmlspecialchars($query)
         . '</textarea>';
+    $html .= '<div id="querymessage"></div>';
     // Add buttons to generate query easily for
     // select all, single select, insert, update and delete
-    if (count($fields_list)) {
+    if (! empty($columns_list)) {
         $html .= '<input type="button" value="SELECT *" id="selectall"'
             . ' class="button sqlbutton" />';
         $html .= '<input type="button" value="SELECT" id="select"'
@@ -274,19 +243,34 @@ function PMA_getHtmlForSqlQueryFormInsert(
     }
     $html .= '<input type="button" value="' . __('Clear') . '" id="clear"'
         . ' class="button sqlbutton" />';
+    if ($GLOBALS['cfg']['CodemirrorEnable']) {
+        $html .= '<input type="button" value="' . __('Format') . '" id="format"'
+            . ' class="button sqlbutton" />';
+    }
+    $html .= '<input type="button" value="' . __('Get auto-saved query')
+        . '" id="saved" class="button sqlbutton" />';
+
+    // parameter binding
+    $html .= '<div>';
+    $html .= '<input type="checkbox" name="parameterized" id="parameterized" />';
+    $html .= '<label for="parameterized">' . __('Bind parameters') . '</label>';
+    $html .= PMA_Util::showDocu('faq', 'faq6-40');
+    $html .= '<div id="parametersDiv"></div>';
+    $html .= '</div>';
+
     $html .= '</div>' . "\n";
 
-    if (count($fields_list)) {
+    if (! empty($columns_list)) {
         $html .= '<div id="tablefieldscontainer">'
             . '<label>' . __('Columns') . '</label>'
             . '<select id="tablefields" name="dummy" '
             . 'size="' . ($GLOBALS['cfg']['TextareaRows'] - 2) . '" '
             . 'multiple="multiple" ondblclick="insertValueQuery()">';
-        foreach ($fields_list as $field) {
+        foreach ($columns_list as $field) {
             $html .= '<option value="'
                 . PMA_Util::backquote(htmlspecialchars($field['Field'])) . '"';
             if (isset($field['Field'])
-                && strlen($field['Field'])
+                && /*overload*/mb_strlen($field['Field'])
                 && isset($field['Comment'])
             ) {
                 $html .= ' title="' . htmlspecialchars($field['Comment']) . '"';
@@ -311,7 +295,8 @@ function PMA_getHtmlForSqlQueryFormInsert(
     $html .= '<div class="clearfloat"></div>' . "\n";
     $html .= '</div>' . "\n";
 
-    if (! empty($GLOBALS['cfg']['Bookmark'])) {
+    $cfgBookmark = PMA_Bookmark_getParams();
+    if ($cfgBookmark) {
         $html .= '<div id="bookmarkoptions">';
         $html .= '<div class="formelement">';
         $html .= '<label for="bkm_label">'
@@ -340,44 +325,47 @@ function PMA_getHtmlForSqlQueryFormInsert(
 
     $html .= '<fieldset id="queryboxfooter" class="tblFooters">' . "\n";
     $html .= '<div class="formelement">' . "\n";
-
-    if ($is_querywindow) {
-        $html .= '<input type="checkbox" '
-            . 'name="LockFromUpdate" checked="checked" tabindex="120" '
-            . 'id="checkbox_lock" /> <label for="checkbox_lock">'
-            . __('Do not overwrite this query from outside the window')
-            . '</label>';
-    }
     $html .= '</div>' . "\n";
-    $html .= '<div class="formelement">' . "\n";
+
+    $html .= '<div class="formelement">';
     $html .= '<label for="id_sql_delimiter">[ ' . __('Delimiter')
         . '</label>' . "\n";
     $html .= '<input type="text" name="sql_delimiter" tabindex="131" size="3" '
         . 'value="' . $delimiter . '" '
         . 'id="id_sql_delimiter" /> ]';
+    $html .= '</div>';
 
+    $html .= '<div class="formelement">';
     $html .= '<input type="checkbox" name="show_query" value="1" '
         . 'id="checkbox_show_query" tabindex="132" checked="checked" />'
         . '<label for="checkbox_show_query">' . __('Show this query here again')
         . '</label>';
+    $html .= '</div>';
+
+    $html .= '<div class="formelement">';
+    $html .= '<input type="checkbox" name="retain_query_box" value="1" '
+        . 'id="retain_query_box" tabindex="133" '
+        . ($GLOBALS['cfg']['RetainQueryBox'] === false
+            ? '' : ' checked="checked"')
+        . ' />'
+        . '<label for="retain_query_box">' . __('Retain query box')
+        . '</label>';
+    $html .= '</div>';
+
+    $html .= '<div class="formelement">';
+    $html .= '<input type="checkbox" name="rollback_query" value="1" '
+        . 'id="rollback_query" tabindex="134" />'
+        . '<label for="rollback_query">' . __('Rollback when finished')
+        . '</label>';
+    $html .= '</div>';
+
+    // Disable/Enable foreign key checks
+    $html .= '<div class="formelement">';
+    $html .= PMA_Util::getFKCheckbox();
+    $html .= '</div>';
 
-    if (! $is_querywindow) {
-        $html .= '<input type="checkbox" name="retain_query_box" value="1" '
-            . 'id="retain_query_box" tabindex="133" '
-            . ($GLOBALS['cfg']['RetainQueryBox'] === false
-                ? '' : ' checked="checked"')
-            . ' />'
-            . '<label for="retain_query_box">' . __('Retain query box')
-            . '</label>';
-    }
-    $html .= '</div>' . "\n";
     $html .= '<input type="submit" id="button_submit_query" name="SQL"';
-    if ($is_querywindow) {
-        $html .= 'onclick="var form = this.parentNode.parentNode;'
-            . ' window.opener.name = \'sqlParentWindow\';'
-            . ' form.target = \'sqlParentWindow\';'
-            . ' return checkSqlQuery(form);"';
-    }
+
     $html .= ' tabindex="200" value="' . __('Go') . '" />' . "\n";
     $html .= '<div class="clearfloat"></div>' . "\n";
     $html .= '</fieldset>' . "\n";
@@ -388,15 +376,15 @@ function PMA_getHtmlForSqlQueryFormInsert(
 /**
  * return HTML for sql Query Form Bookmark
  *
- * @return string|void
+ * @return string|null
  *
  * @usedby  PMA_getHtmlForSqlQueryForm()
  */
 function PMA_getHtmlForSqlQueryFormBookmark()
 {
     $bookmark_list = PMA_Bookmark_getList($GLOBALS['db']);
-    if (! $bookmark_list || count($bookmark_list) < 1) {
-        return;
+    if (empty($bookmark_list) || count($bookmark_list) < 1) {
+        return null;
     }
 
     $html  = '<fieldset id="fieldsetBookmarkOptions">';
@@ -406,19 +394,15 @@ function PMA_getHtmlForSqlQueryFormBookmark()
     $html .= '<select name="id_bookmark" id="id_bookmark">' . "\n";
     $html .= '<option value="">&nbsp;</option>' . "\n";
     foreach ($bookmark_list as $key => $value) {
-        $html .= '<option value="' . htmlspecialchars($key) . '">'
-            . htmlspecialchars($value) . '</option>' . "\n";
+        $html .= '<option value="' . htmlspecialchars($key) . '"'
+            . ' data-varcount="' . PMA_Bookmark_getVariableCount($value['query'])
+            . '">'
+            . htmlspecialchars($value['label']) . '</option>' . "\n";
     }
     // &nbsp; is required for correct display with styles/line height
     $html .= '</select>&nbsp;' . "\n";
     $html .= '</div>' . "\n";
     $html .= '<div class="formelement">' . "\n";
-    $html .= __('Variable');
-    $html .= PMA_Util::showDocu('faq', 'faqbookmark');
-    $html .= '<input type="text" name="bookmark_variable" class="textfield"'
-        . ' size="10" />' . "\n";
-    $html .= '</div>' . "\n";
-    $html .= '<div class="formelement">' . "\n";
     $html .= '<input type="radio" name="action_bookmark" value="0"'
         . ' id="radio_bookmark_exe" checked="checked" />'
         . '<label for="radio_bookmark_exe">' . __('Submit')
@@ -433,6 +417,11 @@ function PMA_getHtmlForSqlQueryFormBookmark()
         . '</label>' . "\n";
     $html .= '</div>' . "\n";
     $html .= '<div class="clearfloat"></div>' . "\n";
+    $html .= '<div class="formelement hide">' . "\n";
+    $html .= __('Variables');
+    $html .= PMA_Util::showDocu('faq', 'faqbookmark');
+    $html .= '<div id="bookmark_variables"></div>';
+    $html .= '</div>' . "\n";
     $html .= '</fieldset>' . "\n";
 
     $html .= '<fieldset id="fieldsetBookmarkOptionsFooter" class="tblFooters">';
@@ -443,78 +432,3 @@ function PMA_getHtmlForSqlQueryFormBookmark()
 
     return $html;
 }
-
-/**
- * return HTML for Sql Query Form Upload
- *
- * @return string
- *
- * @usedby  PMA_getHtmlForSqlQueryForm()
- */
-function PMA_getHtmlForSqlQueryFormUpload()
-{
-    global $timeout_passed, $local_import_file;
-
-    $errors = array();
-
-    // we allow only SQL here
-    $matcher = '@\.sql(\.(' . PMA_supportedDecompressions() . '))?$@';
-
-    if (!empty($GLOBALS['cfg']['UploadDir'])) {
-        $files = PMA_getFileSelectOptions(
-            PMA_Util::userDir($GLOBALS['cfg']['UploadDir']), $matcher,
-            (isset($timeout_passed) && $timeout_passed && isset($local_import_file))
-            ? $local_import_file
-            : ''
-        );
-    } else {
-        $files = '';
-    }
-
-    // start output
-    $html  = '<fieldset id="">';
-    $html .= '<legend>';
-    $html .= __('Browse your computer:') . '</legend>';
-    $html .= '<div class="formelement">';
-    $html .= '<input type="file" name="sql_file" class="textfield" /> ';
-    $html .= PMA_Util::getFormattedMaximumUploadSize($GLOBALS['max_upload_size']);
-    // some browsers should respect this :)
-    $html .= PMA_Util::generateHiddenMaxFileSize($GLOBALS['max_upload_size']) . "\n";
-    $html .= '</div>';
-
-    if ($files === false) {
-        $errors[] = PMA_Message::error(
-            __('The directory you set for upload work cannot be reached.')
-        );
-    } elseif (!empty($files)) {
-        $html .= '<div class="formelement">';
-        $html .= '<strong>' . __('web server upload directory:') . '</strong>' . "\n";
-        $html .= '<select size="1" name="sql_localfile">' . "\n";
-        $html .= '<option value="" selected="selected"></option>' . "\n";
-        $html .= $files;
-        $html .= '</select>' . "\n";
-        $html .= '</div>';
-    }
-
-    $html .= '<div class="clearfloat"></div>' . "\n";
-    $html .= '</fieldset>';
-
-
-    $html .= '<fieldset id="" class="tblFooters">';
-    $html .= __('Character set of the file:') . "\n";
-    $html .= PMA_generateCharsetDropdownBox(
-        PMA_CSDROPDOWN_CHARSET,
-        'charset_of_file', null, 'utf8', false
-    );
-    $html .= '<input type="submit" name="SQL" value="' . __('Go')
-        . '" />' . "\n";
-    $html .= '<div class="clearfloat"></div>' . "\n";
-    $html .= '</fieldset>';
-
-    foreach ($errors as $error) {
-        $html .= $error->getDisplay();
-    }
-
-    return $html;
-}
-?>
