@@ -3,7 +3,7 @@
 /**
  * Set of functions used with the relation and pdf feature
  *
- * This file also provides basic functions to use in other plungins!
+ * This file also provides basic functions to use in other plugins!
  * These are declared in the 'GLOBAL Plugin functions' section
  *
  * Please use short and expressive names.
@@ -41,7 +41,7 @@ function PMA_Transformation_getOptions($option_string)
 {
     $result = array();
 
-    if (! strlen($option_string)
+    if (! /*overload*/mb_strlen($option_string)
         || ! $transform_options = preg_split('/,/', $option_string)
     ) {
         return $result;
@@ -49,12 +49,12 @@ function PMA_Transformation_getOptions($option_string)
 
     while (($option = array_shift($transform_options)) !== null) {
         $trimmed = trim($option);
-        if (strlen($trimmed) > 1
+        if (/*overload*/mb_strlen($trimmed) > 1
             && $trimmed[0] == "'"
-            && $trimmed[strlen($trimmed) - 1] == "'"
+            && $trimmed[/*overload*/mb_strlen($trimmed) - 1] == "'"
         ) {
             // '...'
-            $option = substr($trimmed, 1, -1);
+            $option = /*overload*/mb_substr($trimmed, 1, -1);
         } elseif (isset($trimmed[0]) && $trimmed[0] == "'") {
             // '...,
             $trimmed = ltrim($option);
@@ -62,12 +62,12 @@ function PMA_Transformation_getOptions($option_string)
                 // ...,
                 $trimmed .= ',' . $option;
                 $rtrimmed = rtrim($trimmed);
-                if ($rtrimmed[strlen($rtrimmed) - 1] == "'") {
+                if ($rtrimmed[/*overload*/mb_strlen($rtrimmed) - 1] == "'") {
                     // ,...'
                     break;
                 }
             }
-            $option = substr($rtrimmed, 1, -1);
+            $option = /*overload*/mb_substr($rtrimmed, 1, -1);
         }
         $result[] = stripslashes($option);
     }
@@ -91,77 +91,119 @@ function PMA_getAvailableMIMEtypes()
     }
 
     $stack = array();
-    $filestack = array();
+    $sub_dirs = array(
+        'input/' => 'input_',
+        'output/' => '',
+        '' => ''
+    );
+    foreach ($sub_dirs as $sd => $prefix) {
+        $handle = opendir('./libraries/plugins/transformations/' . $sd);
 
-    $handle = opendir('./libraries/plugins/transformations');
+        if (! $handle) {
+            $stack[$prefix . 'transformation'] = array();
+            $stack[$prefix . 'transformation_file'] = array();
+            continue;
+        }
 
-    if (! $handle) {
-        return $stack;
-    }
+        $filestack = array();
+        while ($file = readdir($handle)) {
+            $filestack[] = $file;
+        }
 
-    while ($file = readdir($handle)) {
-        $filestack[] = $file;
-    }
+        closedir($handle);
+        sort($filestack);
 
-    closedir($handle);
-    sort($filestack);
-
-    foreach ($filestack as $file) {
-        if (preg_match('|^[^.].*_.*_.*\.class\.php$|', $file)) {
-            // File contains transformation functions.
-            $parts = explode('_', str_replace('.class.php', '', $file));
-            $mimetype = $parts[0] . "/" . $parts[1];
-            $stack['mimetype'][$mimetype] = $mimetype;
-            $stack['transformation'][] = $mimetype . ': ' . $parts[2];
-            $stack['transformation_file'][] = $file;
-
-        } elseif (preg_match('|^[^.].*\.class.php$|', $file)) {
-            // File is a plain mimetype, no functions.
-            $base = str_replace('.class.php', '', $file);
-
-            if ($base != 'global') {
-                $mimetype = str_replace('_', '/', $base);
+        foreach ($filestack as $file) {
+            if (preg_match('|^[^.].*_.*_.*\.class\.php$|', $file)) {
+                // File contains transformation functions.
+                $parts = explode('_', str_replace('.class.php', '', $file));
+                $mimetype = $parts[0] . "/" . $parts[1];
                 $stack['mimetype'][$mimetype] = $mimetype;
-                $stack['empty_mimetype'][$mimetype] = $mimetype;
+
+                $stack[$prefix . 'transformation'][] = $mimetype . ': ' . $parts[2];
+                $stack[$prefix . 'transformation_file'][] = $sd . $file;
+                if ($sd === '') {
+                    $stack['input_transformation'][] = $mimetype . ': ' . $parts[2];
+                    $stack['input_transformation_file'][] = $sd . $file;
+                }
+
+            } elseif (preg_match('|^[^.].*\.class.php$|', $file)) {
+                // File is a plain mimetype, no functions.
+                $base = str_replace('.class.php', '', $file);
+
+                if ($base != 'global') {
+                    $mimetype = str_replace('_', '/', $base);
+                    $stack['mimetype'][$mimetype] = $mimetype;
+                    $stack['empty_mimetype'][$mimetype] = $mimetype;
+                }
             }
         }
     }
-
     return $stack;
 }
 
+/**
+ * Returns the class name of the transformation
+ *
+ * @param string $filename transformation file name
+ *
+ * @return string the class name of transformation
+ */
+function PMA_getTransformationClassName($filename)
+{
+    // get the transformation class name
+    $class_name = explode(".class.php", $filename);
+    $class_name = explode("/", $class_name[0]);
+    $class_name = count($class_name) === 1 ? $class_name[0] : $class_name[1];
+
+    return $class_name;
+}
+
 /**
  * Returns the description of the transformation
  *
- * @param string  $file           transformation file
- * @param boolean $html_formatted whether the description should be formatted
- *                                as HTML
+ * @param string $file transformation file
  *
  * @return String the description of the transformation
  */
-function PMA_getTransformationDescription($file, $html_formatted = true)
+function PMA_getTransformationDescription($file)
 {
-    // get the transformation class name
-    $class_name = explode(".class.php", $file);
-    $class_name = $class_name[0];
-
+    /* @var $class_name TransformationsInterface */
+    $class_name = PMA_getTransformationClassName($file);
     // include and instantiate the class
     include_once 'libraries/plugins/transformations/' . $file;
     return $class_name::getInfo();
 }
 
+/**
+ * Returns the name of the transformation
+ *
+ * @param string $file transformation file
+ *
+ * @return String the name of the transformation
+ */
+function PMA_getTransformationName($file)
+{
+    /* @var $class_name TransformationsInterface */
+    $class_name = PMA_getTransformationClassName($file);
+    // include and instantiate the class
+    include_once 'libraries/plugins/transformations/' . $file;
+    return $class_name::getName();
+}
+
 /**
  * Gets the mimetypes for all columns of a table
  *
- * @param string  $db     the name of the db to check for
- * @param string  $table  the name of the table to check for
- * @param boolean $strict whether to include only results having a mimetype set
+ * @param string  $db       the name of the db to check for
+ * @param string  $table    the name of the table to check for
+ * @param boolean $strict   whether to include only results having a mimetype set
+ * @param boolean $fullName whether to use full column names as the key
  *
  * @access public
  *
  * @return array [field_name][field_key] = field_value
  */
-function PMA_getMIME($db, $table, $strict = false)
+function PMA_getMIME($db, $table, $strict = false, $fullName = false)
 {
     $cfgRelation = PMA_getRelationsParam();
 
@@ -169,18 +211,28 @@ function PMA_getMIME($db, $table, $strict = false)
         return false;
     }
 
-    $com_qry  = '
-         SELECT `column_name`,
-                `mimetype`,
+    $com_qry = '';
+    if ($fullName) {
+        $com_qry .= "SELECT CONCAT("
+            . "`db_name`, '.', `table_name`, '.', `column_name`"
+            . ") AS column_name, ";
+    } else {
+        $com_qry  = "SELECT `column_name`, ";
+    }
+    $com_qry .= '`mimetype`,
                 `transformation`,
-                `transformation_options`
+                `transformation_options`,
+                `input_transformation`,
+                `input_transformation_options`
          FROM ' . PMA_Util::backquote($cfgRelation['db']) . '.'
         . PMA_Util::backquote($cfgRelation['column_info']) . '
          WHERE `db_name`    = \'' . PMA_Util::sqlAddSlashes($db) . '\'
            AND `table_name` = \'' . PMA_Util::sqlAddSlashes($table) . '\'
            AND ( `mimetype` != \'\'' . (!$strict ? '
               OR `transformation` != \'\'
-              OR `transformation_options` != \'\'' : '') . ')';
+              OR `transformation_options` != \'\'
+              OR `input_transformation` != \'\'
+              OR `input_transformation_options` != \'\'' : '') . ')';
     $result = $GLOBALS['dbi']->fetchResult(
         $com_qry, 'column_name', null, $GLOBALS['controllink']
     );
@@ -189,7 +241,6 @@ function PMA_getMIME($db, $table, $strict = false)
         // replacements in mimetype and transformation
         $values = str_replace("jpeg", "JPEG", $values);
         $values = str_replace("png", "PNG", $values);
-        $values = str_replace("octet-stream", "Octetstream", $values);
 
         // convert mimetype to new format (f.e. Text_Plain, etc)
         $delimiter_space = '- ';
@@ -206,10 +257,15 @@ function PMA_getMIME($db, $table, $strict = false)
             )
         );
 
-        // convert transformation to new format (class name)
-        // f.e. Text_Plain_Substring.class.php
-        $values = str_replace("__", "_", $values);
-        $values = str_replace(".inc.php", ".class.php", $values);
+        // For transformation of form
+        // output/image_jpeg__inline.inc.php
+        // extract dir part.
+        $dir = explode('/', $values['transformation']);
+        $subdir = '';
+        if (count($dir) === 2) {
+            $subdir = $dir[0] . '/';
+            $values['transformation'] = $dir[1];
+        }
 
         $values['transformation'] = str_replace(
             $delimiter_space,
@@ -222,7 +278,7 @@ function PMA_getMIME($db, $table, $strict = false)
                 )
             )
         );
-
+        $values['transformation'] = $subdir . $values['transformation'];
         $result[$column] = $values;
     }
 
@@ -238,6 +294,8 @@ function PMA_getMIME($db, $table, $strict = false)
  * @param string  $mimetype           the mimetype of the column
  * @param string  $transformation     the transformation of the column
  * @param string  $transformationOpts the transformation options of the column
+ * @param string  $inputTransform     the input transformation of the column
+ * @param string  $inputTransformOpts the input transformation options of the column
  * @param boolean $forcedelete        force delete, will erase any existing
  *                                    comments for this column
  *
@@ -246,7 +304,7 @@ function PMA_getMIME($db, $table, $strict = false)
  * @return boolean  true, if comment-query was made.
  */
 function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
-    $transformationOpts, $forcedelete = false
+    $transformationOpts, $inputTransform, $inputTransformOpts, $forcedelete = false
 ) {
     $cfgRelation = PMA_getRelationsParam();
 
@@ -254,19 +312,9 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
         return false;
     }
 
-    // convert mimetype to old format (f.e. text_plain)
-    $mimetype = strtolower($mimetype);
-    // old format has octet-stream instead of octetstream for mimetype
-    if (strstr($mimetype, "octetstream")) {
-        $mimetype = "application_octet-stream";
-    }
-
-    // convert transformation to old format (f.e. text_plain__substring.inc.php)
-    $transformation = strtolower($transformation);
-    $transformation = str_replace(".class.php", ".inc.php", $transformation);
-    $last_pos = strrpos($transformation, "_");
-    $transformation = substr($transformation, 0, $last_pos) . "_"
-        . substr($transformation, $last_pos);
+    // lowercase mimetype & transformation
+    $mimetype = /*overload*/mb_strtolower($mimetype);
+    $transformation = /*overload*/mb_strtolower($transformation);
 
     $test_qry = '
          SELECT `mimetype`,
@@ -285,9 +333,11 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
         $row = @$GLOBALS['dbi']->fetchAssoc($test_rs);
         $GLOBALS['dbi']->freeResult($test_rs);
 
+        $transformationLength = /*overload*/mb_strlen($transformation);
         if (! $forcedelete
-            && (strlen($mimetype) || strlen($transformation)
-            || strlen($transformationOpts) || strlen($row['comment']))
+            && (/*overload*/mb_strlen($mimetype) || $transformationLength
+            || /*overload*/mb_strlen($transformationOpts)
+            || /*overload*/mb_strlen($row['comment']))
         ) {
             $upd_query = 'UPDATE ' . PMA_Util::backquote($cfgRelation['db']) . '.'
                 . PMA_Util::backquote($cfgRelation['column_info'])
@@ -297,7 +347,11 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
                 . '`transformation` = \''
                 . PMA_Util::sqlAddSlashes($transformation) . '\', '
                 . '`transformation_options` = \''
-                . PMA_Util::sqlAddSlashes($transformationOpts) . '\'';
+                . PMA_Util::sqlAddSlashes($transformationOpts) . '\', '
+                . '`input_transformation` = \''
+                . PMA_Util::sqlAddSlashes($inputTransform) . '\', '
+                . '`input_transformation_options` = \''
+                . PMA_Util::sqlAddSlashes($inputTransformOpts) . '\'';
         } else {
             $upd_query = 'DELETE FROM ' . PMA_Util::backquote($cfgRelation['db'])
                 . '.' . PMA_Util::backquote($cfgRelation['column_info']);
@@ -306,22 +360,25 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
             WHERE `db_name`     = \'' . PMA_Util::sqlAddSlashes($db) . '\'
               AND `table_name`  = \'' . PMA_Util::sqlAddSlashes($table) . '\'
               AND `column_name` = \'' . PMA_Util::sqlAddSlashes($key) . '\'';
-    } elseif (strlen($mimetype)
-        || strlen($transformation)
-        || strlen($transformationOpts)
+    } elseif (/*overload*/mb_strlen($mimetype)
+        || /*overload*/mb_strlen($transformation)
+        || /*overload*/mb_strlen($transformationOpts)
     ) {
 
         $upd_query = 'INSERT INTO ' . PMA_Util::backquote($cfgRelation['db'])
             . '.' . PMA_Util::backquote($cfgRelation['column_info'])
             . ' (db_name, table_name, column_name, mimetype, '
-            . 'transformation, transformation_options) '
+            . 'transformation, transformation_options, '
+            . 'input_transformation, input_transformation_options) '
             . ' VALUES('
             . '\'' . PMA_Util::sqlAddSlashes($db) . '\','
             . '\'' . PMA_Util::sqlAddSlashes($table) . '\','
             . '\'' . PMA_Util::sqlAddSlashes($key) . '\','
             . '\'' . PMA_Util::sqlAddSlashes($mimetype) . '\','
             . '\'' . PMA_Util::sqlAddSlashes($transformation) . '\','
-            . '\'' . PMA_Util::sqlAddSlashes($transformationOpts) . '\')';
+            . '\'' . PMA_Util::sqlAddSlashes($transformationOpts) . '\','
+            . '\'' . PMA_Util::sqlAddSlashes($inputTransform) . '\','
+            . '\'' . PMA_Util::sqlAddSlashes($inputTransformOpts) . '\')';
     }
 
     if (isset($upd_query)) {
@@ -338,7 +395,7 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
 
 
 /**
- * Replaces "[__BUFFER__]" occurences found in $options['string'] with the text
+ * Replaces "[__BUFFER__]" occurrences found in $options['string'] with the text
  * in $buffer, after performing a regular expression search and replace on
  * $buffer using $options['regex'] and $options['regex_replace'].
  *
@@ -356,7 +413,7 @@ function PMA_setMIME($db, $table, $key, $mimetype, $transformation,
  */
 function PMA_Transformation_globalHtmlReplace($buffer, $options = array())
 {
-    if ( ! isset($options['string']) ) {
+    if (! isset($options['string'])) {
         $options['string'] = '';
     }
 
@@ -368,7 +425,7 @@ function PMA_Transformation_globalHtmlReplace($buffer, $options = array())
         );
     }
 
-    // Replace occurences of [__BUFFER__] with actual text
+    // Replace occurrences of [__BUFFER__] with actual text
     $return = str_replace("[__BUFFER__]", $buffer, $options['string']);
     return $return;
 }
@@ -416,4 +473,3 @@ function PMA_clearTransformations($db, $table = '', $column = '')
 
 }
 
-?>
