@@ -25,7 +25,10 @@ $filename = LICENSE_FILE;
 if (is_readable($filename)) {
     readfile($filename);
 } else {
-    printf(__('The %s file is not available on this system, please visit www.phpmyadmin.net for more information.'), $filename);
+    printf(
+        __(
+            'The %s file is not available on this system, please visit ' .
+            'www.phpmyadmin.net for more information.'
+        ), $filename
+    );
 }
-
-?>
