@@ -22,7 +22,7 @@ if (! PMA_DRIZZLE) {
     include_once 'libraries/replication.inc.php';
 } else {
     $replication_types = array();
-    $replication_info = null;
+    $GLOBALS['replication_info'] = null;
 }
 require 'libraries/build_html_for_db.lib.php';
 
@@ -94,7 +94,7 @@ if ($server > 0) {
 /**
  * Displays the page
  */
-if ($databases_count > 0) {
+if ($databases_count > 0 && ! empty($databases)) {
     $html .= PMA_getHtmlForDatabase(
         $databases,
         $databases_count,
@@ -105,7 +105,7 @@ if ($databases_count > 0) {
         $is_superuser,
         $cfg,
         $replication_types,
-        $replication_info,
+        $GLOBALS['replication_info'],
         $url_query
     );
 } else {
@@ -114,5 +114,3 @@ if ($databases_count > 0) {
 unset($databases_count);
 
 $response->addHTML($html);
-
-?>
