@@ -10,6 +10,9 @@
  *
  */
 require_once 'libraries/common.inc.php';
+require_once 'libraries/config/page_settings.class.php';
+
+PMA_PageSettings::showGroup('Import');
 
 $response = PMA_Response::getInstance();
 $header   = $response->getHeader();
@@ -21,7 +24,10 @@ $scripts->addFile('import.js');
  */
 require 'libraries/server_common.inc.php';
 
-$import_type = 'server';
-require 'libraries/display_import.inc.php';
-
-?>
+require 'libraries/display_import.lib.php';
+$response = PMA_Response::getInstance();
+$response->addHTML(
+    PMA_getImportDisplay(
+        'server', $db, $table, $max_upload_size
+    )
+);
