@@ -15,7 +15,7 @@ define('PMA_SETUP', true);
 chdir('..');
 
 if (!file_exists('./libraries/common.inc.php')) {
-    PMA_fatalError('Bad invocation!');
+    die('Bad invocation!');
 }
 
 require_once './libraries/common.inc.php';
@@ -53,4 +53,3 @@ $GLOBALS['ConfigFile']->setPersistKeys(
 // allows for redirection even after sending some data
 ob_start();
 
-?>
