@@ -23,7 +23,11 @@ PMA_Util::checkParameters(array('db', 'table'));
 /**
  * Defines the url to return to in case of error in a sql statement
  */
-$err_url = 'tbl_sql.php?' . PMA_URL_getCommon($db, $table);
+$err_url = 'tbl_sql.php' . PMA_URL_getCommon(
+    array(
+        'db' => $db, 'table' => $table
+    )
+);
 
 /**
  * The form used to define the field to add has been submitted
@@ -64,16 +68,20 @@ if (isset($_REQUEST['do_save_data'])) {
             && is_array($_REQUEST['field_mimetype'])
             && $cfg['BrowseMIME']
         ) {
+            /** @var PMA_String $pmaString */
+            $pmaString = $GLOBALS['PMA_String'];
             foreach ($_REQUEST['field_mimetype'] as $fieldindex => $mimetype) {
                 if (isset($_REQUEST['field_name'][$fieldindex])
-                    && strlen($_REQUEST['field_name'][$fieldindex])
+                    && /*overload*/mb_strlen($_REQUEST['field_name'][$fieldindex])
                 ) {
                     PMA_setMIME(
                         $db, $table,
                         $_REQUEST['field_name'][$fieldindex],
                         $mimetype,
                         $_REQUEST['field_transformation'][$fieldindex],
-                        $_REQUEST['field_transformation_options'][$fieldindex]
+                        $_REQUEST['field_transformation_options'][$fieldindex],
+                        $_REQUEST['field_input_transformation'][$fieldindex],
+                        $_REQUEST['field_input_transformation_options'][$fieldindex]
                     );
                 }
             }
@@ -84,15 +92,14 @@ if (isset($_REQUEST['do_save_data'])) {
             __('Table %1$s has been altered successfully.')
         );
         $message->addParam($table);
-        $response->addJSON('message', $message);
         $response->addJSON(
-            'sql_query',
-            PMA_Util::getMessage(null, $sql_query)
+            'message', PMA_Util::getMessage($message, $sql_query, 'success')
         );
         exit;
     } else {
-        $error_message_html = PMA_Util::mysqlDie('', '', '', $err_url, false);
+        $error_message_html = PMA_Util::mysqlDie('', '', false, $err_url, false);
         $response->addHTML($error_message_html);
+        $response->isSuccess(false);
         exit;
     }
 } // end do alter table
@@ -102,7 +109,7 @@ if (isset($_REQUEST['do_save_data'])) {
  */
 if ($abort == false) {
     /**
-     * Gets tables informations
+     * Gets tables information
      */
     include_once 'libraries/tbl_common.inc.php';
     include_once 'libraries/tbl_info.inc.php';
@@ -114,4 +121,3 @@ if ($abort == false) {
     $action = 'tbl_addfield.php';
     include_once 'libraries/tbl_columns_definition_form.inc.php';
 }
-?>
