@@ -30,9 +30,14 @@ if (isset($_REQUEST['mult_btn'])) {
     $submit_mult = 'row_delete';
 }
 
+if (! isset($submit_mult)) {
+    $submit_mult = 'row_edit';
+}
+
 switch($submit_mult) {
 case 'row_delete':
 case 'row_edit':
+case 'row_copy':
 case 'row_export':
     // leave as is
     break;
@@ -45,24 +50,44 @@ case 'delete':
     $submit_mult = 'row_delete';
     break;
 
-default:
+case 'copy':
+    $submit_mult = 'row_copy';
+    break;
+
 case 'edit':
+default:
     $submit_mult = 'row_edit';
     break;
 }
 
 if (!empty($submit_mult)) {
+
+    if (isset($_REQUEST['goto'])
+        && (! isset($_REQUEST['rows_to_delete'])
+        || ! is_array($_REQUEST['rows_to_delete']))
+    ) {
+        $response = PMA_Response::getInstance();
+        $response->isSuccess(false);
+        $response->addJSON('message', __('No row selected.'));
+    }
+
     switch($submit_mult) {
+    case 'row_copy':
+        $_REQUEST['default_action'] = 'insert';
+        // no break to allow for fallthough
     case 'row_edit':
         // As we got the rows to be edited from the
         // 'rows_to_delete' checkbox, we use the index of it as the
         // indicating WHERE clause. Then we build the array which is used
         // for the tbl_change.php script.
         $where_clause = array();
-        foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
-            $where_clause[] = urldecode($i_where_clause);
+        if (isset($_REQUEST['rows_to_delete'])
+            && is_array($_REQUEST['rows_to_delete'])
+        ) {
+            foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
+                $where_clause[] = urldecode($i_where_clause);
+            }
         }
-
         $active_page = 'tbl_change.php';
         include 'tbl_change.php';
         break;
@@ -76,10 +101,13 @@ if (!empty($submit_mult)) {
         // indicating WHERE clause. Then we build the array which is used
         // for the tbl_change.php script.
         $where_clause = array();
-        foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
-            $where_clause[] = urldecode($i_where_clause);
+        if (isset($_REQUEST['rows_to_delete'])
+            && is_array($_REQUEST['rows_to_delete'])
+        ) {
+            foreach ($_REQUEST['rows_to_delete'] as $i => $i_where_clause) {
+                $where_clause[] = urldecode($i_where_clause);
+            }
         }
-
         $active_page = 'tbl_export.php';
         include 'tbl_export.php';
         break;
@@ -127,10 +155,24 @@ if (!empty($submit_mult)) {
         include_once 'libraries/parse_analyze.inc.php';
 
         PMA_executeQueryAndSendQueryResponse(
-            $analyzed_sql_results, false, $db, $table, null, null, null, false, null,
-            null, null, null, $goto, $pmaThemeImage, null, null, null, $sql_query,
-            null, null
+            $analyzed_sql_results, // analyzed_sql_results
+            false, // is_gotofile
+            $db, // db
+            $table, // table
+            null, // find_real_end
+            null, // sql_query_for_bookmark
+            null, // extra_data
+            null, // message_to_show
+            null, // message
+            null, // sql_data
+            $goto, // goto
+            $pmaThemeImage, // pmaThemeImage
+            null, // disp_query
+            null, // disp_message
+            null, // query_type
+            $sql_query, // sql_query
+            null, // selectedTables
+            null // complete_query
         );
     }
 }
-?>
