@@ -1,6 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * Table SQL executor
  *
  * @package PhpMyAdmin
  */
@@ -9,6 +10,9 @@
  *
  */
 require_once 'libraries/common.inc.php';
+require_once 'libraries/config/page_settings.class.php';
+
+PMA_PageSettings::showGroup('Sql_queries');
 
 /**
  * Runs common work
@@ -17,6 +21,7 @@ $response = PMA_Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('makegrid.js');
+$scripts->addFile('jquery/jquery.uitablefilter.js');
 $scripts->addFile('sql.js');
 
 require 'libraries/tbl_common.inc.php';
@@ -38,9 +43,11 @@ require_once 'libraries/tbl_info.inc.php';
 /**
  * Query box, bookmark, insert data from textfile
  */
-PMA_sqlQueryForm(
-    true, false,
-    isset($_REQUEST['delimiter']) ? htmlspecialchars($_REQUEST['delimiter']) : ';'
+$response->addHTML(
+    PMA_getHtmlForSqlQueryForm(
+        true, false,
+        isset($_REQUEST['delimiter'])
+        ? htmlspecialchars($_REQUEST['delimiter'])
+        : ';'
+    )
 );
-
-?>
